/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "msg_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_MSG_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::MSG >()))
        return -1;

    ::MSG* cptr = 0;
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { 0 };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "MSG", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: MSG()
    // 1: MSG(MSG)
    if (numArgs == 0) {
        overloadId = 0; // MSG()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_MSG_IDX], (pyArgs[0])))) {
        overloadId = 1; // MSG(MSG)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_MSG_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // MSG()
        {

            if (!PyErr_Occurred()) {
                // MSG()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::MSG();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // MSG(const MSG & MSG)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::MSG cppArg0_local = ::MSG();
            ::MSG* cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_MSG_IDX], pythonToCpp[0]))
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (!PyErr_Occurred()) {
                // MSG(MSG)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::MSG(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::MSG >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_MSG_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_MSG_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.MSG", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.MSG", overloads);
        return -1;
}

static PyObject* Sbk_MSG___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::MSG& cppSelf = *(((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self)));
    PyObject* pyResult = Shiboken::Conversions::copyToPython((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_MSG_IDX], &cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_MSG_methods[] = {

    {"__copy__", (PyCFunction)Sbk_MSG___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_MSG_get_lParam(PyObject* self, void*)
{
    ::MSG* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self));
    long cppOut_local = cppSelf->lParam;
    PyObject* pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<long>(), &cppOut_local);
    return pyOut;
}
static int Sbk_MSG_set_lParam(PyObject* self, PyObject* pyIn, void*)
{
    ::MSG* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self));
    if (pyIn == 0) {
        PyErr_SetString(PyExc_TypeError, "'lParam' may not be deleted");
        return -1;
    }
    PythonToCppFunc pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<long>(), (pyIn)))) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'lParam', 'long' or convertible type expected");
        return -1;
    }

    long cppOut_local = cppSelf->lParam;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->lParam = cppOut_local;

    return 0;
}

static PyObject* Sbk_MSG_get_pt(PyObject* self, void*)
{
    ::MSG* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self));
    PyObject* pyOut = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_POINT_IDX], &(cppSelf->pt), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_MSG_set_pt(PyObject* self, PyObject* pyIn, void*)
{
    ::MSG* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self));
    if (pyIn == 0) {
        PyErr_SetString(PyExc_TypeError, "'pt' may not be deleted");
        return -1;
    }
    PythonToCppFunc pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::isPythonToCppValueConvertible((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_POINT_IDX], (pyIn)))) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'pt', 'POINT' or convertible type expected");
        return -1;
    }

    ::POINT& cppOut_ptr = cppSelf->pt;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject* Sbk_MSG_get_hwnd(PyObject* self, void*)
{
    ::MSG* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self));
    PyObject* pyOut = Shiboken::Conversions::copyToPython(SbkPySide_QtCoreTypeConverters[SBK_HWND_IDX], &cppSelf->hwnd);
    return pyOut;
}
static int Sbk_MSG_set_hwnd(PyObject* self, PyObject* pyIn, void*)
{
    ::MSG* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self));
    if (pyIn == 0) {
        PyErr_SetString(PyExc_TypeError, "'hwnd' may not be deleted");
        return -1;
    }
    PythonToCppFunc pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide_QtCoreTypeConverters[SBK_HWND_IDX], (pyIn)))) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'hwnd', 'HWND' or convertible type expected");
        return -1;
    }

    ::HWND& cppOut_ptr = cppSelf->hwnd;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject* Sbk_MSG_get_time(PyObject* self, void*)
{
    ::MSG* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self));
    unsigned long cppOut_local = cppSelf->time;
    PyObject* pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), &cppOut_local);
    return pyOut;
}
static int Sbk_MSG_set_time(PyObject* self, PyObject* pyIn, void*)
{
    ::MSG* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self));
    if (pyIn == 0) {
        PyErr_SetString(PyExc_TypeError, "'time' may not be deleted");
        return -1;
    }
    PythonToCppFunc pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyIn)))) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'time', 'unsigned long' or convertible type expected");
        return -1;
    }

    unsigned long cppOut_local = cppSelf->time;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->time = cppOut_local;

    return 0;
}

// Getters and Setters for MSG
static PyGetSetDef Sbk_MSG_getsetlist[] = {
    {const_cast<char*>("lParam"), Sbk_MSG_get_lParam, Sbk_MSG_set_lParam},
    {const_cast<char*>("pt"), Sbk_MSG_get_pt, Sbk_MSG_set_pt},
    {const_cast<char*>("hwnd"), Sbk_MSG_get_hwnd, Sbk_MSG_set_hwnd},
    {const_cast<char*>("time"), Sbk_MSG_get_time, Sbk_MSG_set_time},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_MSG_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_MSG_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
extern "C"
{
static PyObject* Sbk_MSG__repr__(PyObject* self)
{
    ::MSG* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)self));
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    int idx = str.indexOf('(');
    if (idx >= 0)
        str.replace(0, idx, Py_TYPE(self)->tp_name);
    PyObject* mod = PyDict_GetItemString(Py_TYPE(self)->tp_dict, "__module__");
    if (mod)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    else
        return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_MSG_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.MSG",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_MSG__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_MSG_traverse,
    /*tp_clear*/            Sbk_MSG_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_MSG_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_MSG_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_MSG_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void MSG_PythonToCpp_MSG_PTR(PyObject* pyIn, void* cppOut) {
    Shiboken::Conversions::pythonToCppPointer(&Sbk_MSG_Type, pyIn, cppOut);
}
static PythonToCppFunc is_MSG_PythonToCpp_MSG_PTR_Convertible(PyObject* pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, (PyTypeObject*)&Sbk_MSG_Type))
        return MSG_PythonToCpp_MSG_PTR;
    return 0;
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject* MSG_PTR_CppToPython_MSG(const void* cppIn) {
    PyObject* pyOut = (PyObject*)Shiboken::BindingManager::instance().retrieveWrapper(cppIn);
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    const char* typeName = typeid(*((::MSG*)cppIn)).name();
    return Shiboken::Object::newObject(&Sbk_MSG_Type, const_cast<void*>(cppIn), false, false, typeName);
}

// C++ to Python copy conversion.
static PyObject* MSG_COPY_CppToPython_MSG(const void* cppIn) {
    return Shiboken::Object::newObject(&Sbk_MSG_Type, new ::MSG(*((::MSG*)cppIn)), true, true);
}

// Python to C++ copy conversion.
static void MSG_PythonToCpp_MSG_COPY(PyObject* pyIn, void* cppOut) {
    *((::MSG*)cppOut) = *((::MSG*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_MSG_IDX], (SbkObject*)pyIn));
}
static PythonToCppFunc is_MSG_PythonToCpp_MSG_COPY_Convertible(PyObject* pyIn) {
    if (PyObject_TypeCheck(pyIn, (PyTypeObject*)&Sbk_MSG_Type))
        return MSG_PythonToCpp_MSG_COPY;
    return 0;
}

void init_MSG(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_MSG_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_MSG_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "MSG", "MSG",
        &Sbk_MSG_Type, &Shiboken::callCppDestructor< ::MSG >)) {
        return;
    }

    // Register Converter
    SbkConverter* converter = Shiboken::Conversions::createConverter(&Sbk_MSG_Type,
        MSG_PythonToCpp_MSG_PTR,
        is_MSG_PythonToCpp_MSG_PTR_Convertible,
        MSG_PTR_CppToPython_MSG,
        MSG_COPY_CppToPython_MSG);

    Shiboken::Conversions::registerConverterName(converter, "MSG");
    Shiboken::Conversions::registerConverterName(converter, "MSG*");
    Shiboken::Conversions::registerConverterName(converter, "MSG&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::MSG).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        MSG_PythonToCpp_MSG_COPY,
        is_MSG_PythonToCpp_MSG_COPY_Convertible);


    qRegisterMetaType< ::MSG >("MSG");
}
