/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "point_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_POINT_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::POINT >()))
        return -1;

    ::POINT* cptr = 0;
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { 0 };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "POINT", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: POINT()
    // 1: POINT(POINT)
    if (numArgs == 0) {
        overloadId = 0; // POINT()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_POINT_IDX], (pyArgs[0])))) {
        overloadId = 1; // POINT(POINT)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_POINT_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // POINT()
        {

            if (!PyErr_Occurred()) {
                // POINT()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::POINT();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // POINT(const POINT & POINT)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::POINT cppArg0_local = ::POINT();
            ::POINT* cppArg0 = &cppArg0_local;
            if (Shiboken::Conversions::isImplicitConversion((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_POINT_IDX], pythonToCpp[0]))
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (!PyErr_Occurred()) {
                // POINT(POINT)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::POINT(*cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::POINT >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_POINT_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_POINT_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.POINT", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.POINT", overloads);
        return -1;
}

static PyObject* Sbk_POINT___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::POINT& cppSelf = *(((::POINT*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_POINT_IDX], (SbkObject*)self)));
    PyObject* pyResult = Shiboken::Conversions::copyToPython((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_POINT_IDX], &cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_POINT_methods[] = {

    {"__copy__", (PyCFunction)Sbk_POINT___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_POINT_get_x(PyObject* self, void*)
{
    ::POINT* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::POINT*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_POINT_IDX], (SbkObject*)self));
    long cppOut_local = cppSelf->x;
    PyObject* pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<long>(), &cppOut_local);
    return pyOut;
}
static int Sbk_POINT_set_x(PyObject* self, PyObject* pyIn, void*)
{
    ::POINT* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::POINT*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_POINT_IDX], (SbkObject*)self));
    if (pyIn == 0) {
        PyErr_SetString(PyExc_TypeError, "'x' may not be deleted");
        return -1;
    }
    PythonToCppFunc pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<long>(), (pyIn)))) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'x', 'long' or convertible type expected");
        return -1;
    }

    long cppOut_local = cppSelf->x;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->x = cppOut_local;

    return 0;
}

static PyObject* Sbk_POINT_get_y(PyObject* self, void*)
{
    ::POINT* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::POINT*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_POINT_IDX], (SbkObject*)self));
    long cppOut_local = cppSelf->y;
    PyObject* pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<long>(), &cppOut_local);
    return pyOut;
}
static int Sbk_POINT_set_y(PyObject* self, PyObject* pyIn, void*)
{
    ::POINT* cppSelf = 0;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = ((::POINT*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_POINT_IDX], (SbkObject*)self));
    if (pyIn == 0) {
        PyErr_SetString(PyExc_TypeError, "'y' may not be deleted");
        return -1;
    }
    PythonToCppFunc pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<long>(), (pyIn)))) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'y', 'long' or convertible type expected");
        return -1;
    }

    long cppOut_local = cppSelf->y;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->y = cppOut_local;

    return 0;
}

// Getters and Setters for POINT
static PyGetSetDef Sbk_POINT_getsetlist[] = {
    {const_cast<char*>("x"), Sbk_POINT_get_x, Sbk_POINT_set_x},
    {const_cast<char*>("y"), Sbk_POINT_get_y, Sbk_POINT_set_y},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_POINT_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_POINT_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_POINT_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.POINT",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_POINT_traverse,
    /*tp_clear*/            Sbk_POINT_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_POINT_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_POINT_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_POINT_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void POINT_PythonToCpp_POINT_PTR(PyObject* pyIn, void* cppOut) {
    Shiboken::Conversions::pythonToCppPointer(&Sbk_POINT_Type, pyIn, cppOut);
}
static PythonToCppFunc is_POINT_PythonToCpp_POINT_PTR_Convertible(PyObject* pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, (PyTypeObject*)&Sbk_POINT_Type))
        return POINT_PythonToCpp_POINT_PTR;
    return 0;
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject* POINT_PTR_CppToPython_POINT(const void* cppIn) {
    PyObject* pyOut = (PyObject*)Shiboken::BindingManager::instance().retrieveWrapper(cppIn);
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    const char* typeName = typeid(*((::POINT*)cppIn)).name();
    return Shiboken::Object::newObject(&Sbk_POINT_Type, const_cast<void*>(cppIn), false, false, typeName);
}

// C++ to Python copy conversion.
static PyObject* POINT_COPY_CppToPython_POINT(const void* cppIn) {
    return Shiboken::Object::newObject(&Sbk_POINT_Type, new ::POINT(*((::POINT*)cppIn)), true, true);
}

// Python to C++ copy conversion.
static void POINT_PythonToCpp_POINT_COPY(PyObject* pyIn, void* cppOut) {
    *((::POINT*)cppOut) = *((::POINT*)Shiboken::Conversions::cppPointer(SbkPySide_QtCoreTypes[SBK_POINT_IDX], (SbkObject*)pyIn));
}
static PythonToCppFunc is_POINT_PythonToCpp_POINT_COPY_Convertible(PyObject* pyIn) {
    if (PyObject_TypeCheck(pyIn, (PyTypeObject*)&Sbk_POINT_Type))
        return POINT_PythonToCpp_POINT_COPY;
    return 0;
}

void init_POINT(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_POINT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_POINT_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "POINT", "POINT",
        &Sbk_POINT_Type, &Shiboken::callCppDestructor< ::POINT >)) {
        return;
    }

    // Register Converter
    SbkConverter* converter = Shiboken::Conversions::createConverter(&Sbk_POINT_Type,
        POINT_PythonToCpp_POINT_PTR,
        is_POINT_PythonToCpp_POINT_PTR_Convertible,
        POINT_PTR_CppToPython_POINT,
        POINT_COPY_CppToPython_POINT);

    Shiboken::Conversions::registerConverterName(converter, "POINT");
    Shiboken::Conversions::registerConverterName(converter, "POINT*");
    Shiboken::Conversions::registerConverterName(converter, "POINT&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::POINT).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        POINT_PythonToCpp_POINT_COPY,
        is_POINT_PythonToCpp_POINT_COPY_Convertible);


    qRegisterMetaType< ::POINT >("POINT");
}
