/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QBUFFERWRAPPER_H
#define SBK_QBUFFERWRAPPER_H

#include <shiboken.h>

#include <qbuffer.h>

namespace PySide { class DynamicQMetaObject; }

class QBufferWrapper : public QBuffer
{
public:
    QBufferWrapper(QByteArray * buf, QObject * parent = 0);
    QBufferWrapper(QObject * parent = 0);
    virtual bool atEnd() const;
    virtual qint64 bytesAvailable() const;
    virtual qint64 bytesToWrite() const;
    virtual bool canReadLine() const;
    inline void childEvent_protected(QChildEvent * arg__1) { QBuffer::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual void close();
    inline void connectNotify_protected(const char * arg__1) { QBuffer::connectNotify(arg__1); }
    virtual void connectNotify(const char * arg__1);
    inline void customEvent_protected(QEvent * arg__1) { QBuffer::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * arg__1) { QBuffer::disconnectNotify(arg__1); }
    virtual void disconnectNotify(const char * arg__1);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    virtual bool isSequential() const;
    virtual const QMetaObject * metaObject() const;
    virtual bool open(QFlags<QIODevice::OpenModeFlag> openMode);
    virtual qint64 pos() const;
    inline qint64 readData_protected(char * data, qint64 maxlen) { return QBuffer::readData(data, maxlen); }
    virtual qint64 readData(char * data, qint64 maxlen);
    inline qint64 readLineData_protected(char * data, qint64 maxlen) { return QBuffer::readLineData(data, maxlen); }
    virtual qint64 readLineData(char * data, qint64 maxlen);
    inline int receivers_protected(const char * signal) const { return QBuffer::receivers(signal); }
    virtual bool reset();
    virtual bool seek(qint64 off);
    inline QObject * sender_protected() const { return QBuffer::sender(); }
    inline int senderSignalIndex_protected() const { return QBuffer::senderSignalIndex(); }
    inline void setErrorString_protected(const QString & errorString) { QBuffer::setErrorString(errorString); }
    inline void setOpenMode_protected(int openMode) { QBuffer::setOpenMode(QFlags<QIODevice::OpenModeFlag>(openMode)); }
    virtual qint64 size() const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QBuffer::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual bool waitForBytesWritten(int msecs);
    virtual bool waitForReadyRead(int msecs);
    inline qint64 writeData_protected(const char * data, qint64 len) { return QBuffer::writeData(data, len); }
    virtual qint64 writeData(const char * data, qint64 len);
    virtual ~QBufferWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QBUFFERWRAPPER_H

