/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QIODEVICEWRAPPER_H
#define SBK_QIODEVICEWRAPPER_H

#include <shiboken.h>

#include <qiodevice.h>

namespace PySide { class DynamicQMetaObject; }

class QIODeviceWrapper : public QIODevice
{
public:
    QIODeviceWrapper();
    QIODeviceWrapper(QObject * parent);
    virtual bool atEnd() const;
    virtual qint64 bytesAvailable() const;
    virtual qint64 bytesToWrite() const;
    virtual bool canReadLine() const;
    inline void childEvent_protected(QChildEvent * arg__1) { QIODevice::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual void close();
    inline void connectNotify_protected(const char * signal) { QIODevice::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void customEvent_protected(QEvent * arg__1) { QIODevice::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QIODevice::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    virtual bool isSequential() const;
    virtual const QMetaObject * metaObject() const;
    virtual bool open(QFlags<QIODevice::OpenModeFlag> mode);
    virtual qint64 pos() const;
    inline qint64 readData_protected(char * data, qint64 maxlen) { return readData(data, maxlen); }
    virtual qint64 readData(char * data, qint64 maxlen);
    inline qint64 readLineData_protected(char * data, qint64 maxlen) { return QIODevice::readLineData(data, maxlen); }
    virtual qint64 readLineData(char * data, qint64 maxlen);
    inline int receivers_protected(const char * signal) const { return QIODevice::receivers(signal); }
    virtual bool reset();
    virtual bool seek(qint64 pos);
    inline QObject * sender_protected() const { return QIODevice::sender(); }
    inline int senderSignalIndex_protected() const { return QIODevice::senderSignalIndex(); }
    inline void setErrorString_protected(const QString & errorString) { QIODevice::setErrorString(errorString); }
    inline void setOpenMode_protected(int openMode) { QIODevice::setOpenMode(QFlags<QIODevice::OpenModeFlag>(openMode)); }
    virtual qint64 size() const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QIODevice::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual bool waitForBytesWritten(int msecs);
    virtual bool waitForReadyRead(int msecs);
    inline qint64 writeData_protected(const char * data, qint64 len) { return writeData(data, len); }
    virtual qint64 writeData(const char * data, qint64 len);
    virtual ~QIODeviceWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QIODEVICEWRAPPER_H

