/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QDECLARATIVEITEMWRAPPER_H
#define SBK_QDECLARATIVEITEMWRAPPER_H

#include <shiboken.h>

#include <qdeclarativeitem.h>

namespace PySide { class DynamicQMetaObject; }

class QDeclarativeItemWrapper : public QDeclarativeItem
{
public:
    QDeclarativeItemWrapper(QDeclarativeItem * parent = 0);
    inline void addToIndex_protected() { QDeclarativeItem::addToIndex(); }
    virtual void advance(int phase);
    virtual QRectF boundingRect() const;
    inline void childEvent_protected(QChildEvent * arg__1) { QDeclarativeItem::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void classBegin_protected() { QDeclarativeItem::classBegin(); }
    virtual void classBegin();
    virtual bool collidesWithItem(const QGraphicsItem * other, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    virtual bool collidesWithPath(const QPainterPath & path, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    inline void componentComplete_protected() { QDeclarativeItem::componentComplete(); }
    virtual void componentComplete();
    inline void connectNotify_protected(const char * signal) { QDeclarativeItem::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    virtual bool contains(const QPointF & point) const;
    inline void contextMenuEvent_protected(QGraphicsSceneContextMenuEvent * event) { QDeclarativeItem::contextMenuEvent(event); }
    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QDeclarativeItem::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QDeclarativeItem::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QGraphicsSceneDragDropEvent * event) { QDeclarativeItem::dragEnterEvent(event); }
    virtual void dragEnterEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragLeaveEvent_protected(QGraphicsSceneDragDropEvent * event) { QDeclarativeItem::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragMoveEvent_protected(QGraphicsSceneDragDropEvent * event) { QDeclarativeItem::dragMoveEvent(event); }
    virtual void dragMoveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dropEvent_protected(QGraphicsSceneDragDropEvent * event) { QDeclarativeItem::dropEvent(event); }
    virtual void dropEvent(QGraphicsSceneDragDropEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QDeclarativeItem::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline QVariant extension_protected(const QVariant & variant) const { return QDeclarativeItem::extension(variant); }
    virtual QVariant extension(const QVariant & variant) const;
    inline void focusInEvent_protected(QFocusEvent * event) { QDeclarativeItem::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline void focusOutEvent_protected(QFocusEvent * event) { QDeclarativeItem::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline void geometryChanged_protected(const QRectF & newGeometry, const QRectF & oldGeometry) { QDeclarativeItem::geometryChanged(newGeometry, oldGeometry); }
    virtual void geometryChanged(const QRectF & newGeometry, const QRectF & oldGeometry);
    inline bool heightValid_protected() const { return QDeclarativeItem::heightValid(); }
    inline void hoverEnterEvent_protected(QGraphicsSceneHoverEvent * event) { QDeclarativeItem::hoverEnterEvent(event); }
    virtual void hoverEnterEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverLeaveEvent_protected(QGraphicsSceneHoverEvent * event) { QDeclarativeItem::hoverLeaveEvent(event); }
    virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverMoveEvent_protected(QGraphicsSceneHoverEvent * event) { QDeclarativeItem::hoverMoveEvent(event); }
    virtual void hoverMoveEvent(QGraphicsSceneHoverEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * arg__1) { QDeclarativeItem::inputMethodEvent(arg__1); }
    virtual void inputMethodEvent(QInputMethodEvent * arg__1);
    inline void inputMethodPreHandler_protected(QInputMethodEvent * arg__1) { QDeclarativeItem::inputMethodPreHandler(arg__1); }
    inline QVariant inputMethodQuery_protected(int query) const { return QDeclarativeItem::inputMethodQuery(Qt::InputMethodQuery(query)); }
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline bool isComponentComplete_protected() const { return QDeclarativeItem::isComponentComplete(); }
    virtual bool isObscuredBy(const QGraphicsItem * item) const;
    inline QVariant itemChange_protected(int arg__1, const QVariant & arg__2) { return QDeclarativeItem::itemChange(QGraphicsItem::GraphicsItemChange(arg__1), arg__2); }
    virtual QVariant itemChange(QGraphicsItem::GraphicsItemChange arg__1, const QVariant & arg__2);
    inline void keyPressEvent_protected(QKeyEvent * event) { QDeclarativeItem::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyPressPreHandler_protected(QKeyEvent * arg__1) { QDeclarativeItem::keyPressPreHandler(arg__1); }
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QDeclarativeItem::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void keyReleasePreHandler_protected(QKeyEvent * arg__1) { QDeclarativeItem::keyReleasePreHandler(arg__1); }
    virtual const QMetaObject * metaObject() const;
    inline void mouseDoubleClickEvent_protected(QGraphicsSceneMouseEvent * event) { QDeclarativeItem::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseMoveEvent_protected(QGraphicsSceneMouseEvent * event) { QDeclarativeItem::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
    inline void mousePressEvent_protected(QGraphicsSceneMouseEvent * event) { QDeclarativeItem::mousePressEvent(event); }
    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseReleaseEvent_protected(QGraphicsSceneMouseEvent * event) { QDeclarativeItem::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
    virtual QPainterPath opaqueArea() const;
    virtual void paint(QPainter * arg__1, const QStyleOptionGraphicsItem * arg__2, QWidget * arg__3);
    inline void prepareGeometryChange_protected() { QDeclarativeItem::prepareGeometryChange(); }
    inline int receivers_protected(const char * signal) const { return QDeclarativeItem::receivers(signal); }
    inline void removeFromIndex_protected() { QDeclarativeItem::removeFromIndex(); }
    inline bool sceneEvent_protected(QEvent * arg__1) { return QDeclarativeItem::sceneEvent(arg__1); }
    virtual bool sceneEvent(QEvent * arg__1);
    inline bool sceneEventFilter_protected(QGraphicsItem * watched, QEvent * event) { return QDeclarativeItem::sceneEventFilter(watched, event); }
    virtual bool sceneEventFilter(QGraphicsItem * watched, QEvent * event);
    inline QObject * sender_protected() const { return QDeclarativeItem::sender(); }
    inline int senderSignalIndex_protected() const { return QDeclarativeItem::senderSignalIndex(); }
    inline void setImplicitHeight_protected(qreal arg__1) { QDeclarativeItem::setImplicitHeight(arg__1); }
    inline void setImplicitWidth_protected(qreal arg__1) { QDeclarativeItem::setImplicitWidth(arg__1); }
    virtual QPainterPath shape() const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QDeclarativeItem::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual int type() const;
    inline void updateMicroFocus_protected() { QDeclarativeItem::updateMicroFocus(); }
    inline void wheelEvent_protected(QGraphicsSceneWheelEvent * event) { QDeclarativeItem::wheelEvent(event); }
    virtual void wheelEvent(QGraphicsSceneWheelEvent * event);
    inline bool widthValid_protected() const { return QDeclarativeItem::widthValid(); }
    virtual ~QDeclarativeItemWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QDECLARATIVEITEMWRAPPER_H

