/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QDECLARATIVEVIEWWRAPPER_H
#define SBK_QDECLARATIVEVIEWWRAPPER_H

#include <shiboken.h>

#include <qdeclarativeview.h>

namespace PySide { class DynamicQMetaObject; }

class QDeclarativeViewWrapper : public QDeclarativeView
{
public:
    QDeclarativeViewWrapper(QWidget * parent = 0);
    QDeclarativeViewWrapper(const QUrl & source, QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QDeclarativeView::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QDeclarativeView::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QDeclarativeView::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QDeclarativeView::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QDeclarativeView::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QDeclarativeView::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QDeclarativeView::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QDeclarativeView::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QDeclarativeView::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QDeclarativeView::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QDeclarativeView::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QDeclarativeView::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void drawBackground_protected(QPainter * painter, const QRectF & rect) { QDeclarativeView::drawBackground(painter, rect); }
    virtual void drawBackground(QPainter * painter, const QRectF & rect);
    inline void drawForeground_protected(QPainter * painter, const QRectF & rect) { QDeclarativeView::drawForeground(painter, rect); }
    virtual void drawForeground(QPainter * painter, const QRectF & rect);
    inline void drawFrame_protected(QPainter * arg__1) { QDeclarativeView::drawFrame(arg__1); }
    inline void drawItems_protected(QPainter * painter, int numItems, QGraphicsItem ** items, const QStyleOptionGraphicsItem * options) { QDeclarativeView::drawItems(painter, numItems, items, options); }
    virtual void drawItems(QPainter * painter, int numItems, QGraphicsItem ** items, const QStyleOptionGraphicsItem * options);
    inline void dropEvent_protected(QDropEvent * event) { QDeclarativeView::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QDeclarativeView::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * event) { return QDeclarativeView::event(event); }
    virtual bool event(QEvent * event);
    inline bool eventFilter_protected(QObject * watched, QEvent * e) { return QDeclarativeView::eventFilter(watched, e); }
    virtual bool eventFilter(QObject * watched, QEvent * e);
    inline void focusInEvent_protected(QFocusEvent * event) { QDeclarativeView::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QDeclarativeView::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QDeclarativeView::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QDeclarativeView::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QDeclarativeView::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QDeclarativeView::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QDeclarativeView::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QDeclarativeView::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QDeclarativeView::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QDeclarativeView::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QDeclarativeView::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QDeclarativeView::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QDeclarativeView::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QDeclarativeView::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QDeclarativeView::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QDeclarativeView::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline void moveEvent_protected(QMoveEvent * event) { QDeclarativeView::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * event) { QDeclarativeView::paintEvent(event); }
    virtual void paintEvent(QPaintEvent * event);
    inline void resetInputContext_protected() { QDeclarativeView::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * arg__1) { QDeclarativeView::resizeEvent(arg__1); }
    virtual void resizeEvent(QResizeEvent * arg__1);
    inline void scrollContentsBy_protected(int dx, int dy) { QDeclarativeView::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void setRootObject_protected(QObject * obj) { QDeclarativeView::setRootObject(obj); }
    virtual void setRootObject(QObject * obj);
    inline void setViewportMargins_protected(const QMargins & margins) { QDeclarativeView::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QDeclarativeView::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * widget) { QDeclarativeView::setupViewport(widget); }
    inline void showEvent_protected(QShowEvent * event) { QDeclarativeView::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QDeclarativeView::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QDeclarativeView::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QDeclarativeView::updateMicroFocus(); }
    inline bool viewportEvent_protected(QEvent * event) { return QDeclarativeView::viewportEvent(event); }
    virtual bool viewportEvent(QEvent * event);
    inline void wheelEvent_protected(QWheelEvent * event) { QDeclarativeView::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QDeclarativeView::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QDeclarativeViewWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QDECLARATIVEVIEWWRAPPER_H

