/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QABSTRACTPROXYMODELWRAPPER_H
#define SBK_QABSTRACTPROXYMODELWRAPPER_H

#include <shiboken.h>

#include <qabstractproxymodel.h>

namespace PySide { class DynamicQMetaObject; }

class QAbstractProxyModelWrapper : public QAbstractProxyModel
{
public:
    QAbstractProxyModelWrapper(QObject * parent = 0);
    inline void beginInsertColumns_protected(const QModelIndex & parent, int first, int last) { QAbstractProxyModel::beginInsertColumns(parent, first, last); }
    inline void beginInsertRows_protected(const QModelIndex & parent, int first, int last) { QAbstractProxyModel::beginInsertRows(parent, first, last); }
    inline bool beginMoveColumns_protected(const QModelIndex & sourceParent, int sourceFirst, int sourceLast, const QModelIndex & destinationParent, int destinationColumn) { return QAbstractProxyModel::beginMoveColumns(sourceParent, sourceFirst, sourceLast, destinationParent, destinationColumn); }
    inline bool beginMoveRows_protected(const QModelIndex & sourceParent, int sourceFirst, int sourceLast, const QModelIndex & destinationParent, int destinationRow) { return QAbstractProxyModel::beginMoveRows(sourceParent, sourceFirst, sourceLast, destinationParent, destinationRow); }
    inline void beginRemoveColumns_protected(const QModelIndex & parent, int first, int last) { QAbstractProxyModel::beginRemoveColumns(parent, first, last); }
    inline void beginRemoveRows_protected(const QModelIndex & parent, int first, int last) { QAbstractProxyModel::beginRemoveRows(parent, first, last); }
    inline void beginResetModel_protected() { QAbstractProxyModel::beginResetModel(); }
    virtual QModelIndex buddy(const QModelIndex & index) const;
    virtual bool canFetchMore(const QModelIndex & parent) const;
    inline void changePersistentIndex_protected(const QModelIndex & from, const QModelIndex & to) { QAbstractProxyModel::changePersistentIndex(from, to); }
    inline void changePersistentIndexList_protected(const QModelIndexList & from, const QModelIndexList & to) { QAbstractProxyModel::changePersistentIndexList(from, to); }
    inline void childEvent_protected(QChildEvent * arg__1) { QAbstractProxyModel::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual int columnCount(const QModelIndex & parent = QModelIndex()) const;
    inline void connectNotify_protected(const char * signal) { QAbstractProxyModel::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline QModelIndex createIndex_protected(int row, int column, int id) const { return QAbstractProxyModel::createIndex(row, column, id); }
    inline void customEvent_protected(QEvent * arg__1) { QAbstractProxyModel::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    virtual QVariant data(const QModelIndex & proxyIndex, int role = Qt::DisplayRole) const;
    inline bool decodeData_protected(int row, int column, const QModelIndex & parent, QDataStream & stream) { return QAbstractProxyModel::decodeData(row, column, parent, stream); }
    inline void disconnectNotify_protected(const char * signal) { QAbstractProxyModel::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    virtual bool dropMimeData(const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent);
    inline void encodeData_protected(const QModelIndexList & indexes, QDataStream & stream) const { QAbstractProxyModel::encodeData(indexes, stream); }
    inline void endInsertColumns_protected() { QAbstractProxyModel::endInsertColumns(); }
    inline void endInsertRows_protected() { QAbstractProxyModel::endInsertRows(); }
    inline void endMoveColumns_protected() { QAbstractProxyModel::endMoveColumns(); }
    inline void endMoveRows_protected() { QAbstractProxyModel::endMoveRows(); }
    inline void endRemoveColumns_protected() { QAbstractProxyModel::endRemoveColumns(); }
    inline void endRemoveRows_protected() { QAbstractProxyModel::endRemoveRows(); }
    inline void endResetModel_protected() { QAbstractProxyModel::endResetModel(); }
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    virtual void fetchMore(const QModelIndex & parent);
    virtual QFlags<Qt::ItemFlag> flags(const QModelIndex & index) const;
    virtual bool hasChildren(const QModelIndex & parent = QModelIndex()) const;
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const;
    virtual QModelIndex index(int row, int column, const QModelIndex & parent = QModelIndex()) const;
    virtual bool insertColumns(int column, int count, const QModelIndex & parent = QModelIndex());
    virtual bool insertRows(int row, int count, const QModelIndex & parent = QModelIndex());
    virtual QMap<int, QVariant > itemData(const QModelIndex & index) const;
    virtual QModelIndex mapFromSource(const QModelIndex & sourceIndex) const;
    virtual QItemSelection mapSelectionFromSource(const QItemSelection & selection) const;
    virtual QItemSelection mapSelectionToSource(const QItemSelection & selection) const;
    virtual QModelIndex mapToSource(const QModelIndex & proxyIndex) const;
    virtual QModelIndexList match(const QModelIndex & start, int role, const QVariant & value, int hits = 1, QFlags<Qt::MatchFlag> flags = Qt::MatchFlags(Qt::MatchStartsWith|Qt::MatchWrap)) const;
    virtual const QMetaObject * metaObject() const;
    virtual QMimeData * mimeData(const QModelIndexList & indexes) const;
    virtual QStringList mimeTypes() const;
    virtual QModelIndex parent(const QModelIndex & child) const;
    inline QModelIndexList persistentIndexList_protected() const { return QAbstractProxyModel::persistentIndexList(); }
    inline int receivers_protected(const char * signal) const { return QAbstractProxyModel::receivers(signal); }
    virtual bool removeColumns(int column, int count, const QModelIndex & parent = QModelIndex());
    virtual bool removeRows(int row, int count, const QModelIndex & parent = QModelIndex());
    inline void reset_protected() { QAbstractProxyModel::reset(); }
    inline void resetInternalData_protected() { QAbstractProxyModel::resetInternalData(); }
    virtual void revert();
    virtual int rowCount(const QModelIndex & parent = QModelIndex()) const;
    inline QObject * sender_protected() const { return QAbstractProxyModel::sender(); }
    inline int senderSignalIndex_protected() const { return QAbstractProxyModel::senderSignalIndex(); }
    virtual bool setData(const QModelIndex & index, const QVariant & value, int role = Qt::EditRole);
    virtual bool setHeaderData(int section, Qt::Orientation orientation, const QVariant & value, int role = Qt::EditRole);
    virtual bool setItemData(const QModelIndex & index, const QMap<int, QVariant > & roles);
    inline void setRoleNames_protected(const QHash<int, QByteArray > & roleNames) { QAbstractProxyModel::setRoleNames(roleNames); }
    virtual void setSourceModel(QAbstractItemModel * sourceModel);
    virtual void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);
    virtual QSize span(const QModelIndex & index) const;
    virtual bool submit();
    virtual QFlags<Qt::DropAction> supportedDropActions() const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QAbstractProxyModel::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual ~QAbstractProxyModelWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    // Inherited overloads, because the using keyword sux
    inline QObject * parent() const { return QAbstractProxyModel::parent(); }
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QABSTRACTPROXYMODELWRAPPER_H

