/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QABSTRACTSLIDERWRAPPER_H
#define SBK_QABSTRACTSLIDERWRAPPER_H

#include <shiboken.h>

#include <qabstractslider.h>

namespace PySide { class DynamicQMetaObject; }

class QAbstractSliderWrapper : public QAbstractSlider
{
public:
    QAbstractSliderWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QAbstractSlider::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * e) { QAbstractSlider::changeEvent(e); }
    virtual void changeEvent(QEvent * e);
    inline void childEvent_protected(QChildEvent * arg__1) { QAbstractSlider::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QAbstractSlider::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QAbstractSlider::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QAbstractSlider::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QAbstractSlider::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QAbstractSlider::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QAbstractSlider::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QAbstractSlider::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QAbstractSlider::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QAbstractSlider::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QAbstractSlider::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QAbstractSlider::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QAbstractSlider::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QAbstractSlider::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QAbstractSlider::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QAbstractSlider::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QAbstractSlider::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QAbstractSlider::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QAbstractSlider::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QAbstractSlider::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * ev) { QAbstractSlider::keyPressEvent(ev); }
    virtual void keyPressEvent(QKeyEvent * ev);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QAbstractSlider::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QAbstractSlider::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QAbstractSlider::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QAbstractSlider::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QAbstractSlider::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QAbstractSlider::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QAbstractSlider::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QAbstractSlider::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline void moveEvent_protected(QMoveEvent * event) { QAbstractSlider::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * event) { QAbstractSlider::paintEvent(event); }
    virtual void paintEvent(QPaintEvent * event);
    inline int repeatAction_protected() const { return QAbstractSlider::repeatAction(); }
    inline void resetInputContext_protected() { QAbstractSlider::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QAbstractSlider::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    inline void setRepeatAction_protected(int action, int thresholdTime = 500, int repeatTime = 50) { QAbstractSlider::setRepeatAction(QAbstractSlider::SliderAction(action), thresholdTime, repeatTime); }
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QAbstractSlider::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void sliderChange_protected(int change) { QAbstractSlider::sliderChange(QAbstractSlider::SliderChange(change)); }
    virtual void sliderChange(QAbstractSlider::SliderChange change);
    inline void tabletEvent_protected(QTabletEvent * event) { QAbstractSlider::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QAbstractSlider::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QAbstractSlider::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * e) { QAbstractSlider::wheelEvent(e); }
    virtual void wheelEvent(QWheelEvent * e);
    inline bool winEvent_protected(MSG * message, long * result) { return QAbstractSlider::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QAbstractSliderWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QABSTRACTSLIDERWRAPPER_H

