/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QCOLUMNVIEWWRAPPER_H
#define SBK_QCOLUMNVIEWWRAPPER_H

#include <shiboken.h>

#include <qcolumnview.h>

namespace PySide { class DynamicQMetaObject; }

class QColumnViewWrapper : public QColumnView
{
public:
    QColumnViewWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QColumnView::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QColumnView::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QColumnView::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEditor_protected(QWidget * editor, int hint) { QColumnView::closeEditor(editor, QAbstractItemDelegate::EndEditHint(hint)); }
    virtual void closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint);
    inline void closeEvent_protected(QCloseEvent * event) { QColumnView::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void commitData_protected(QWidget * editor) { QColumnView::commitData(editor); }
    virtual void commitData(QWidget * editor);
    inline void connectNotify_protected(const char * signal) { QColumnView::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QColumnView::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline QAbstractItemView * createColumn_protected(const QModelIndex & rootIndex) { return QColumnView::createColumn(rootIndex); }
    virtual QAbstractItemView * createColumn(const QModelIndex & rootIndex);
    inline void currentChanged_protected(const QModelIndex & current, const QModelIndex & previous) { QColumnView::currentChanged(current, previous); }
    virtual void currentChanged(const QModelIndex & current, const QModelIndex & previous);
    inline void customEvent_protected(QEvent * arg__1) { QColumnView::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void dataChanged_protected(const QModelIndex & topLeft, const QModelIndex & bottomRight) { QColumnView::dataChanged(topLeft, bottomRight); }
    virtual void dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QColumnView::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline QPoint dirtyRegionOffset_protected() const { return QColumnView::dirtyRegionOffset(); }
    inline void disconnectNotify_protected(const char * signal) { QColumnView::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void doAutoScroll_protected() { QColumnView::doAutoScroll(); }
    virtual void doItemsLayout();
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QColumnView::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QColumnView::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QColumnView::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void drawFrame_protected(QPainter * arg__1) { QColumnView::drawFrame(arg__1); }
    inline void dropEvent_protected(QDropEvent * event) { QColumnView::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline int dropIndicatorPosition_protected() const { return QColumnView::dropIndicatorPosition(); }
    inline bool edit_protected(const QModelIndex & index, int trigger, QEvent * event) { return QColumnView::edit(index, QAbstractItemView::EditTrigger(trigger), event); }
    virtual bool edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event);
    inline void editorDestroyed_protected(QObject * editor) { QColumnView::editorDestroyed(editor); }
    virtual void editorDestroyed(QObject * editor);
    inline void enterEvent_protected(QEvent * event) { QColumnView::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * event) { return QColumnView::event(event); }
    virtual bool event(QEvent * event);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void executeDelayedItemsLayout_protected() { QColumnView::executeDelayedItemsLayout(); }
    inline void focusInEvent_protected(QFocusEvent * event) { QColumnView::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QColumnView::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QColumnView::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QColumnView::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QColumnView::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QColumnView::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline int horizontalOffset_protected() const { return QColumnView::horizontalOffset(); }
    virtual int horizontalOffset() const;
    inline void horizontalScrollbarAction_protected(int action) { QColumnView::horizontalScrollbarAction(action); }
    virtual void horizontalScrollbarAction(int action);
    inline void horizontalScrollbarValueChanged_protected(int value) { QColumnView::horizontalScrollbarValueChanged(value); }
    virtual void horizontalScrollbarValueChanged(int value);
    virtual QModelIndex indexAt(const QPoint & point) const;
    inline void initializeColumn_protected(QAbstractItemView * column) const { QColumnView::initializeColumn(column); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QColumnView::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline bool isIndexHidden_protected(const QModelIndex & index) const { return QColumnView::isIndexHidden(index); }
    virtual bool isIndexHidden(const QModelIndex & index) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QColumnView::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QColumnView::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual void keyboardSearch(const QString & search);
    inline void languageChange_protected() { QColumnView::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QColumnView::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QColumnView::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QColumnView::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QColumnView::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QColumnView::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QColumnView::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline QModelIndex moveCursor_protected(int cursorAction, int modifiers) { return QColumnView::moveCursor(QAbstractItemView::CursorAction(cursorAction), QFlags<Qt::KeyboardModifier>(modifiers)); }
    virtual QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction, QFlags<Qt::KeyboardModifier> modifiers);
    inline void moveEvent_protected(QMoveEvent * event) { QColumnView::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QColumnView::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    virtual void reset();
    inline void resetInputContext_protected() { QColumnView::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QColumnView::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    inline void rowsAboutToBeRemoved_protected(const QModelIndex & parent, int start, int end) { QColumnView::rowsAboutToBeRemoved(parent, start, end); }
    virtual void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end);
    inline void rowsInserted_protected(const QModelIndex & parent, int start, int end) { QColumnView::rowsInserted(parent, start, end); }
    virtual void rowsInserted(const QModelIndex & parent, int start, int end);
    inline void scheduleDelayedItemsLayout_protected() { QColumnView::scheduleDelayedItemsLayout(); }
    inline void scrollContentsBy_protected(int dx, int dy) { QColumnView::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void scrollDirtyRegion_protected(int dx, int dy) { QColumnView::scrollDirtyRegion(dx, dy); }
    virtual void scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint = EnsureVisible);
    virtual void selectAll();
    inline QModelIndexList selectedIndexes_protected() const { return QColumnView::selectedIndexes(); }
    virtual QModelIndexList selectedIndexes() const;
    inline void selectionChanged_protected(const QItemSelection & selected, const QItemSelection & deselected) { QColumnView::selectionChanged(selected, deselected); }
    virtual void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
    inline int selectionCommand_protected(const QModelIndex & index, const QEvent * event = 0) const { return QColumnView::selectionCommand(index, event); }
    virtual QFlags<QItemSelectionModel::SelectionFlag> selectionCommand(const QModelIndex & index, const QEvent * event = 0) const;
    inline void setDirtyRegion_protected(const QRegion & region) { QColumnView::setDirtyRegion(region); }
    virtual void setModel(QAbstractItemModel * model);
    virtual void setRootIndex(const QModelIndex & index);
    inline void setSelection_protected(const QRect & rect, int command) { QColumnView::setSelection(rect, QFlags<QItemSelectionModel::SelectionFlag>(command)); }
    virtual void setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command);
    virtual void setSelectionModel(QItemSelectionModel * selectionModel);
    inline void setState_protected(int state) { QColumnView::setState(QAbstractItemView::State(state)); }
    inline void setViewportMargins_protected(const QMargins & margins) { QColumnView::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QColumnView::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QColumnView::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * event) { QColumnView::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    virtual int sizeHintForColumn(int column) const;
    virtual int sizeHintForRow(int row) const;
    inline void startAutoScroll_protected() { QColumnView::startAutoScroll(); }
    inline void startDrag_protected(int supportedActions) { QColumnView::startDrag(QFlags<Qt::DropAction>(supportedActions)); }
    virtual void startDrag(QFlags<Qt::DropAction> supportedActions);
    inline int state_protected() const { return QColumnView::state(); }
    inline void stopAutoScroll_protected() { QColumnView::stopAutoScroll(); }
    inline void tabletEvent_protected(QTabletEvent * event) { QColumnView::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * event) { QColumnView::timerEvent(event); }
    virtual void timerEvent(QTimerEvent * event);
    inline void updateEditorData_protected() { QColumnView::updateEditorData(); }
    virtual void updateEditorData();
    inline void updateEditorGeometries_protected() { QColumnView::updateEditorGeometries(); }
    virtual void updateEditorGeometries();
    inline void updateGeometries_protected() { QColumnView::updateGeometries(); }
    virtual void updateGeometries();
    inline void updateMicroFocus_protected() { QColumnView::updateMicroFocus(); }
    inline int verticalOffset_protected() const { return QColumnView::verticalOffset(); }
    virtual int verticalOffset() const;
    inline void verticalScrollbarAction_protected(int action) { QColumnView::verticalScrollbarAction(action); }
    virtual void verticalScrollbarAction(int action);
    inline void verticalScrollbarValueChanged_protected(int value) { QColumnView::verticalScrollbarValueChanged(value); }
    virtual void verticalScrollbarValueChanged(int value);
    inline QStyleOptionViewItem viewOptions_protected() const { return QColumnView::viewOptions(); }
    virtual QStyleOptionViewItem viewOptions() const;
    inline bool viewportEvent_protected(QEvent * event) { return QColumnView::viewportEvent(event); }
    virtual bool viewportEvent(QEvent * event);
    virtual QRect visualRect(const QModelIndex & index) const;
    inline QRegion visualRegionForSelection_protected(const QItemSelection & selection) const { return QColumnView::visualRegionForSelection(selection); }
    virtual QRegion visualRegionForSelection(const QItemSelection & selection) const;
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QColumnView::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QColumnView::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QColumnViewWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    // Inherited overloads, because the using keyword sux
    inline void edit(const QModelIndex & index) { QColumnView::edit(index); }
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QCOLUMNVIEWWRAPPER_H

