/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QCOMBOBOXWRAPPER_H
#define SBK_QCOMBOBOXWRAPPER_H

#include <shiboken.h>

#include <qcombobox.h>

namespace PySide { class DynamicQMetaObject; }

class QComboBoxWrapper : public QComboBox
{
public:
    QComboBoxWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QComboBox::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * e) { QComboBox::changeEvent(e); }
    virtual void changeEvent(QEvent * e);
    inline void childEvent_protected(QChildEvent * arg__1) { QComboBox::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QComboBox::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QComboBox::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * e) { QComboBox::contextMenuEvent(e); }
    virtual void contextMenuEvent(QContextMenuEvent * e);
    inline void customEvent_protected(QEvent * arg__1) { QComboBox::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QComboBox::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QComboBox::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QComboBox::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QComboBox::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QComboBox::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QComboBox::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QComboBox::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    virtual bool event(QEvent * event);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * e) { QComboBox::focusInEvent(e); }
    virtual void focusInEvent(QFocusEvent * e);
    inline bool focusNextChild_protected() { return QComboBox::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QComboBox::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * e) { QComboBox::focusOutEvent(e); }
    virtual void focusOutEvent(QFocusEvent * e);
    inline bool focusPreviousChild_protected() { return QComboBox::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * e) { QComboBox::hideEvent(e); }
    virtual void hideEvent(QHideEvent * e);
    virtual void hidePopup();
    inline void initStyleOption_protected(QStyleOptionComboBox * option) const { QComboBox::initStyleOption(option); }
    inline void inputMethodEvent_protected(QInputMethodEvent * arg__1) { QComboBox::inputMethodEvent(arg__1); }
    virtual void inputMethodEvent(QInputMethodEvent * arg__1);
    inline QVariant inputMethodQuery_protected(int arg__1) const { return QComboBox::inputMethodQuery(Qt::InputMethodQuery(arg__1)); }
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * e) { QComboBox::keyPressEvent(e); }
    virtual void keyPressEvent(QKeyEvent * e);
    inline void keyReleaseEvent_protected(QKeyEvent * e) { QComboBox::keyReleaseEvent(e); }
    virtual void keyReleaseEvent(QKeyEvent * e);
    inline void languageChange_protected() { QComboBox::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QComboBox::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QComboBox::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QComboBox::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QComboBox::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * e) { QComboBox::mousePressEvent(e); }
    virtual void mousePressEvent(QMouseEvent * e);
    inline void mouseReleaseEvent_protected(QMouseEvent * e) { QComboBox::mouseReleaseEvent(e); }
    virtual void mouseReleaseEvent(QMouseEvent * e);
    inline void moveEvent_protected(QMoveEvent * event) { QComboBox::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * e) { QComboBox::paintEvent(e); }
    virtual void paintEvent(QPaintEvent * e);
    inline void resetInputContext_protected() { QComboBox::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * e) { QComboBox::resizeEvent(e); }
    virtual void resizeEvent(QResizeEvent * e);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * e) { QComboBox::showEvent(e); }
    virtual void showEvent(QShowEvent * e);
    virtual void showPopup();
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QComboBox::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QComboBox::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QComboBox::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * e) { QComboBox::wheelEvent(e); }
    virtual void wheelEvent(QWheelEvent * e);
    inline bool winEvent_protected(MSG * message, long * result) { return QComboBox::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QComboBoxWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QCOMBOBOXWRAPPER_H

