/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QDIALWRAPPER_H
#define SBK_QDIALWRAPPER_H

#include <shiboken.h>

#include <qdial.h>

namespace PySide { class DynamicQMetaObject; }

class QDialWrapper : public QDial
{
public:
    QDialWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QDial::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * e) { QDial::changeEvent(e); }
    virtual void changeEvent(QEvent * e);
    inline void childEvent_protected(QChildEvent * arg__1) { QDial::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QDial::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QDial::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QDial::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QDial::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QDial::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QDial::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QDial::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QDial::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QDial::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QDial::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QDial::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QDial::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QDial::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QDial::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QDial::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QDial::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QDial::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QDial::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void initStyleOption_protected(QStyleOptionSlider * option) const { QDial::initStyleOption(option); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QDial::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * ev) { QDial::keyPressEvent(ev); }
    virtual void keyPressEvent(QKeyEvent * ev);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QDial::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QDial::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QDial::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QDial::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QDial::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * me) { QDial::mouseMoveEvent(me); }
    virtual void mouseMoveEvent(QMouseEvent * me);
    inline void mousePressEvent_protected(QMouseEvent * me) { QDial::mousePressEvent(me); }
    virtual void mousePressEvent(QMouseEvent * me);
    inline void mouseReleaseEvent_protected(QMouseEvent * me) { QDial::mouseReleaseEvent(me); }
    virtual void mouseReleaseEvent(QMouseEvent * me);
    inline void moveEvent_protected(QMoveEvent * event) { QDial::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * pe) { QDial::paintEvent(pe); }
    virtual void paintEvent(QPaintEvent * pe);
    inline int repeatAction_protected() const { return QDial::repeatAction(); }
    inline void resetInputContext_protected() { QDial::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * re) { QDial::resizeEvent(re); }
    virtual void resizeEvent(QResizeEvent * re);
    inline void setRepeatAction_protected(int action, int thresholdTime = 500, int repeatTime = 50) { QDial::setRepeatAction(QAbstractSlider::SliderAction(action), thresholdTime, repeatTime); }
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QDial::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void sliderChange_protected(int change) { QDial::sliderChange(QAbstractSlider::SliderChange(change)); }
    virtual void sliderChange(QAbstractSlider::SliderChange change);
    inline void tabletEvent_protected(QTabletEvent * event) { QDial::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QDial::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QDial::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * e) { QDial::wheelEvent(e); }
    virtual void wheelEvent(QWheelEvent * e);
    inline bool winEvent_protected(MSG * message, long * result) { return QDial::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QDialWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QDIALWRAPPER_H

