/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QFONTDIALOGWRAPPER_H
#define SBK_QFONTDIALOGWRAPPER_H

#include <shiboken.h>

#include <qfontdialog.h>

namespace PySide { class DynamicQMetaObject; }

class QFontDialogWrapper : public QFontDialog
{
public:
    QFontDialogWrapper(QWidget * parent = 0);
    QFontDialogWrapper(const QFont & initial, QWidget * parent = 0);
    virtual void accept();
    inline void actionEvent_protected(QActionEvent * event) { QFontDialog::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void adjustPosition_protected(QWidget * arg__1) { QFontDialog::adjustPosition(arg__1); }
    inline void changeEvent_protected(QEvent * event) { QFontDialog::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QFontDialog::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * arg__1) { QFontDialog::closeEvent(arg__1); }
    virtual void closeEvent(QCloseEvent * arg__1);
    inline void connectNotify_protected(const char * signal) { QFontDialog::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QFontDialog::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void customEvent_protected(QEvent * arg__1) { QFontDialog::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QFontDialog::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QFontDialog::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void done_protected(int result) { QFontDialog::done(result); }
    virtual void done(int result);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QFontDialog::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QFontDialog::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QFontDialog::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QFontDialog::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QFontDialog::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QFontDialog::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    inline void focusInEvent_protected(QFocusEvent * event) { QFontDialog::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QFontDialog::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QFontDialog::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QFontDialog::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QFontDialog::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QFontDialog::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QFontDialog::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * arg__1) { QFontDialog::keyPressEvent(arg__1); }
    virtual void keyPressEvent(QKeyEvent * arg__1);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QFontDialog::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QFontDialog::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QFontDialog::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QFontDialog::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QFontDialog::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QFontDialog::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QFontDialog::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QFontDialog::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline void moveEvent_protected(QMoveEvent * event) { QFontDialog::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * event) { QFontDialog::paintEvent(event); }
    virtual void paintEvent(QPaintEvent * event);
    virtual void reject();
    inline void resetInputContext_protected() { QFontDialog::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * arg__1) { QFontDialog::resizeEvent(arg__1); }
    virtual void resizeEvent(QResizeEvent * arg__1);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * arg__1) { QFontDialog::showEvent(arg__1); }
    virtual void showEvent(QShowEvent * arg__1);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QFontDialog::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QFontDialog::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QFontDialog::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QFontDialog::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QFontDialog::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QFontDialogWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QFONTDIALOGWRAPPER_H

