/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QGRAPHICSITEMGROUPWRAPPER_H
#define SBK_QGRAPHICSITEMGROUPWRAPPER_H

#include <shiboken.h>

#include <qgraphicsitem.h>

class QGraphicsItemGroupWrapper : public QGraphicsItemGroup
{
public:
    QGraphicsItemGroupWrapper(QGraphicsItem * parent = 0, QGraphicsScene * scene = 0);
    inline void addToIndex_protected() { QGraphicsItemGroup::addToIndex(); }
    virtual void advance(int phase);
    virtual QRectF boundingRect() const;
    virtual bool collidesWithItem(const QGraphicsItem * other, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    virtual bool collidesWithPath(const QPainterPath & path, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    virtual bool contains(const QPointF & point) const;
    inline void contextMenuEvent_protected(QGraphicsSceneContextMenuEvent * event) { QGraphicsItemGroup::contextMenuEvent(event); }
    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent * event);
    inline void dragEnterEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsItemGroup::dragEnterEvent(event); }
    virtual void dragEnterEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragLeaveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsItemGroup::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragMoveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsItemGroup::dragMoveEvent(event); }
    virtual void dragMoveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dropEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsItemGroup::dropEvent(event); }
    virtual void dropEvent(QGraphicsSceneDragDropEvent * event);
    inline QVariant extension_protected(const QVariant & variant) const { return QGraphicsItemGroup::extension(variant); }
    virtual QVariant extension(const QVariant & variant) const;
    inline void focusInEvent_protected(QFocusEvent * event) { QGraphicsItemGroup::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline void focusOutEvent_protected(QFocusEvent * event) { QGraphicsItemGroup::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline void hoverEnterEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsItemGroup::hoverEnterEvent(event); }
    virtual void hoverEnterEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverLeaveEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsItemGroup::hoverLeaveEvent(event); }
    virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverMoveEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsItemGroup::hoverMoveEvent(event); }
    virtual void hoverMoveEvent(QGraphicsSceneHoverEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QGraphicsItemGroup::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    inline QVariant inputMethodQuery_protected(int query) const { return QGraphicsItemGroup::inputMethodQuery(Qt::InputMethodQuery(query)); }
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    virtual bool isObscuredBy(const QGraphicsItem * item) const;
    inline QVariant itemChange_protected(int change, const QVariant & value) { return QGraphicsItemGroup::itemChange(QGraphicsItem::GraphicsItemChange(change), value); }
    virtual QVariant itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant & value);
    inline void keyPressEvent_protected(QKeyEvent * event) { QGraphicsItemGroup::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QGraphicsItemGroup::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void mouseDoubleClickEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsItemGroup::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseMoveEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsItemGroup::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
    inline void mousePressEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsItemGroup::mousePressEvent(event); }
    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseReleaseEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsItemGroup::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
    virtual QPainterPath opaqueArea() const;
    virtual void paint(QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget = 0);
    inline void prepareGeometryChange_protected() { QGraphicsItemGroup::prepareGeometryChange(); }
    inline void removeFromIndex_protected() { QGraphicsItemGroup::removeFromIndex(); }
    inline bool sceneEvent_protected(QEvent * event) { return QGraphicsItemGroup::sceneEvent(event); }
    virtual bool sceneEvent(QEvent * event);
    inline bool sceneEventFilter_protected(QGraphicsItem * watched, QEvent * event) { return QGraphicsItemGroup::sceneEventFilter(watched, event); }
    virtual bool sceneEventFilter(QGraphicsItem * watched, QEvent * event);
    virtual QPainterPath shape() const;
    virtual int type() const;
    inline void updateMicroFocus_protected() { QGraphicsItemGroup::updateMicroFocus(); }
    inline void wheelEvent_protected(QGraphicsSceneWheelEvent * event) { QGraphicsItemGroup::wheelEvent(event); }
    virtual void wheelEvent(QGraphicsSceneWheelEvent * event);
    virtual ~QGraphicsItemGroupWrapper();
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QGRAPHICSITEMGROUPWRAPPER_H

