/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QGRAPHICSPROXYWIDGETWRAPPER_H
#define SBK_QGRAPHICSPROXYWIDGETWRAPPER_H

#include <shiboken.h>

#include <qgraphicsproxywidget.h>

namespace PySide { class DynamicQMetaObject; }

class QGraphicsProxyWidgetWrapper : public QGraphicsProxyWidget
{
public:
    QGraphicsProxyWidgetWrapper(QGraphicsItem * parent = 0, QFlags<Qt::WindowType> wFlags = 0);
    virtual void advance(int phase);
    virtual QRectF boundingRect() const;
    inline void changeEvent_protected(QEvent * event) { QGraphicsProxyWidget::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QGraphicsProxyWidget::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QGraphicsProxyWidget::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    virtual bool collidesWithItem(const QGraphicsItem * other, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    virtual bool collidesWithPath(const QPainterPath & path, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    inline void connectNotify_protected(const char * signal) { QGraphicsProxyWidget::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    virtual bool contains(const QPointF & point) const;
    inline void contextMenuEvent_protected(QGraphicsSceneContextMenuEvent * event) { QGraphicsProxyWidget::contextMenuEvent(event); }
    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QGraphicsProxyWidget::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QGraphicsProxyWidget::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsProxyWidget::dragEnterEvent(event); }
    virtual void dragEnterEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragLeaveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsProxyWidget::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragMoveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsProxyWidget::dragMoveEvent(event); }
    virtual void dragMoveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dropEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsProxyWidget::dropEvent(event); }
    virtual void dropEvent(QGraphicsSceneDragDropEvent * event);
    inline bool event_protected(QEvent * event) { return QGraphicsProxyWidget::event(event); }
    virtual bool event(QEvent * event);
    inline bool eventFilter_protected(QObject * object, QEvent * event) { return QGraphicsProxyWidget::eventFilter(object, event); }
    virtual bool eventFilter(QObject * object, QEvent * event);
    inline QVariant extension_protected(const QVariant & variant) const { return QGraphicsProxyWidget::extension(variant); }
    virtual QVariant extension(const QVariant & variant) const;
    inline void focusInEvent_protected(QFocusEvent * event) { QGraphicsProxyWidget::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextPrevChild_protected(bool next) { return QGraphicsProxyWidget::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QGraphicsProxyWidget::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    virtual void getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const;
    inline void grabKeyboardEvent_protected(QEvent * event) { QGraphicsProxyWidget::grabKeyboardEvent(event); }
    virtual void grabKeyboardEvent(QEvent * event);
    inline void grabMouseEvent_protected(QEvent * event) { QGraphicsProxyWidget::grabMouseEvent(event); }
    virtual void grabMouseEvent(QEvent * event);
    inline void hideEvent_protected(QHideEvent * event) { QGraphicsProxyWidget::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void hoverEnterEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsProxyWidget::hoverEnterEvent(event); }
    virtual void hoverEnterEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverLeaveEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsProxyWidget::hoverLeaveEvent(event); }
    virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverMoveEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsProxyWidget::hoverMoveEvent(event); }
    virtual void hoverMoveEvent(QGraphicsSceneHoverEvent * event);
    inline void initStyleOption_protected(QStyleOption * option) const { QGraphicsProxyWidget::initStyleOption(option); }
    virtual void initStyleOption(QStyleOption * option) const;
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QGraphicsProxyWidget::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    inline QVariant inputMethodQuery_protected(int query) const { return QGraphicsProxyWidget::inputMethodQuery(Qt::InputMethodQuery(query)); }
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    virtual bool isObscuredBy(const QGraphicsItem * item) const;
    inline QVariant itemChange_protected(int change, const QVariant & value) { return QGraphicsProxyWidget::itemChange(QGraphicsItem::GraphicsItemChange(change), value); }
    virtual QVariant itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant & value);
    inline void keyPressEvent_protected(QKeyEvent * event) { QGraphicsProxyWidget::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QGraphicsProxyWidget::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline void mouseDoubleClickEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsProxyWidget::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseMoveEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsProxyWidget::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
    inline void mousePressEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsProxyWidget::mousePressEvent(event); }
    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseReleaseEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsProxyWidget::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
    inline void moveEvent_protected(QGraphicsSceneMoveEvent * event) { QGraphicsProxyWidget::moveEvent(event); }
    virtual void moveEvent(QGraphicsSceneMoveEvent * event);
    inline QGraphicsProxyWidget * newProxyWidget_protected(const QWidget * arg__1) { return QGraphicsProxyWidget::newProxyWidget(arg__1); }
    virtual QPainterPath opaqueArea() const;
    virtual void paint(QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget);
    virtual void paintWindowFrame(QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget = 0);
    inline void polishEvent_protected() { QGraphicsProxyWidget::polishEvent(); }
    virtual void polishEvent();
    inline QVariant propertyChange_protected(const QString & propertyName, const QVariant & value) { return QGraphicsProxyWidget::propertyChange(propertyName, value); }
    virtual QVariant propertyChange(const QString & propertyName, const QVariant & value);
    inline void resizeEvent_protected(QGraphicsSceneResizeEvent * event) { QGraphicsProxyWidget::resizeEvent(event); }
    virtual void resizeEvent(QGraphicsSceneResizeEvent * event);
    inline bool sceneEvent_protected(QEvent * event) { return QGraphicsProxyWidget::sceneEvent(event); }
    virtual bool sceneEvent(QEvent * event);
    inline bool sceneEventFilter_protected(QGraphicsItem * watched, QEvent * event) { return QGraphicsProxyWidget::sceneEventFilter(watched, event); }
    virtual bool sceneEventFilter(QGraphicsItem * watched, QEvent * event);
    virtual void setGeometry(const QRectF & rect);
    inline void setGraphicsItem_protected(QGraphicsItem * item) { QGraphicsProxyWidget::setGraphicsItem(item); }
    inline void setOwnedByLayout_protected(bool ownedByLayout) { QGraphicsProxyWidget::setOwnedByLayout(ownedByLayout); }
    virtual QPainterPath shape() const;
    inline void showEvent_protected(QShowEvent * event) { QGraphicsProxyWidget::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    inline QSizeF sizeHint_protected(int which, const QSizeF & constraint = QSizeF()) const { return QGraphicsProxyWidget::sizeHint(Qt::SizeHint(which), constraint); }
    virtual QSizeF sizeHint(Qt::SizeHint which, const QSizeF & constraint = QSizeF()) const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QGraphicsProxyWidget::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual int type() const;
    inline void ungrabKeyboardEvent_protected(QEvent * event) { QGraphicsProxyWidget::ungrabKeyboardEvent(event); }
    virtual void ungrabKeyboardEvent(QEvent * event);
    inline void ungrabMouseEvent_protected(QEvent * event) { QGraphicsProxyWidget::ungrabMouseEvent(event); }
    virtual void ungrabMouseEvent(QEvent * event);
    inline void updateGeometry_protected() { QGraphicsProxyWidget::updateGeometry(); }
    virtual void updateGeometry();
    inline void wheelEvent_protected(QGraphicsSceneWheelEvent * event) { QGraphicsProxyWidget::wheelEvent(event); }
    virtual void wheelEvent(QGraphicsSceneWheelEvent * event);
    inline bool windowFrameEvent_protected(QEvent * e) { return QGraphicsProxyWidget::windowFrameEvent(e); }
    virtual bool windowFrameEvent(QEvent * e);
    inline int windowFrameSectionAt_protected(const QPointF & pos) const { return QGraphicsProxyWidget::windowFrameSectionAt(pos); }
    virtual Qt::WindowFrameSection windowFrameSectionAt(const QPointF & pos) const;
    virtual ~QGraphicsProxyWidgetWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QGRAPHICSPROXYWIDGETWRAPPER_H

