/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QGRAPHICSSCENEWRAPPER_H
#define SBK_QGRAPHICSSCENEWRAPPER_H

#include <shiboken.h>

#include <qgraphicsscene.h>

namespace PySide { class DynamicQMetaObject; }

class QGraphicsSceneWrapper : public QGraphicsScene
{
public:
    QGraphicsSceneWrapper(QObject * parent = 0);
    QGraphicsSceneWrapper(const QRectF & sceneRect, QObject * parent = 0);
    QGraphicsSceneWrapper(qreal x, qreal y, qreal width, qreal height, QObject * parent = 0);
    inline void childEvent_protected(QChildEvent * arg__1) { QGraphicsScene::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void connectNotify_protected(const char * signal) { QGraphicsScene::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QGraphicsSceneContextMenuEvent * event) { QGraphicsScene::contextMenuEvent(event); }
    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QGraphicsScene::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QGraphicsScene::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsScene::dragEnterEvent(event); }
    virtual void dragEnterEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragLeaveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsScene::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragMoveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsScene::dragMoveEvent(event); }
    virtual void dragMoveEvent(QGraphicsSceneDragDropEvent * event);
    inline void drawBackground_protected(QPainter * painter, const QRectF & rect) { QGraphicsScene::drawBackground(painter, rect); }
    virtual void drawBackground(QPainter * painter, const QRectF & rect);
    inline void drawForeground_protected(QPainter * painter, const QRectF & rect) { QGraphicsScene::drawForeground(painter, rect); }
    virtual void drawForeground(QPainter * painter, const QRectF & rect);
    inline void drawItems_protected(QPainter * painter, int numItems, QGraphicsItem ** items, const QStyleOptionGraphicsItem * options, QWidget * widget = 0) { QGraphicsScene::drawItems(painter, numItems, items, options, widget); }
    inline void dropEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsScene::dropEvent(event); }
    virtual void dropEvent(QGraphicsSceneDragDropEvent * event);
    inline bool event_protected(QEvent * event) { return QGraphicsScene::event(event); }
    virtual bool event(QEvent * event);
    inline bool eventFilter_protected(QObject * watched, QEvent * event) { return QGraphicsScene::eventFilter(watched, event); }
    virtual bool eventFilter(QObject * watched, QEvent * event);
    inline void focusInEvent_protected(QFocusEvent * event) { QGraphicsScene::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextPrevChild_protected(bool next) { return QGraphicsScene::focusNextPrevChild(next); }
    inline void focusOutEvent_protected(QFocusEvent * event) { QGraphicsScene::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline void helpEvent_protected(QGraphicsSceneHelpEvent * event) { QGraphicsScene::helpEvent(event); }
    virtual void helpEvent(QGraphicsSceneHelpEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QGraphicsScene::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QGraphicsScene::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QGraphicsScene::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline void mouseDoubleClickEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsScene::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseMoveEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsScene::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
    inline void mousePressEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsScene::mousePressEvent(event); }
    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseReleaseEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsScene::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
    inline int receivers_protected(const char * signal) const { return QGraphicsScene::receivers(signal); }
    inline QObject * sender_protected() const { return QGraphicsScene::sender(); }
    inline int senderSignalIndex_protected() const { return QGraphicsScene::senderSignalIndex(); }
    inline void timerEvent_protected(QTimerEvent * arg__1) { QGraphicsScene::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void wheelEvent_protected(QGraphicsSceneWheelEvent * event) { QGraphicsScene::wheelEvent(event); }
    virtual void wheelEvent(QGraphicsSceneWheelEvent * event);
    virtual ~QGraphicsSceneWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QGRAPHICSSCENEWRAPPER_H

