/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QGRAPHICSTEXTITEMWRAPPER_H
#define SBK_QGRAPHICSTEXTITEMWRAPPER_H

#include <shiboken.h>

#include <qgraphicsitem.h>

namespace PySide { class DynamicQMetaObject; }

class QGraphicsTextItemWrapper : public QGraphicsTextItem
{
public:
    QGraphicsTextItemWrapper(QGraphicsItem * parent = 0, QGraphicsScene * scene = 0);
    QGraphicsTextItemWrapper(const QString & text, QGraphicsItem * parent = 0, QGraphicsScene * scene = 0);
    inline void addToIndex_protected() { QGraphicsTextItem::addToIndex(); }
    virtual void advance(int phase);
    virtual QRectF boundingRect() const;
    inline void childEvent_protected(QChildEvent * arg__1) { QGraphicsTextItem::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual bool collidesWithItem(const QGraphicsItem * other, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    virtual bool collidesWithPath(const QPainterPath & path, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    inline void connectNotify_protected(const char * signal) { QGraphicsTextItem::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    virtual bool contains(const QPointF & point) const;
    inline void contextMenuEvent_protected(QGraphicsSceneContextMenuEvent * event) { QGraphicsTextItem::contextMenuEvent(event); }
    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QGraphicsTextItem::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QGraphicsTextItem::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsTextItem::dragEnterEvent(event); }
    virtual void dragEnterEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragLeaveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsTextItem::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragMoveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsTextItem::dragMoveEvent(event); }
    virtual void dragMoveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dropEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsTextItem::dropEvent(event); }
    virtual void dropEvent(QGraphicsSceneDragDropEvent * event);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline QVariant extension_protected(const QVariant & variant) const { return QGraphicsTextItem::extension(variant); }
    virtual QVariant extension(const QVariant & variant) const;
    inline void focusInEvent_protected(QFocusEvent * event) { QGraphicsTextItem::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline void focusOutEvent_protected(QFocusEvent * event) { QGraphicsTextItem::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline void hoverEnterEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsTextItem::hoverEnterEvent(event); }
    virtual void hoverEnterEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverLeaveEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsTextItem::hoverLeaveEvent(event); }
    virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverMoveEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsTextItem::hoverMoveEvent(event); }
    virtual void hoverMoveEvent(QGraphicsSceneHoverEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QGraphicsTextItem::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    inline QVariant inputMethodQuery_protected(int query) const { return QGraphicsTextItem::inputMethodQuery(Qt::InputMethodQuery(query)); }
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    virtual bool isObscuredBy(const QGraphicsItem * item) const;
    inline QVariant itemChange_protected(int change, const QVariant & value) { return QGraphicsTextItem::itemChange(QGraphicsItem::GraphicsItemChange(change), value); }
    virtual QVariant itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant & value);
    inline void keyPressEvent_protected(QKeyEvent * event) { QGraphicsTextItem::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QGraphicsTextItem::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline void mouseDoubleClickEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsTextItem::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseMoveEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsTextItem::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
    inline void mousePressEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsTextItem::mousePressEvent(event); }
    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseReleaseEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsTextItem::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
    virtual QPainterPath opaqueArea() const;
    virtual void paint(QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget);
    inline void prepareGeometryChange_protected() { QGraphicsTextItem::prepareGeometryChange(); }
    inline void removeFromIndex_protected() { QGraphicsTextItem::removeFromIndex(); }
    inline bool sceneEvent_protected(QEvent * event) { return QGraphicsTextItem::sceneEvent(event); }
    virtual bool sceneEvent(QEvent * event);
    inline bool sceneEventFilter_protected(QGraphicsItem * watched, QEvent * event) { return QGraphicsTextItem::sceneEventFilter(watched, event); }
    virtual bool sceneEventFilter(QGraphicsItem * watched, QEvent * event);
    inline void setExtension_protected(int extension, const QVariant & variant) { QGraphicsTextItem::setExtension(QGraphicsItem::Extension(extension), variant); }
    virtual QPainterPath shape() const;
    inline bool supportsExtension_protected(int extension) const { return QGraphicsTextItem::supportsExtension(QGraphicsItem::Extension(extension)); }
    inline void timerEvent_protected(QTimerEvent * arg__1) { QGraphicsTextItem::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual int type() const;
    inline void updateMicroFocus_protected() { QGraphicsTextItem::updateMicroFocus(); }
    inline void wheelEvent_protected(QGraphicsSceneWheelEvent * event) { QGraphicsTextItem::wheelEvent(event); }
    virtual void wheelEvent(QGraphicsSceneWheelEvent * event);
    virtual ~QGraphicsTextItemWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QGRAPHICSTEXTITEMWRAPPER_H

