/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QHEADERVIEWWRAPPER_H
#define SBK_QHEADERVIEWWRAPPER_H

#include <shiboken.h>

#include <qheaderview.h>

namespace PySide { class DynamicQMetaObject; }

class QHeaderViewWrapper : public QHeaderView
{
public:
    QHeaderViewWrapper(Qt::Orientation orientation, QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QHeaderView::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QHeaderView::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QHeaderView::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEditor_protected(QWidget * editor, int hint) { QHeaderView::closeEditor(editor, QAbstractItemDelegate::EndEditHint(hint)); }
    virtual void closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint);
    inline void closeEvent_protected(QCloseEvent * event) { QHeaderView::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void commitData_protected(QWidget * editor) { QHeaderView::commitData(editor); }
    virtual void commitData(QWidget * editor);
    inline void connectNotify_protected(const char * signal) { QHeaderView::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QHeaderView::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void currentChanged_protected(const QModelIndex & current, const QModelIndex & old) { QHeaderView::currentChanged(current, old); }
    virtual void currentChanged(const QModelIndex & current, const QModelIndex & old);
    inline void customEvent_protected(QEvent * arg__1) { QHeaderView::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void dataChanged_protected(const QModelIndex & topLeft, const QModelIndex & bottomRight) { QHeaderView::dataChanged(topLeft, bottomRight); }
    virtual void dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QHeaderView::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline QPoint dirtyRegionOffset_protected() const { return QHeaderView::dirtyRegionOffset(); }
    inline void disconnectNotify_protected(const char * signal) { QHeaderView::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void doAutoScroll_protected() { QHeaderView::doAutoScroll(); }
    virtual void doItemsLayout();
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QHeaderView::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QHeaderView::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QHeaderView::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void drawFrame_protected(QPainter * arg__1) { QHeaderView::drawFrame(arg__1); }
    inline void dropEvent_protected(QDropEvent * event) { QHeaderView::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline int dropIndicatorPosition_protected() const { return QHeaderView::dropIndicatorPosition(); }
    inline bool edit_protected(const QModelIndex & index, int trigger, QEvent * event) { return QHeaderView::edit(index, QAbstractItemView::EditTrigger(trigger), event); }
    virtual bool edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event);
    inline void editorDestroyed_protected(QObject * editor) { QHeaderView::editorDestroyed(editor); }
    virtual void editorDestroyed(QObject * editor);
    inline void enterEvent_protected(QEvent * event) { QHeaderView::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QHeaderView::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void executeDelayedItemsLayout_protected() { QHeaderView::executeDelayedItemsLayout(); }
    inline void focusInEvent_protected(QFocusEvent * event) { QHeaderView::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QHeaderView::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QHeaderView::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QHeaderView::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QHeaderView::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QHeaderView::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline int horizontalOffset_protected() const { return QHeaderView::horizontalOffset(); }
    virtual int horizontalOffset() const;
    inline void horizontalScrollbarAction_protected(int action) { QHeaderView::horizontalScrollbarAction(action); }
    virtual void horizontalScrollbarAction(int action);
    inline void horizontalScrollbarValueChanged_protected(int value) { QHeaderView::horizontalScrollbarValueChanged(value); }
    virtual void horizontalScrollbarValueChanged(int value);
    inline QModelIndex indexAt_protected(const QPoint & p) const { return QHeaderView::indexAt(p); }
    virtual QModelIndex indexAt(const QPoint & p) const;
    inline void initStyleOption_protected(QStyleOptionHeader * option) const { QHeaderView::initStyleOption(option); }
    inline void initialize_protected() { QHeaderView::initialize(); }
    inline void initializeSections_protected() { QHeaderView::initializeSections(); }
    inline void initializeSections_protected(int start, int end) { QHeaderView::initializeSections(start, end); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QHeaderView::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline bool isIndexHidden_protected(const QModelIndex & index) const { return QHeaderView::isIndexHidden(index); }
    virtual bool isIndexHidden(const QModelIndex & index) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QHeaderView::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QHeaderView::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual void keyboardSearch(const QString & search);
    inline void languageChange_protected() { QHeaderView::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QHeaderView::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QHeaderView::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * e) { QHeaderView::mouseDoubleClickEvent(e); }
    virtual void mouseDoubleClickEvent(QMouseEvent * e);
    inline void mouseMoveEvent_protected(QMouseEvent * e) { QHeaderView::mouseMoveEvent(e); }
    virtual void mouseMoveEvent(QMouseEvent * e);
    inline void mousePressEvent_protected(QMouseEvent * e) { QHeaderView::mousePressEvent(e); }
    virtual void mousePressEvent(QMouseEvent * e);
    inline void mouseReleaseEvent_protected(QMouseEvent * e) { QHeaderView::mouseReleaseEvent(e); }
    virtual void mouseReleaseEvent(QMouseEvent * e);
    inline QModelIndex moveCursor_protected(int arg__1, int arg__2) { return QHeaderView::moveCursor(QAbstractItemView::CursorAction(arg__1), QFlags<Qt::KeyboardModifier>(arg__2)); }
    virtual QModelIndex moveCursor(QAbstractItemView::CursorAction arg__1, QFlags<Qt::KeyboardModifier> arg__2);
    inline void moveEvent_protected(QMoveEvent * event) { QHeaderView::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * e) { QHeaderView::paintEvent(e); }
    virtual void paintEvent(QPaintEvent * e);
    inline void paintSection_protected(QPainter * painter, const QRect & rect, int logicalIndex) const { QHeaderView::paintSection(painter, rect, logicalIndex); }
    virtual void paintSection(QPainter * painter, const QRect & rect, int logicalIndex) const;
    virtual void reset();
    inline void resetInputContext_protected() { QHeaderView::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QHeaderView::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    inline void resizeSections_protected() { QHeaderView::resizeSections(); }
    inline void rowsAboutToBeRemoved_protected(const QModelIndex & parent, int start, int end) { QHeaderView::rowsAboutToBeRemoved(parent, start, end); }
    virtual void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end);
    inline void rowsInserted_protected(const QModelIndex & parent, int start, int end) { QHeaderView::rowsInserted(parent, start, end); }
    virtual void rowsInserted(const QModelIndex & parent, int start, int end);
    inline void scheduleDelayedItemsLayout_protected() { QHeaderView::scheduleDelayedItemsLayout(); }
    inline void scrollContentsBy_protected(int dx, int dy) { QHeaderView::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void scrollDirtyRegion_protected(int dx, int dy) { QHeaderView::scrollDirtyRegion(dx, dy); }
    inline void scrollTo_protected(const QModelIndex & index, int hint) { QHeaderView::scrollTo(index, QAbstractItemView::ScrollHint(hint)); }
    virtual void scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint);
    inline QSize sectionSizeFromContents_protected(int logicalIndex) const { return QHeaderView::sectionSizeFromContents(logicalIndex); }
    virtual QSize sectionSizeFromContents(int logicalIndex) const;
    inline void sectionsAboutToBeRemoved_protected(const QModelIndex & parent, int logicalFirst, int logicalLast) { QHeaderView::sectionsAboutToBeRemoved(parent, logicalFirst, logicalLast); }
    inline void sectionsInserted_protected(const QModelIndex & parent, int logicalFirst, int logicalLast) { QHeaderView::sectionsInserted(parent, logicalFirst, logicalLast); }
    virtual void selectAll();
    inline QModelIndexList selectedIndexes_protected() const { return QHeaderView::selectedIndexes(); }
    virtual QModelIndexList selectedIndexes() const;
    inline void selectionChanged_protected(const QItemSelection & selected, const QItemSelection & deselected) { QHeaderView::selectionChanged(selected, deselected); }
    virtual void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
    inline int selectionCommand_protected(const QModelIndex & index, const QEvent * event = 0) const { return QHeaderView::selectionCommand(index, event); }
    virtual QFlags<QItemSelectionModel::SelectionFlag> selectionCommand(const QModelIndex & index, const QEvent * event = 0) const;
    inline void setDirtyRegion_protected(const QRegion & region) { QHeaderView::setDirtyRegion(region); }
    virtual void setModel(QAbstractItemModel * model);
    virtual void setRootIndex(const QModelIndex & index);
    inline void setSelection_protected(const QRect & rect, int flags) { QHeaderView::setSelection(rect, QFlags<QItemSelectionModel::SelectionFlag>(flags)); }
    virtual void setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> flags);
    virtual void setSelectionModel(QItemSelectionModel * selectionModel);
    inline void setState_protected(int state) { QHeaderView::setState(QAbstractItemView::State(state)); }
    inline void setViewportMargins_protected(const QMargins & margins) { QHeaderView::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QHeaderView::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QHeaderView::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * event) { QHeaderView::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    virtual int sizeHintForColumn(int column) const;
    virtual int sizeHintForRow(int row) const;
    inline void startAutoScroll_protected() { QHeaderView::startAutoScroll(); }
    inline void startDrag_protected(int supportedActions) { QHeaderView::startDrag(QFlags<Qt::DropAction>(supportedActions)); }
    virtual void startDrag(QFlags<Qt::DropAction> supportedActions);
    inline int state_protected() const { return QHeaderView::state(); }
    inline void stopAutoScroll_protected() { QHeaderView::stopAutoScroll(); }
    inline void tabletEvent_protected(QTabletEvent * event) { QHeaderView::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * event) { QHeaderView::timerEvent(event); }
    virtual void timerEvent(QTimerEvent * event);
    inline void updateEditorData_protected() { QHeaderView::updateEditorData(); }
    virtual void updateEditorData();
    inline void updateEditorGeometries_protected() { QHeaderView::updateEditorGeometries(); }
    virtual void updateEditorGeometries();
    inline void updateGeometries_protected() { QHeaderView::updateGeometries(); }
    virtual void updateGeometries();
    inline void updateMicroFocus_protected() { QHeaderView::updateMicroFocus(); }
    inline void updateSection_protected(int logicalIndex) { QHeaderView::updateSection(logicalIndex); }
    inline int verticalOffset_protected() const { return QHeaderView::verticalOffset(); }
    virtual int verticalOffset() const;
    inline void verticalScrollbarAction_protected(int action) { QHeaderView::verticalScrollbarAction(action); }
    virtual void verticalScrollbarAction(int action);
    inline void verticalScrollbarValueChanged_protected(int value) { QHeaderView::verticalScrollbarValueChanged(value); }
    virtual void verticalScrollbarValueChanged(int value);
    inline QStyleOptionViewItem viewOptions_protected() const { return QHeaderView::viewOptions(); }
    virtual QStyleOptionViewItem viewOptions() const;
    inline bool viewportEvent_protected(QEvent * e) { return QHeaderView::viewportEvent(e); }
    virtual bool viewportEvent(QEvent * e);
    inline QRect visualRect_protected(const QModelIndex & index) const { return QHeaderView::visualRect(index); }
    virtual QRect visualRect(const QModelIndex & index) const;
    inline QRegion visualRegionForSelection_protected(const QItemSelection & selection) const { return QHeaderView::visualRegionForSelection(selection); }
    virtual QRegion visualRegionForSelection(const QItemSelection & selection) const;
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QHeaderView::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QHeaderView::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QHeaderViewWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    // Inherited overloads, because the using keyword sux
    inline void edit(const QModelIndex & index) { QHeaderView::edit(index); }
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QHEADERVIEWWRAPPER_H

