/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QITEMDELEGATEWRAPPER_H
#define SBK_QITEMDELEGATEWRAPPER_H

#include <shiboken.h>

#include <qitemdelegate.h>

namespace PySide { class DynamicQMetaObject; }

class QItemDelegateWrapper : public QItemDelegate
{
public:
    QItemDelegateWrapper(QObject * parent = 0);
    inline QRect check_protected(const QStyleOptionViewItem & option, const QRect & bounding, const QVariant & variant) const { return QItemDelegate::check(option, bounding, variant); }
    inline void childEvent_protected(QChildEvent * arg__1) { QItemDelegate::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void connectNotify_protected(const char * signal) { QItemDelegate::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    virtual QWidget * createEditor(QWidget * parent, const QStyleOptionViewItem & option, const QModelIndex & index) const;
    inline void customEvent_protected(QEvent * arg__1) { QItemDelegate::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline QPixmap decoration_protected(const QStyleOptionViewItem & option, const QVariant & variant) const { return QItemDelegate::decoration(option, variant); }
    inline void disconnectNotify_protected(const char * signal) { QItemDelegate::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void doLayout_protected(const QStyleOptionViewItem & option, QRect * checkRect, QRect * iconRect, QRect * textRect, bool hint) const { QItemDelegate::doLayout(option, checkRect, iconRect, textRect, hint); }
    inline void drawBackground_protected(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const { QItemDelegate::drawBackground(painter, option, index); }
    inline void drawCheck_protected(QPainter * painter, const QStyleOptionViewItem & option, const QRect & rect, int state) const { QItemDelegate::drawCheck(painter, option, rect, Qt::CheckState(state)); }
    virtual void drawCheck(QPainter * painter, const QStyleOptionViewItem & option, const QRect & rect, Qt::CheckState state) const;
    inline void drawDecoration_protected(QPainter * painter, const QStyleOptionViewItem & option, const QRect & rect, const QPixmap & pixmap) const { QItemDelegate::drawDecoration(painter, option, rect, pixmap); }
    virtual void drawDecoration(QPainter * painter, const QStyleOptionViewItem & option, const QRect & rect, const QPixmap & pixmap) const;
    inline void drawDisplay_protected(QPainter * painter, const QStyleOptionViewItem & option, const QRect & rect, const QString & text) const { QItemDelegate::drawDisplay(painter, option, rect, text); }
    virtual void drawDisplay(QPainter * painter, const QStyleOptionViewItem & option, const QRect & rect, const QString & text) const;
    inline void drawFocus_protected(QPainter * painter, const QStyleOptionViewItem & option, const QRect & rect) const { QItemDelegate::drawFocus(painter, option, rect); }
    virtual void drawFocus(QPainter * painter, const QStyleOptionViewItem & option, const QRect & rect) const;
    inline bool editorEvent_protected(QEvent * event, QAbstractItemModel * model, const QStyleOptionViewItem & option, const QModelIndex & index) { return QItemDelegate::editorEvent(event, model, option, index); }
    virtual bool editorEvent(QEvent * event, QAbstractItemModel * model, const QStyleOptionViewItem & option, const QModelIndex & index);
    virtual bool event(QEvent * arg__1);
    inline bool eventFilter_protected(QObject * object, QEvent * event) { return QItemDelegate::eventFilter(object, event); }
    virtual bool eventFilter(QObject * object, QEvent * event);
    virtual const QMetaObject * metaObject() const;
    virtual void paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const;
    inline int receivers_protected(const char * signal) const { return QItemDelegate::receivers(signal); }
    inline QRect rect_protected(const QStyleOptionViewItem & option, const QModelIndex & index, int role) const { return QItemDelegate::rect(option, index, role); }
    inline QPixmap * selected_protected(const QPixmap & pixmap, const QPalette & palette, bool enabled) const { return QItemDelegate::selected(pixmap, palette, enabled); }
    inline QObject * sender_protected() const { return QItemDelegate::sender(); }
    inline int senderSignalIndex_protected() const { return QItemDelegate::senderSignalIndex(); }
    virtual void setEditorData(QWidget * editor, const QModelIndex & index) const;
    virtual void setModelData(QWidget * editor, QAbstractItemModel * model, const QModelIndex & index) const;
    inline QStyleOptionViewItem setOptions_protected(const QModelIndex & index, const QStyleOptionViewItem & option) const { return QItemDelegate::setOptions(index, option); }
    virtual QSize sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const;
    inline QRect textRectangle_protected(QPainter * painter, const QRect & rect, const QFont & font, const QString & text) const { return QItemDelegate::textRectangle(painter, rect, font, text); }
    inline void timerEvent_protected(QTimerEvent * arg__1) { QItemDelegate::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual void updateEditorGeometry(QWidget * editor, const QStyleOptionViewItem & option, const QModelIndex & index) const;
    virtual ~QItemDelegateWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QITEMDELEGATEWRAPPER_H

