/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QLINEEDITWRAPPER_H
#define SBK_QLINEEDITWRAPPER_H

#include <shiboken.h>

#include <qlineedit.h>

namespace PySide { class DynamicQMetaObject; }

class QLineEditWrapper : public QLineEdit
{
public:
    QLineEditWrapper(QWidget * parent = 0);
    QLineEditWrapper(const QString & arg__1, QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QLineEdit::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QLineEdit::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QLineEdit::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QLineEdit::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QLineEdit::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QLineEdit::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline QRect cursorRect_protected() const { return QLineEdit::cursorRect(); }
    inline void customEvent_protected(QEvent * arg__1) { QLineEdit::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QLineEdit::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QLineEdit::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * arg__1) { QLineEdit::dragEnterEvent(arg__1); }
    virtual void dragEnterEvent(QDragEnterEvent * arg__1);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * e) { QLineEdit::dragLeaveEvent(e); }
    virtual void dragLeaveEvent(QDragLeaveEvent * e);
    inline void dragMoveEvent_protected(QDragMoveEvent * e) { QLineEdit::dragMoveEvent(e); }
    virtual void dragMoveEvent(QDragMoveEvent * e);
    inline void dropEvent_protected(QDropEvent * arg__1) { QLineEdit::dropEvent(arg__1); }
    virtual void dropEvent(QDropEvent * arg__1);
    inline void enterEvent_protected(QEvent * event) { QLineEdit::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * arg__1) { QLineEdit::focusInEvent(arg__1); }
    virtual void focusInEvent(QFocusEvent * arg__1);
    inline bool focusNextChild_protected() { return QLineEdit::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QLineEdit::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * arg__1) { QLineEdit::focusOutEvent(arg__1); }
    virtual void focusOutEvent(QFocusEvent * arg__1);
    inline bool focusPreviousChild_protected() { return QLineEdit::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QLineEdit::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void initStyleOption_protected(QStyleOptionFrame * option) const { QLineEdit::initStyleOption(option); }
    inline void inputMethodEvent_protected(QInputMethodEvent * arg__1) { QLineEdit::inputMethodEvent(arg__1); }
    virtual void inputMethodEvent(QInputMethodEvent * arg__1);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * arg__1) { QLineEdit::keyPressEvent(arg__1); }
    virtual void keyPressEvent(QKeyEvent * arg__1);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QLineEdit::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QLineEdit::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QLineEdit::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QLineEdit::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * arg__1) { QLineEdit::mouseDoubleClickEvent(arg__1); }
    virtual void mouseDoubleClickEvent(QMouseEvent * arg__1);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QLineEdit::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QLineEdit::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * arg__1) { QLineEdit::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QMouseEvent * arg__1);
    inline void moveEvent_protected(QMoveEvent * event) { QLineEdit::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QLineEdit::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void resetInputContext_protected() { QLineEdit::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QLineEdit::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QLineEdit::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QLineEdit::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QLineEdit::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QLineEdit::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QLineEdit::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QLineEdit::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QLineEditWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QLINEEDITWRAPPER_H

