/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QLISTVIEWWRAPPER_H
#define SBK_QLISTVIEWWRAPPER_H

#include <shiboken.h>

#include <qlistview.h>

namespace PySide { class DynamicQMetaObject; }

class QListViewWrapper : public QListView
{
public:
    QListViewWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QListView::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QListView::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QListView::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEditor_protected(QWidget * editor, int hint) { QListView::closeEditor(editor, QAbstractItemDelegate::EndEditHint(hint)); }
    virtual void closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint);
    inline void closeEvent_protected(QCloseEvent * event) { QListView::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void commitData_protected(QWidget * editor) { QListView::commitData(editor); }
    virtual void commitData(QWidget * editor);
    inline void connectNotify_protected(const char * signal) { QListView::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline QSize contentsSize_protected() const { return QListView::contentsSize(); }
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QListView::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void currentChanged_protected(const QModelIndex & current, const QModelIndex & previous) { QListView::currentChanged(current, previous); }
    virtual void currentChanged(const QModelIndex & current, const QModelIndex & previous);
    inline void customEvent_protected(QEvent * arg__1) { QListView::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void dataChanged_protected(const QModelIndex & topLeft, const QModelIndex & bottomRight) { QListView::dataChanged(topLeft, bottomRight); }
    virtual void dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QListView::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline QPoint dirtyRegionOffset_protected() const { return QListView::dirtyRegionOffset(); }
    inline void disconnectNotify_protected(const char * signal) { QListView::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void doAutoScroll_protected() { QListView::doAutoScroll(); }
    virtual void doItemsLayout();
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QListView::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * e) { QListView::dragLeaveEvent(e); }
    virtual void dragLeaveEvent(QDragLeaveEvent * e);
    inline void dragMoveEvent_protected(QDragMoveEvent * e) { QListView::dragMoveEvent(e); }
    virtual void dragMoveEvent(QDragMoveEvent * e);
    inline void drawFrame_protected(QPainter * arg__1) { QListView::drawFrame(arg__1); }
    inline void dropEvent_protected(QDropEvent * e) { QListView::dropEvent(e); }
    virtual void dropEvent(QDropEvent * e);
    inline int dropIndicatorPosition_protected() const { return QListView::dropIndicatorPosition(); }
    inline bool edit_protected(const QModelIndex & index, int trigger, QEvent * event) { return QListView::edit(index, QAbstractItemView::EditTrigger(trigger), event); }
    virtual bool edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event);
    inline void editorDestroyed_protected(QObject * editor) { QListView::editorDestroyed(editor); }
    virtual void editorDestroyed(QObject * editor);
    inline void enterEvent_protected(QEvent * event) { QListView::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QListView::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void executeDelayedItemsLayout_protected() { QListView::executeDelayedItemsLayout(); }
    inline void focusInEvent_protected(QFocusEvent * event) { QListView::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QListView::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QListView::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QListView::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QListView::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QListView::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline int horizontalOffset_protected() const { return QListView::horizontalOffset(); }
    virtual int horizontalOffset() const;
    inline void horizontalScrollbarAction_protected(int action) { QListView::horizontalScrollbarAction(action); }
    virtual void horizontalScrollbarAction(int action);
    inline void horizontalScrollbarValueChanged_protected(int value) { QListView::horizontalScrollbarValueChanged(value); }
    virtual void horizontalScrollbarValueChanged(int value);
    virtual QModelIndex indexAt(const QPoint & p) const;
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QListView::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline void internalDrag_protected(int supportedActions) { QListView::internalDrag(QFlags<Qt::DropAction>(supportedActions)); }
    inline void internalDrop_protected(QDropEvent * e) { QListView::internalDrop(e); }
    inline bool isIndexHidden_protected(const QModelIndex & index) const { return QListView::isIndexHidden(index); }
    virtual bool isIndexHidden(const QModelIndex & index) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QListView::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QListView::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual void keyboardSearch(const QString & search);
    inline void languageChange_protected() { QListView::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QListView::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QListView::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QListView::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * e) { QListView::mouseMoveEvent(e); }
    virtual void mouseMoveEvent(QMouseEvent * e);
    inline void mousePressEvent_protected(QMouseEvent * event) { QListView::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * e) { QListView::mouseReleaseEvent(e); }
    virtual void mouseReleaseEvent(QMouseEvent * e);
    inline QModelIndex moveCursor_protected(int cursorAction, int modifiers) { return QListView::moveCursor(QAbstractItemView::CursorAction(cursorAction), QFlags<Qt::KeyboardModifier>(modifiers)); }
    virtual QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction, QFlags<Qt::KeyboardModifier> modifiers);
    inline void moveEvent_protected(QMoveEvent * event) { QListView::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * e) { QListView::paintEvent(e); }
    virtual void paintEvent(QPaintEvent * e);
    inline QRect rectForIndex_protected(const QModelIndex & index) const { return QListView::rectForIndex(index); }
    virtual void reset();
    inline void resetInputContext_protected() { QListView::resetInputContext(); }
    inline void resizeContents_protected(int width, int height) { QListView::resizeContents(width, height); }
    inline void resizeEvent_protected(QResizeEvent * e) { QListView::resizeEvent(e); }
    virtual void resizeEvent(QResizeEvent * e);
    inline void rowsAboutToBeRemoved_protected(const QModelIndex & parent, int start, int end) { QListView::rowsAboutToBeRemoved(parent, start, end); }
    virtual void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end);
    inline void rowsInserted_protected(const QModelIndex & parent, int start, int end) { QListView::rowsInserted(parent, start, end); }
    virtual void rowsInserted(const QModelIndex & parent, int start, int end);
    inline void scheduleDelayedItemsLayout_protected() { QListView::scheduleDelayedItemsLayout(); }
    inline void scrollContentsBy_protected(int dx, int dy) { QListView::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void scrollDirtyRegion_protected(int dx, int dy) { QListView::scrollDirtyRegion(dx, dy); }
    virtual void scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint = EnsureVisible);
    virtual void selectAll();
    inline QModelIndexList selectedIndexes_protected() const { return QListView::selectedIndexes(); }
    virtual QModelIndexList selectedIndexes() const;
    inline void selectionChanged_protected(const QItemSelection & selected, const QItemSelection & deselected) { QListView::selectionChanged(selected, deselected); }
    virtual void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
    inline int selectionCommand_protected(const QModelIndex & index, const QEvent * event = 0) const { return QListView::selectionCommand(index, event); }
    virtual QFlags<QItemSelectionModel::SelectionFlag> selectionCommand(const QModelIndex & index, const QEvent * event = 0) const;
    inline void setDirtyRegion_protected(const QRegion & region) { QListView::setDirtyRegion(region); }
    virtual void setModel(QAbstractItemModel * model);
    inline void setPositionForIndex_protected(const QPoint & position, const QModelIndex & index) { QListView::setPositionForIndex(position, index); }
    virtual void setRootIndex(const QModelIndex & index);
    inline void setSelection_protected(const QRect & rect, int command) { QListView::setSelection(rect, QFlags<QItemSelectionModel::SelectionFlag>(command)); }
    virtual void setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command);
    virtual void setSelectionModel(QItemSelectionModel * selectionModel);
    inline void setState_protected(int state) { QListView::setState(QAbstractItemView::State(state)); }
    inline void setViewportMargins_protected(const QMargins & margins) { QListView::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QListView::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QListView::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * event) { QListView::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    virtual int sizeHintForColumn(int column) const;
    virtual int sizeHintForRow(int row) const;
    inline void startAutoScroll_protected() { QListView::startAutoScroll(); }
    inline void startDrag_protected(int supportedActions) { QListView::startDrag(QFlags<Qt::DropAction>(supportedActions)); }
    virtual void startDrag(QFlags<Qt::DropAction> supportedActions);
    inline int state_protected() const { return QListView::state(); }
    inline void stopAutoScroll_protected() { QListView::stopAutoScroll(); }
    inline void tabletEvent_protected(QTabletEvent * event) { QListView::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * e) { QListView::timerEvent(e); }
    virtual void timerEvent(QTimerEvent * e);
    inline void updateEditorData_protected() { QListView::updateEditorData(); }
    virtual void updateEditorData();
    inline void updateEditorGeometries_protected() { QListView::updateEditorGeometries(); }
    virtual void updateEditorGeometries();
    inline void updateGeometries_protected() { QListView::updateGeometries(); }
    virtual void updateGeometries();
    inline void updateMicroFocus_protected() { QListView::updateMicroFocus(); }
    inline int verticalOffset_protected() const { return QListView::verticalOffset(); }
    virtual int verticalOffset() const;
    inline void verticalScrollbarAction_protected(int action) { QListView::verticalScrollbarAction(action); }
    virtual void verticalScrollbarAction(int action);
    inline void verticalScrollbarValueChanged_protected(int value) { QListView::verticalScrollbarValueChanged(value); }
    virtual void verticalScrollbarValueChanged(int value);
    inline QStyleOptionViewItem viewOptions_protected() const { return QListView::viewOptions(); }
    virtual QStyleOptionViewItem viewOptions() const;
    inline bool viewportEvent_protected(QEvent * event) { return QListView::viewportEvent(event); }
    virtual bool viewportEvent(QEvent * event);
    virtual QRect visualRect(const QModelIndex & index) const;
    inline QRegion visualRegionForSelection_protected(const QItemSelection & selection) const { return QListView::visualRegionForSelection(selection); }
    virtual QRegion visualRegionForSelection(const QItemSelection & selection) const;
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QListView::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QListView::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QListViewWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    // Inherited overloads, because the using keyword sux
    inline void edit(const QModelIndex & index) { QListView::edit(index); }
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QLISTVIEWWRAPPER_H

