/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QLISTWIDGETWRAPPER_H
#define SBK_QLISTWIDGETWRAPPER_H

#include <shiboken.h>

#include <qlistwidget.h>

namespace PySide { class DynamicQMetaObject; }

class QListWidgetWrapper : public QListWidget
{
public:
    QListWidgetWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QListWidget::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QListWidget::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QListWidget::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEditor_protected(QWidget * editor, int hint) { QListWidget::closeEditor(editor, QAbstractItemDelegate::EndEditHint(hint)); }
    virtual void closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint);
    inline void closeEvent_protected(QCloseEvent * event) { QListWidget::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void commitData_protected(QWidget * editor) { QListWidget::commitData(editor); }
    virtual void commitData(QWidget * editor);
    inline void connectNotify_protected(const char * signal) { QListWidget::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline QSize contentsSize_protected() const { return QListWidget::contentsSize(); }
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QListWidget::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void currentChanged_protected(const QModelIndex & current, const QModelIndex & previous) { QListWidget::currentChanged(current, previous); }
    virtual void currentChanged(const QModelIndex & current, const QModelIndex & previous);
    inline void customEvent_protected(QEvent * arg__1) { QListWidget::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void dataChanged_protected(const QModelIndex & topLeft, const QModelIndex & bottomRight) { QListWidget::dataChanged(topLeft, bottomRight); }
    virtual void dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QListWidget::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline QPoint dirtyRegionOffset_protected() const { return QListWidget::dirtyRegionOffset(); }
    inline void disconnectNotify_protected(const char * signal) { QListWidget::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void doAutoScroll_protected() { QListWidget::doAutoScroll(); }
    virtual void doItemsLayout();
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QListWidget::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * e) { QListWidget::dragLeaveEvent(e); }
    virtual void dragLeaveEvent(QDragLeaveEvent * e);
    inline void dragMoveEvent_protected(QDragMoveEvent * e) { QListWidget::dragMoveEvent(e); }
    virtual void dragMoveEvent(QDragMoveEvent * e);
    inline void drawFrame_protected(QPainter * arg__1) { QListWidget::drawFrame(arg__1); }
    virtual void dropEvent(QDropEvent * event);
    inline int dropIndicatorPosition_protected() const { return QListWidget::dropIndicatorPosition(); }
    inline bool dropMimeData_protected(int index, const QMimeData * data, int action) { return QListWidget::dropMimeData(index, data, Qt::DropAction(action)); }
    virtual bool dropMimeData(int index, const QMimeData * data, Qt::DropAction action);
    inline bool edit_protected(const QModelIndex & index, int trigger, QEvent * event) { return QListWidget::edit(index, QAbstractItemView::EditTrigger(trigger), event); }
    virtual bool edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event);
    inline void editorDestroyed_protected(QObject * editor) { QListWidget::editorDestroyed(editor); }
    virtual void editorDestroyed(QObject * editor);
    inline void enterEvent_protected(QEvent * event) { QListWidget::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QListWidget::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void executeDelayedItemsLayout_protected() { QListWidget::executeDelayedItemsLayout(); }
    inline void focusInEvent_protected(QFocusEvent * event) { QListWidget::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QListWidget::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QListWidget::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QListWidget::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QListWidget::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QListWidget::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline int horizontalOffset_protected() const { return QListWidget::horizontalOffset(); }
    virtual int horizontalOffset() const;
    inline void horizontalScrollbarAction_protected(int action) { QListWidget::horizontalScrollbarAction(action); }
    virtual void horizontalScrollbarAction(int action);
    inline void horizontalScrollbarValueChanged_protected(int value) { QListWidget::horizontalScrollbarValueChanged(value); }
    virtual void horizontalScrollbarValueChanged(int value);
    virtual QModelIndex indexAt(const QPoint & p) const;
    inline QModelIndex indexFromItem_protected(QListWidgetItem * item) const { return QListWidget::indexFromItem(item); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QListWidget::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline void internalDrag_protected(int supportedActions) { QListWidget::internalDrag(QFlags<Qt::DropAction>(supportedActions)); }
    inline void internalDrop_protected(QDropEvent * e) { QListWidget::internalDrop(e); }
    inline bool isIndexHidden_protected(const QModelIndex & index) const { return QListWidget::isIndexHidden(index); }
    virtual bool isIndexHidden(const QModelIndex & index) const;
    inline QListWidgetItem * itemFromIndex_protected(const QModelIndex & index) const { return QListWidget::itemFromIndex(index); }
    inline QList<QListWidgetItem * > items_protected(const QMimeData * data) const { return QListWidget::items(data); }
    inline void keyPressEvent_protected(QKeyEvent * event) { QListWidget::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QListWidget::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual void keyboardSearch(const QString & search);
    inline void languageChange_protected() { QListWidget::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QListWidget::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QListWidget::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    inline QMimeData * mimeData_protected(const QList<QListWidgetItem * > items) const { return QListWidget::mimeData(items); }
    virtual QMimeData * mimeData(const QList<QListWidgetItem * > items) const;
    inline QStringList mimeTypes_protected() const { return QListWidget::mimeTypes(); }
    virtual QStringList mimeTypes() const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QListWidget::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * e) { QListWidget::mouseMoveEvent(e); }
    virtual void mouseMoveEvent(QMouseEvent * e);
    inline void mousePressEvent_protected(QMouseEvent * event) { QListWidget::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * e) { QListWidget::mouseReleaseEvent(e); }
    virtual void mouseReleaseEvent(QMouseEvent * e);
    inline QModelIndex moveCursor_protected(int cursorAction, int modifiers) { return QListWidget::moveCursor(QAbstractItemView::CursorAction(cursorAction), QFlags<Qt::KeyboardModifier>(modifiers)); }
    virtual QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction, QFlags<Qt::KeyboardModifier> modifiers);
    inline void moveEvent_protected(QMoveEvent * event) { QListWidget::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * e) { QListWidget::paintEvent(e); }
    virtual void paintEvent(QPaintEvent * e);
    inline QRect rectForIndex_protected(const QModelIndex & index) const { return QListWidget::rectForIndex(index); }
    virtual void reset();
    inline void resetInputContext_protected() { QListWidget::resetInputContext(); }
    inline void resizeContents_protected(int width, int height) { QListWidget::resizeContents(width, height); }
    inline void resizeEvent_protected(QResizeEvent * e) { QListWidget::resizeEvent(e); }
    virtual void resizeEvent(QResizeEvent * e);
    inline void rowsAboutToBeRemoved_protected(const QModelIndex & parent, int start, int end) { QListWidget::rowsAboutToBeRemoved(parent, start, end); }
    virtual void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end);
    inline void rowsInserted_protected(const QModelIndex & parent, int start, int end) { QListWidget::rowsInserted(parent, start, end); }
    virtual void rowsInserted(const QModelIndex & parent, int start, int end);
    inline void scheduleDelayedItemsLayout_protected() { QListWidget::scheduleDelayedItemsLayout(); }
    inline void scrollContentsBy_protected(int dx, int dy) { QListWidget::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void scrollDirtyRegion_protected(int dx, int dy) { QListWidget::scrollDirtyRegion(dx, dy); }
    virtual void scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint = EnsureVisible);
    virtual void selectAll();
    inline QModelIndexList selectedIndexes_protected() const { return QListWidget::selectedIndexes(); }
    virtual QModelIndexList selectedIndexes() const;
    inline void selectionChanged_protected(const QItemSelection & selected, const QItemSelection & deselected) { QListWidget::selectionChanged(selected, deselected); }
    virtual void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
    inline int selectionCommand_protected(const QModelIndex & index, const QEvent * event = 0) const { return QListWidget::selectionCommand(index, event); }
    virtual QFlags<QItemSelectionModel::SelectionFlag> selectionCommand(const QModelIndex & index, const QEvent * event = 0) const;
    inline void setDirtyRegion_protected(const QRegion & region) { QListWidget::setDirtyRegion(region); }
    inline void setPositionForIndex_protected(const QPoint & position, const QModelIndex & index) { QListWidget::setPositionForIndex(position, index); }
    virtual void setRootIndex(const QModelIndex & index);
    inline void setSelection_protected(const QRect & rect, int command) { QListWidget::setSelection(rect, QFlags<QItemSelectionModel::SelectionFlag>(command)); }
    virtual void setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command);
    virtual void setSelectionModel(QItemSelectionModel * selectionModel);
    inline void setState_protected(int state) { QListWidget::setState(QAbstractItemView::State(state)); }
    inline void setViewportMargins_protected(const QMargins & margins) { QListWidget::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QListWidget::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QListWidget::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * event) { QListWidget::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    virtual int sizeHintForColumn(int column) const;
    virtual int sizeHintForRow(int row) const;
    inline void startAutoScroll_protected() { QListWidget::startAutoScroll(); }
    inline void startDrag_protected(int supportedActions) { QListWidget::startDrag(QFlags<Qt::DropAction>(supportedActions)); }
    virtual void startDrag(QFlags<Qt::DropAction> supportedActions);
    inline int state_protected() const { return QListWidget::state(); }
    inline void stopAutoScroll_protected() { QListWidget::stopAutoScroll(); }
    inline int supportedDropActions_protected() const { return QListWidget::supportedDropActions(); }
    virtual QFlags<Qt::DropAction> supportedDropActions() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QListWidget::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * e) { QListWidget::timerEvent(e); }
    virtual void timerEvent(QTimerEvent * e);
    inline void updateEditorData_protected() { QListWidget::updateEditorData(); }
    virtual void updateEditorData();
    inline void updateEditorGeometries_protected() { QListWidget::updateEditorGeometries(); }
    virtual void updateEditorGeometries();
    inline void updateGeometries_protected() { QListWidget::updateGeometries(); }
    virtual void updateGeometries();
    inline void updateMicroFocus_protected() { QListWidget::updateMicroFocus(); }
    inline int verticalOffset_protected() const { return QListWidget::verticalOffset(); }
    virtual int verticalOffset() const;
    inline void verticalScrollbarAction_protected(int action) { QListWidget::verticalScrollbarAction(action); }
    virtual void verticalScrollbarAction(int action);
    inline void verticalScrollbarValueChanged_protected(int value) { QListWidget::verticalScrollbarValueChanged(value); }
    virtual void verticalScrollbarValueChanged(int value);
    inline QStyleOptionViewItem viewOptions_protected() const { return QListWidget::viewOptions(); }
    virtual QStyleOptionViewItem viewOptions() const;
    inline bool viewportEvent_protected(QEvent * event) { return QListWidget::viewportEvent(event); }
    virtual bool viewportEvent(QEvent * event);
    virtual QRect visualRect(const QModelIndex & index) const;
    inline QRegion visualRegionForSelection_protected(const QItemSelection & selection) const { return QListWidget::visualRegionForSelection(selection); }
    virtual QRegion visualRegionForSelection(const QItemSelection & selection) const;
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QListWidget::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QListWidget::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QListWidgetWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QLISTWIDGETWRAPPER_H

