/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QMDIAREAWRAPPER_H
#define SBK_QMDIAREAWRAPPER_H

#include <shiboken.h>

#include <qmdiarea.h>

namespace PySide { class DynamicQMetaObject; }

class QMdiAreaWrapper : public QMdiArea
{
public:
    QMdiAreaWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QMdiArea::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QMdiArea::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * childEvent) { QMdiArea::childEvent(childEvent); }
    virtual void childEvent(QChildEvent * childEvent);
    inline void closeEvent_protected(QCloseEvent * event) { QMdiArea::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QMdiArea::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QMdiArea::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void customEvent_protected(QEvent * arg__1) { QMdiArea::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QMdiArea::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QMdiArea::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * arg__1) { QMdiArea::dragEnterEvent(arg__1); }
    virtual void dragEnterEvent(QDragEnterEvent * arg__1);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * arg__1) { QMdiArea::dragLeaveEvent(arg__1); }
    virtual void dragLeaveEvent(QDragLeaveEvent * arg__1);
    inline void dragMoveEvent_protected(QDragMoveEvent * arg__1) { QMdiArea::dragMoveEvent(arg__1); }
    virtual void dragMoveEvent(QDragMoveEvent * arg__1);
    inline void drawFrame_protected(QPainter * arg__1) { QMdiArea::drawFrame(arg__1); }
    inline void dropEvent_protected(QDropEvent * arg__1) { QMdiArea::dropEvent(arg__1); }
    virtual void dropEvent(QDropEvent * arg__1);
    inline void enterEvent_protected(QEvent * event) { QMdiArea::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * event) { return QMdiArea::event(event); }
    virtual bool event(QEvent * event);
    inline bool eventFilter_protected(QObject * object, QEvent * event) { return QMdiArea::eventFilter(object, event); }
    virtual bool eventFilter(QObject * object, QEvent * event);
    inline void focusInEvent_protected(QFocusEvent * event) { QMdiArea::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QMdiArea::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QMdiArea::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QMdiArea::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QMdiArea::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QMdiArea::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QMdiArea::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * arg__1) { QMdiArea::keyPressEvent(arg__1); }
    virtual void keyPressEvent(QKeyEvent * arg__1);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QMdiArea::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QMdiArea::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QMdiArea::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QMdiArea::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * arg__1) { QMdiArea::mouseDoubleClickEvent(arg__1); }
    virtual void mouseDoubleClickEvent(QMouseEvent * arg__1);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QMdiArea::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QMdiArea::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * arg__1) { QMdiArea::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QMouseEvent * arg__1);
    inline void moveEvent_protected(QMoveEvent * event) { QMdiArea::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * paintEvent) { QMdiArea::paintEvent(paintEvent); }
    virtual void paintEvent(QPaintEvent * paintEvent);
    inline void resetInputContext_protected() { QMdiArea::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * resizeEvent) { QMdiArea::resizeEvent(resizeEvent); }
    virtual void resizeEvent(QResizeEvent * resizeEvent);
    inline void scrollContentsBy_protected(int dx, int dy) { QMdiArea::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void setViewportMargins_protected(const QMargins & margins) { QMdiArea::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QMdiArea::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QMdiArea::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * showEvent) { QMdiArea::showEvent(showEvent); }
    virtual void showEvent(QShowEvent * showEvent);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QMdiArea::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * timerEvent) { QMdiArea::timerEvent(timerEvent); }
    virtual void timerEvent(QTimerEvent * timerEvent);
    inline void updateMicroFocus_protected() { QMdiArea::updateMicroFocus(); }
    inline bool viewportEvent_protected(QEvent * event) { return QMdiArea::viewportEvent(event); }
    virtual bool viewportEvent(QEvent * event);
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QMdiArea::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QMdiArea::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QMdiAreaWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QMDIAREAWRAPPER_H

