/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QMDISUBWINDOWWRAPPER_H
#define SBK_QMDISUBWINDOWWRAPPER_H

#include <shiboken.h>

#include <qmdisubwindow.h>

namespace PySide { class DynamicQMetaObject; }

class QMdiSubWindowWrapper : public QMdiSubWindow
{
public:
    QMdiSubWindowWrapper(QWidget * parent = 0, QFlags<Qt::WindowType> flags = 0);
    inline void actionEvent_protected(QActionEvent * event) { QMdiSubWindow::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * changeEvent) { QMdiSubWindow::changeEvent(changeEvent); }
    virtual void changeEvent(QEvent * changeEvent);
    inline void childEvent_protected(QChildEvent * childEvent) { QMdiSubWindow::childEvent(childEvent); }
    virtual void childEvent(QChildEvent * childEvent);
    inline void closeEvent_protected(QCloseEvent * closeEvent) { QMdiSubWindow::closeEvent(closeEvent); }
    virtual void closeEvent(QCloseEvent * closeEvent);
    inline void connectNotify_protected(const char * signal) { QMdiSubWindow::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * contextMenuEvent) { QMdiSubWindow::contextMenuEvent(contextMenuEvent); }
    virtual void contextMenuEvent(QContextMenuEvent * contextMenuEvent);
    inline void customEvent_protected(QEvent * arg__1) { QMdiSubWindow::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QMdiSubWindow::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QMdiSubWindow::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QMdiSubWindow::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QMdiSubWindow::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QMdiSubWindow::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QMdiSubWindow::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QMdiSubWindow::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * event) { return QMdiSubWindow::event(event); }
    virtual bool event(QEvent * event);
    inline bool eventFilter_protected(QObject * object, QEvent * event) { return QMdiSubWindow::eventFilter(object, event); }
    virtual bool eventFilter(QObject * object, QEvent * event);
    inline void focusInEvent_protected(QFocusEvent * focusInEvent) { QMdiSubWindow::focusInEvent(focusInEvent); }
    virtual void focusInEvent(QFocusEvent * focusInEvent);
    inline bool focusNextChild_protected() { return QMdiSubWindow::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QMdiSubWindow::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * focusOutEvent) { QMdiSubWindow::focusOutEvent(focusOutEvent); }
    virtual void focusOutEvent(QFocusEvent * focusOutEvent);
    inline bool focusPreviousChild_protected() { return QMdiSubWindow::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * hideEvent) { QMdiSubWindow::hideEvent(hideEvent); }
    virtual void hideEvent(QHideEvent * hideEvent);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QMdiSubWindow::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * keyEvent) { QMdiSubWindow::keyPressEvent(keyEvent); }
    virtual void keyPressEvent(QKeyEvent * keyEvent);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QMdiSubWindow::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QMdiSubWindow::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * leaveEvent) { QMdiSubWindow::leaveEvent(leaveEvent); }
    virtual void leaveEvent(QEvent * leaveEvent);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QMdiSubWindow::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * mouseEvent) { QMdiSubWindow::mouseDoubleClickEvent(mouseEvent); }
    virtual void mouseDoubleClickEvent(QMouseEvent * mouseEvent);
    inline void mouseMoveEvent_protected(QMouseEvent * mouseEvent) { QMdiSubWindow::mouseMoveEvent(mouseEvent); }
    virtual void mouseMoveEvent(QMouseEvent * mouseEvent);
    inline void mousePressEvent_protected(QMouseEvent * mouseEvent) { QMdiSubWindow::mousePressEvent(mouseEvent); }
    virtual void mousePressEvent(QMouseEvent * mouseEvent);
    inline void mouseReleaseEvent_protected(QMouseEvent * mouseEvent) { QMdiSubWindow::mouseReleaseEvent(mouseEvent); }
    virtual void mouseReleaseEvent(QMouseEvent * mouseEvent);
    inline void moveEvent_protected(QMoveEvent * moveEvent) { QMdiSubWindow::moveEvent(moveEvent); }
    virtual void moveEvent(QMoveEvent * moveEvent);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * paintEvent) { QMdiSubWindow::paintEvent(paintEvent); }
    virtual void paintEvent(QPaintEvent * paintEvent);
    inline void resetInputContext_protected() { QMdiSubWindow::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * resizeEvent) { QMdiSubWindow::resizeEvent(resizeEvent); }
    virtual void resizeEvent(QResizeEvent * resizeEvent);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * showEvent) { QMdiSubWindow::showEvent(showEvent); }
    virtual void showEvent(QShowEvent * showEvent);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QMdiSubWindow::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * timerEvent) { QMdiSubWindow::timerEvent(timerEvent); }
    virtual void timerEvent(QTimerEvent * timerEvent);
    inline void updateMicroFocus_protected() { QMdiSubWindow::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QMdiSubWindow::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QMdiSubWindow::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QMdiSubWindowWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QMDISUBWINDOWWRAPPER_H

