/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QMENUBARWRAPPER_H
#define SBK_QMENUBARWRAPPER_H

#include <shiboken.h>

#include <qmenubar.h>

namespace PySide { class DynamicQMetaObject; }

class QMenuBarWrapper : public QMenuBar
{
public:
    QMenuBarWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * arg__1) { QMenuBar::actionEvent(arg__1); }
    virtual void actionEvent(QActionEvent * arg__1);
    inline void changeEvent_protected(QEvent * arg__1) { QMenuBar::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QMenuBar::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QMenuBar::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QMenuBar::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QMenuBar::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QMenuBar::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QMenuBar::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QMenuBar::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QMenuBar::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QMenuBar::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QMenuBar::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QMenuBar::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QMenuBar::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QMenuBar::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    inline bool eventFilter_protected(QObject * arg__1, QEvent * arg__2) { return QMenuBar::eventFilter(arg__1, arg__2); }
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * arg__1) { QMenuBar::focusInEvent(arg__1); }
    virtual void focusInEvent(QFocusEvent * arg__1);
    inline bool focusNextChild_protected() { return QMenuBar::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QMenuBar::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * arg__1) { QMenuBar::focusOutEvent(arg__1); }
    virtual void focusOutEvent(QFocusEvent * arg__1);
    inline bool focusPreviousChild_protected() { return QMenuBar::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QMenuBar::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void initStyleOption_protected(QStyleOptionMenuItem * option, const QAction * action) const { QMenuBar::initStyleOption(option, action); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QMenuBar::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * arg__1) { QMenuBar::keyPressEvent(arg__1); }
    virtual void keyPressEvent(QKeyEvent * arg__1);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QMenuBar::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QMenuBar::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * arg__1) { QMenuBar::leaveEvent(arg__1); }
    virtual void leaveEvent(QEvent * arg__1);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QMenuBar::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QMenuBar::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QMenuBar::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QMenuBar::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * arg__1) { QMenuBar::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QMouseEvent * arg__1);
    inline void moveEvent_protected(QMoveEvent * event) { QMenuBar::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QMenuBar::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void resetInputContext_protected() { QMenuBar::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * arg__1) { QMenuBar::resizeEvent(arg__1); }
    virtual void resizeEvent(QResizeEvent * arg__1);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QMenuBar::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QMenuBar::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QMenuBar::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QMenuBar::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QMenuBar::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QMenuBar::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QMenuBarWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QMENUBARWRAPPER_H

