/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QMESSAGEBOXWRAPPER_H
#define SBK_QMESSAGEBOXWRAPPER_H

#include <shiboken.h>

#include <qmessagebox.h>

namespace PySide { class DynamicQMetaObject; }

class QMessageBoxWrapper : public QMessageBox
{
public:
    QMessageBoxWrapper(QMessageBox::Icon icon, const QString & title, const QString & text, QFlags<QMessageBox::StandardButton> buttons = QMessageBox::NoButton, QWidget * parent = 0, QFlags<Qt::WindowType> flags = Qt::Dialog | Qt::MSWindowsFixedSizeDialogHint);
    QMessageBoxWrapper(QWidget * parent = 0);
    virtual void accept();
    inline void actionEvent_protected(QActionEvent * event) { QMessageBox::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void adjustPosition_protected(QWidget * arg__1) { QMessageBox::adjustPosition(arg__1); }
    inline void changeEvent_protected(QEvent * event) { QMessageBox::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QMessageBox::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QMessageBox::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QMessageBox::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QMessageBox::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void customEvent_protected(QEvent * arg__1) { QMessageBox::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QMessageBox::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QMessageBox::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    virtual void done(int arg__1);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QMessageBox::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QMessageBox::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QMessageBox::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QMessageBox::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QMessageBox::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QMessageBox::event(e); }
    virtual bool event(QEvent * e);
    inline bool eventFilter_protected(QObject * arg__1, QEvent * arg__2) { return QMessageBox::eventFilter(arg__1, arg__2); }
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QMessageBox::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QMessageBox::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QMessageBox::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QMessageBox::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QMessageBox::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QMessageBox::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QMessageBox::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QMessageBox::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QMessageBox::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QMessageBox::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QMessageBox::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QMessageBox::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QMessageBox::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QMessageBox::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QMessageBox::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QMessageBox::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline void moveEvent_protected(QMoveEvent * event) { QMessageBox::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * event) { QMessageBox::paintEvent(event); }
    virtual void paintEvent(QPaintEvent * event);
    virtual void reject();
    inline void resetInputContext_protected() { QMessageBox::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QMessageBox::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QMessageBox::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QMessageBox::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QMessageBox::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QMessageBox::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QMessageBox::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QMessageBox::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QMessageBoxWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QMESSAGEBOXWRAPPER_H

