/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QPLAINTEXTEDITWRAPPER_H
#define SBK_QPLAINTEXTEDITWRAPPER_H

#include <shiboken.h>

#include <qplaintextedit.h>

namespace PySide { class DynamicQMetaObject; }

class QPlainTextEditWrapper : public QPlainTextEdit
{
public:
    QPlainTextEditWrapper(QWidget * parent = 0);
    QPlainTextEditWrapper(const QString & text, QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QPlainTextEdit::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline QRectF blockBoundingGeometry_protected(const QTextBlock & block) const { return QPlainTextEdit::blockBoundingGeometry(block); }
    inline QRectF blockBoundingRect_protected(const QTextBlock & block) const { return QPlainTextEdit::blockBoundingRect(block); }
    inline bool canInsertFromMimeData_protected(const QMimeData * source) const { return QPlainTextEdit::canInsertFromMimeData(source); }
    virtual bool canInsertFromMimeData(const QMimeData * source) const;
    inline void changeEvent_protected(QEvent * e) { QPlainTextEdit::changeEvent(e); }
    virtual void changeEvent(QEvent * e);
    inline void childEvent_protected(QChildEvent * arg__1) { QPlainTextEdit::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QPlainTextEdit::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QPlainTextEdit::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline QPointF contentOffset_protected() const { return QPlainTextEdit::contentOffset(); }
    inline void contextMenuEvent_protected(QContextMenuEvent * e) { QPlainTextEdit::contextMenuEvent(e); }
    virtual void contextMenuEvent(QContextMenuEvent * e);
    inline QMimeData * createMimeDataFromSelection_protected() const { return QPlainTextEdit::createMimeDataFromSelection(); }
    virtual QMimeData * createMimeDataFromSelection() const;
    inline void customEvent_protected(QEvent * arg__1) { QPlainTextEdit::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QPlainTextEdit::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QPlainTextEdit::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * e) { QPlainTextEdit::dragEnterEvent(e); }
    virtual void dragEnterEvent(QDragEnterEvent * e);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * e) { QPlainTextEdit::dragLeaveEvent(e); }
    virtual void dragLeaveEvent(QDragLeaveEvent * e);
    inline void dragMoveEvent_protected(QDragMoveEvent * e) { QPlainTextEdit::dragMoveEvent(e); }
    virtual void dragMoveEvent(QDragMoveEvent * e);
    inline void drawFrame_protected(QPainter * arg__1) { QPlainTextEdit::drawFrame(arg__1); }
    inline void dropEvent_protected(QDropEvent * e) { QPlainTextEdit::dropEvent(e); }
    virtual void dropEvent(QDropEvent * e);
    inline void enterEvent_protected(QEvent * event) { QPlainTextEdit::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QPlainTextEdit::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline QTextBlock firstVisibleBlock_protected() const { return QPlainTextEdit::firstVisibleBlock(); }
    inline void focusInEvent_protected(QFocusEvent * e) { QPlainTextEdit::focusInEvent(e); }
    virtual void focusInEvent(QFocusEvent * e);
    inline bool focusNextChild_protected() { return QPlainTextEdit::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QPlainTextEdit::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * e) { QPlainTextEdit::focusOutEvent(e); }
    virtual void focusOutEvent(QFocusEvent * e);
    inline bool focusPreviousChild_protected() { return QPlainTextEdit::focusPreviousChild(); }
    inline QAbstractTextDocumentLayout::PaintContext getPaintContext_protected() const { return QPlainTextEdit::getPaintContext(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QPlainTextEdit::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * arg__1) { QPlainTextEdit::inputMethodEvent(arg__1); }
    virtual void inputMethodEvent(QInputMethodEvent * arg__1);
    inline QVariant inputMethodQuery_protected(int property) const { return QPlainTextEdit::inputMethodQuery(Qt::InputMethodQuery(property)); }
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery property) const;
    inline void insertFromMimeData_protected(const QMimeData * source) { QPlainTextEdit::insertFromMimeData(source); }
    virtual void insertFromMimeData(const QMimeData * source);
    inline void keyPressEvent_protected(QKeyEvent * e) { QPlainTextEdit::keyPressEvent(e); }
    virtual void keyPressEvent(QKeyEvent * e);
    inline void keyReleaseEvent_protected(QKeyEvent * e) { QPlainTextEdit::keyReleaseEvent(e); }
    virtual void keyReleaseEvent(QKeyEvent * e);
    inline void languageChange_protected() { QPlainTextEdit::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QPlainTextEdit::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual QVariant loadResource(int type, const QUrl & name);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QPlainTextEdit::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * e) { QPlainTextEdit::mouseDoubleClickEvent(e); }
    virtual void mouseDoubleClickEvent(QMouseEvent * e);
    inline void mouseMoveEvent_protected(QMouseEvent * e) { QPlainTextEdit::mouseMoveEvent(e); }
    virtual void mouseMoveEvent(QMouseEvent * e);
    inline void mousePressEvent_protected(QMouseEvent * e) { QPlainTextEdit::mousePressEvent(e); }
    virtual void mousePressEvent(QMouseEvent * e);
    inline void mouseReleaseEvent_protected(QMouseEvent * e) { QPlainTextEdit::mouseReleaseEvent(e); }
    virtual void mouseReleaseEvent(QMouseEvent * e);
    inline void moveEvent_protected(QMoveEvent * event) { QPlainTextEdit::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * e) { QPlainTextEdit::paintEvent(e); }
    virtual void paintEvent(QPaintEvent * e);
    inline void resetInputContext_protected() { QPlainTextEdit::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * e) { QPlainTextEdit::resizeEvent(e); }
    virtual void resizeEvent(QResizeEvent * e);
    inline void scrollContentsBy_protected(int dx, int dy) { QPlainTextEdit::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void setViewportMargins_protected(const QMargins & margins) { QPlainTextEdit::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QPlainTextEdit::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QPlainTextEdit::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * arg__1) { QPlainTextEdit::showEvent(arg__1); }
    virtual void showEvent(QShowEvent * arg__1);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QPlainTextEdit::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * e) { QPlainTextEdit::timerEvent(e); }
    virtual void timerEvent(QTimerEvent * e);
    inline void updateMicroFocus_protected() { QPlainTextEdit::updateMicroFocus(); }
    inline bool viewportEvent_protected(QEvent * arg__1) { return QPlainTextEdit::viewportEvent(arg__1); }
    virtual bool viewportEvent(QEvent * arg__1);
    inline void wheelEvent_protected(QWheelEvent * e) { QPlainTextEdit::wheelEvent(e); }
    virtual void wheelEvent(QWheelEvent * e);
    inline bool winEvent_protected(MSG * message, long * result) { return QPlainTextEdit::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QPlainTextEditWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QPLAINTEXTEDITWRAPPER_H

