/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QPRINTDIALOGWRAPPER_H
#define SBK_QPRINTDIALOGWRAPPER_H

#include <shiboken.h>

#include <qprintdialog.h>

namespace PySide { class DynamicQMetaObject; }

class QPrintDialogWrapper : public QPrintDialog
{
public:
    QPrintDialogWrapper(QPrinter * printer, QWidget * parent = 0);
    QPrintDialogWrapper(QWidget * parent = 0);
    virtual void accept();
    inline void actionEvent_protected(QActionEvent * event) { QPrintDialog::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void adjustPosition_protected(QWidget * arg__1) { QPrintDialog::adjustPosition(arg__1); }
    inline void changeEvent_protected(QEvent * event) { QPrintDialog::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QPrintDialog::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * arg__1) { QPrintDialog::closeEvent(arg__1); }
    virtual void closeEvent(QCloseEvent * arg__1);
    inline void connectNotify_protected(const char * signal) { QPrintDialog::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QPrintDialog::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void customEvent_protected(QEvent * arg__1) { QPrintDialog::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QPrintDialog::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QPrintDialog::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    virtual void done(int result);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QPrintDialog::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QPrintDialog::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QPrintDialog::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QPrintDialog::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QPrintDialog::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QPrintDialog::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    inline bool eventFilter_protected(QObject * arg__1, QEvent * arg__2) { return QPrintDialog::eventFilter(arg__1, arg__2); }
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    virtual int exec();
    inline void focusInEvent_protected(QFocusEvent * event) { QPrintDialog::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QPrintDialog::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QPrintDialog::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QPrintDialog::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QPrintDialog::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QPrintDialog::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QPrintDialog::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * arg__1) { QPrintDialog::keyPressEvent(arg__1); }
    virtual void keyPressEvent(QKeyEvent * arg__1);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QPrintDialog::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QPrintDialog::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QPrintDialog::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QPrintDialog::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QPrintDialog::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QPrintDialog::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QPrintDialog::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QPrintDialog::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline void moveEvent_protected(QMoveEvent * event) { QPrintDialog::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * event) { QPrintDialog::paintEvent(event); }
    virtual void paintEvent(QPaintEvent * event);
    virtual void reject();
    inline void resetInputContext_protected() { QPrintDialog::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * arg__1) { QPrintDialog::resizeEvent(arg__1); }
    virtual void resizeEvent(QResizeEvent * arg__1);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * arg__1) { QPrintDialog::showEvent(arg__1); }
    virtual void showEvent(QShowEvent * arg__1);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QPrintDialog::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QPrintDialog::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QPrintDialog::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QPrintDialog::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QPrintDialog::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QPrintDialogWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QPRINTDIALOGWRAPPER_H

