/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QRADIOBUTTONWRAPPER_H
#define SBK_QRADIOBUTTONWRAPPER_H

#include <shiboken.h>

#include <qradiobutton.h>

namespace PySide { class DynamicQMetaObject; }

class QRadioButtonWrapper : public QRadioButton
{
public:
    QRadioButtonWrapper(QWidget * parent = 0);
    QRadioButtonWrapper(const QString & text, QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QRadioButton::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * e) { QRadioButton::changeEvent(e); }
    virtual void changeEvent(QEvent * e);
    inline void checkStateSet_protected() { QRadioButton::checkStateSet(); }
    virtual void checkStateSet();
    inline void childEvent_protected(QChildEvent * arg__1) { QRadioButton::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QRadioButton::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QRadioButton::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QRadioButton::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QRadioButton::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QRadioButton::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QRadioButton::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QRadioButton::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QRadioButton::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QRadioButton::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QRadioButton::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QRadioButton::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QRadioButton::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * e) { QRadioButton::focusInEvent(e); }
    virtual void focusInEvent(QFocusEvent * e);
    inline bool focusNextChild_protected() { return QRadioButton::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QRadioButton::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * e) { QRadioButton::focusOutEvent(e); }
    virtual void focusOutEvent(QFocusEvent * e);
    inline bool focusPreviousChild_protected() { return QRadioButton::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QRadioButton::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline bool hitButton_protected(const QPoint & arg__1) const { return QRadioButton::hitButton(arg__1); }
    virtual bool hitButton(const QPoint & arg__1) const;
    inline void initStyleOption_protected(QStyleOptionButton * button) const { QRadioButton::initStyleOption(button); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QRadioButton::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * e) { QRadioButton::keyPressEvent(e); }
    virtual void keyPressEvent(QKeyEvent * e);
    inline void keyReleaseEvent_protected(QKeyEvent * e) { QRadioButton::keyReleaseEvent(e); }
    virtual void keyReleaseEvent(QKeyEvent * e);
    inline void languageChange_protected() { QRadioButton::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QRadioButton::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QRadioButton::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QRadioButton::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QRadioButton::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * e) { QRadioButton::mousePressEvent(e); }
    virtual void mousePressEvent(QMouseEvent * e);
    inline void mouseReleaseEvent_protected(QMouseEvent * e) { QRadioButton::mouseReleaseEvent(e); }
    virtual void mouseReleaseEvent(QMouseEvent * e);
    inline void moveEvent_protected(QMoveEvent * event) { QRadioButton::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    inline void nextCheckState_protected() { QRadioButton::nextCheckState(); }
    virtual void nextCheckState();
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QRadioButton::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void resetInputContext_protected() { QRadioButton::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QRadioButton::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QRadioButton::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QRadioButton::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * e) { QRadioButton::timerEvent(e); }
    virtual void timerEvent(QTimerEvent * e);
    inline void updateMicroFocus_protected() { QRadioButton::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QRadioButton::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QRadioButton::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QRadioButtonWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QRADIOBUTTONWRAPPER_H

