/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QSCROLLAREAWRAPPER_H
#define SBK_QSCROLLAREAWRAPPER_H

#include <shiboken.h>

#include <qscrollarea.h>

namespace PySide { class DynamicQMetaObject; }

class QScrollAreaWrapper : public QScrollArea
{
public:
    QScrollAreaWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QScrollArea::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QScrollArea::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QScrollArea::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QScrollArea::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QScrollArea::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QScrollArea::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void customEvent_protected(QEvent * arg__1) { QScrollArea::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QScrollArea::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QScrollArea::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * arg__1) { QScrollArea::dragEnterEvent(arg__1); }
    virtual void dragEnterEvent(QDragEnterEvent * arg__1);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * arg__1) { QScrollArea::dragLeaveEvent(arg__1); }
    virtual void dragLeaveEvent(QDragLeaveEvent * arg__1);
    inline void dragMoveEvent_protected(QDragMoveEvent * arg__1) { QScrollArea::dragMoveEvent(arg__1); }
    virtual void dragMoveEvent(QDragMoveEvent * arg__1);
    inline void drawFrame_protected(QPainter * arg__1) { QScrollArea::drawFrame(arg__1); }
    inline void dropEvent_protected(QDropEvent * arg__1) { QScrollArea::dropEvent(arg__1); }
    virtual void dropEvent(QDropEvent * arg__1);
    inline void enterEvent_protected(QEvent * event) { QScrollArea::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QScrollArea::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    inline bool eventFilter_protected(QObject * arg__1, QEvent * arg__2) { return QScrollArea::eventFilter(arg__1, arg__2); }
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QScrollArea::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QScrollArea::focusNextChild(); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QScrollArea::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QScrollArea::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QScrollArea::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QScrollArea::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * arg__1) { QScrollArea::keyPressEvent(arg__1); }
    virtual void keyPressEvent(QKeyEvent * arg__1);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QScrollArea::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QScrollArea::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QScrollArea::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QScrollArea::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * arg__1) { QScrollArea::mouseDoubleClickEvent(arg__1); }
    virtual void mouseDoubleClickEvent(QMouseEvent * arg__1);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QScrollArea::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QScrollArea::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * arg__1) { QScrollArea::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QMouseEvent * arg__1);
    inline void moveEvent_protected(QMoveEvent * event) { QScrollArea::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QScrollArea::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void resetInputContext_protected() { QScrollArea::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * arg__1) { QScrollArea::resizeEvent(arg__1); }
    virtual void resizeEvent(QResizeEvent * arg__1);
    inline void scrollContentsBy_protected(int dx, int dy) { QScrollArea::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void setViewportMargins_protected(const QMargins & margins) { QScrollArea::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QScrollArea::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QScrollArea::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * event) { QScrollArea::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QScrollArea::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QScrollArea::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QScrollArea::updateMicroFocus(); }
    inline bool viewportEvent_protected(QEvent * arg__1) { return QScrollArea::viewportEvent(arg__1); }
    virtual bool viewportEvent(QEvent * arg__1);
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QScrollArea::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QScrollArea::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QScrollAreaWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QSCROLLAREAWRAPPER_H

