/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QSCROLLBARWRAPPER_H
#define SBK_QSCROLLBARWRAPPER_H

#include <shiboken.h>

#include <qscrollbar.h>

namespace PySide { class DynamicQMetaObject; }

class QScrollBarWrapper : public QScrollBar
{
public:
    QScrollBarWrapper(QWidget * parent = 0);
    QScrollBarWrapper(Qt::Orientation arg__1, QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QScrollBar::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * e) { QScrollBar::changeEvent(e); }
    virtual void changeEvent(QEvent * e);
    inline void childEvent_protected(QChildEvent * arg__1) { QScrollBar::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QScrollBar::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QScrollBar::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QScrollBar::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void customEvent_protected(QEvent * arg__1) { QScrollBar::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QScrollBar::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QScrollBar::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QScrollBar::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QScrollBar::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QScrollBar::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QScrollBar::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QScrollBar::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    virtual bool event(QEvent * event);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QScrollBar::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QScrollBar::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QScrollBar::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QScrollBar::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QScrollBar::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * arg__1) { QScrollBar::hideEvent(arg__1); }
    virtual void hideEvent(QHideEvent * arg__1);
    inline void initStyleOption_protected(QStyleOptionSlider * option) const { QScrollBar::initStyleOption(option); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QScrollBar::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * ev) { QScrollBar::keyPressEvent(ev); }
    virtual void keyPressEvent(QKeyEvent * ev);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QScrollBar::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QScrollBar::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QScrollBar::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QScrollBar::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QScrollBar::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QScrollBar::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QScrollBar::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * arg__1) { QScrollBar::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QMouseEvent * arg__1);
    inline void moveEvent_protected(QMoveEvent * event) { QScrollBar::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QScrollBar::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline int repeatAction_protected() const { return QScrollBar::repeatAction(); }
    inline void resetInputContext_protected() { QScrollBar::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QScrollBar::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    inline void setRepeatAction_protected(int action, int thresholdTime = 500, int repeatTime = 50) { QScrollBar::setRepeatAction(QAbstractSlider::SliderAction(action), thresholdTime, repeatTime); }
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QScrollBar::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void sliderChange_protected(int change) { QScrollBar::sliderChange(QAbstractSlider::SliderChange(change)); }
    virtual void sliderChange(QAbstractSlider::SliderChange change);
    inline void tabletEvent_protected(QTabletEvent * event) { QScrollBar::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QScrollBar::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QScrollBar::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * e) { QScrollBar::wheelEvent(e); }
    virtual void wheelEvent(QWheelEvent * e);
    inline bool winEvent_protected(MSG * message, long * result) { return QScrollBar::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QScrollBarWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QSCROLLBARWRAPPER_H

