/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QSIZEGRIPWRAPPER_H
#define SBK_QSIZEGRIPWRAPPER_H

#include <shiboken.h>

#include <qsizegrip.h>

namespace PySide { class DynamicQMetaObject; }

class QSizeGripWrapper : public QSizeGrip
{
public:
    QSizeGripWrapper(QWidget * parent);
    inline void actionEvent_protected(QActionEvent * event) { QSizeGrip::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * event) { QSizeGrip::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QSizeGrip::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QSizeGrip::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QSizeGrip::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QSizeGrip::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QSizeGrip::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QSizeGrip::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QSizeGrip::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QSizeGrip::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QSizeGrip::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QSizeGrip::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QSizeGrip::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QSizeGrip::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QSizeGrip::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    inline bool eventFilter_protected(QObject * arg__1, QEvent * arg__2) { return QSizeGrip::eventFilter(arg__1, arg__2); }
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QSizeGrip::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QSizeGrip::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QSizeGrip::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QSizeGrip::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QSizeGrip::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * hideEvent) { QSizeGrip::hideEvent(hideEvent); }
    virtual void hideEvent(QHideEvent * hideEvent);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QSizeGrip::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QSizeGrip::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QSizeGrip::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QSizeGrip::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QSizeGrip::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QSizeGrip::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QSizeGrip::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QSizeGrip::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QSizeGrip::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * mouseEvent) { QSizeGrip::mouseReleaseEvent(mouseEvent); }
    virtual void mouseReleaseEvent(QMouseEvent * mouseEvent);
    inline void moveEvent_protected(QMoveEvent * moveEvent) { QSizeGrip::moveEvent(moveEvent); }
    virtual void moveEvent(QMoveEvent * moveEvent);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QSizeGrip::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void resetInputContext_protected() { QSizeGrip::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QSizeGrip::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    virtual void setVisible(bool arg__1);
    inline void showEvent_protected(QShowEvent * showEvent) { QSizeGrip::showEvent(showEvent); }
    virtual void showEvent(QShowEvent * showEvent);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QSizeGrip::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QSizeGrip::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QSizeGrip::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QSizeGrip::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * m, long * result) { return QSizeGrip::winEvent(m, result); }
    virtual bool winEvent(MSG * m, long * result);
    virtual ~QSizeGripWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QSIZEGRIPWRAPPER_H

