/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QSPLASHSCREENWRAPPER_H
#define SBK_QSPLASHSCREENWRAPPER_H

#include <shiboken.h>

#include <qsplashscreen.h>

namespace PySide { class DynamicQMetaObject; }

class QSplashScreenWrapper : public QSplashScreen
{
public:
    QSplashScreenWrapper(QWidget * parent, const QPixmap & pixmap = QPixmap(), QFlags<Qt::WindowType> f = 0);
    QSplashScreenWrapper(const QPixmap & pixmap = QPixmap(), QFlags<Qt::WindowType> f = 0);
    inline void actionEvent_protected(QActionEvent * event) { QSplashScreen::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * event) { QSplashScreen::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QSplashScreen::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QSplashScreen::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QSplashScreen::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QSplashScreen::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QSplashScreen::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QSplashScreen::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QSplashScreen::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QSplashScreen::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QSplashScreen::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QSplashScreen::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void drawContents_protected(QPainter * painter) { QSplashScreen::drawContents(painter); }
    virtual void drawContents(QPainter * painter);
    inline void dropEvent_protected(QDropEvent * event) { QSplashScreen::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QSplashScreen::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QSplashScreen::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QSplashScreen::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QSplashScreen::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QSplashScreen::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QSplashScreen::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QSplashScreen::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QSplashScreen::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QSplashScreen::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QSplashScreen::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QSplashScreen::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QSplashScreen::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QSplashScreen::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QSplashScreen::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QSplashScreen::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QSplashScreen::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QSplashScreen::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QSplashScreen::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline void moveEvent_protected(QMoveEvent * event) { QSplashScreen::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * event) { QSplashScreen::paintEvent(event); }
    virtual void paintEvent(QPaintEvent * event);
    inline void resetInputContext_protected() { QSplashScreen::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QSplashScreen::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QSplashScreen::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QSplashScreen::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QSplashScreen::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QSplashScreen::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QSplashScreen::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QSplashScreen::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QSplashScreenWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QSPLASHSCREENWRAPPER_H

