/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QSPLITTERHANDLEWRAPPER_H
#define SBK_QSPLITTERHANDLEWRAPPER_H

#include <shiboken.h>

#include <qsplitter.h>

namespace PySide { class DynamicQMetaObject; }

class QSplitterHandleWrapper : public QSplitterHandle
{
public:
    QSplitterHandleWrapper(Qt::Orientation o, QSplitter * parent);
    inline void actionEvent_protected(QActionEvent * event) { QSplitterHandle::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * event) { QSplitterHandle::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QSplitterHandle::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QSplitterHandle::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline int closestLegalPosition_protected(int p) { return QSplitterHandle::closestLegalPosition(p); }
    inline void connectNotify_protected(const char * signal) { QSplitterHandle::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QSplitterHandle::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QSplitterHandle::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QSplitterHandle::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QSplitterHandle::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QSplitterHandle::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QSplitterHandle::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QSplitterHandle::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QSplitterHandle::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QSplitterHandle::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QSplitterHandle::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QSplitterHandle::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QSplitterHandle::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QSplitterHandle::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QSplitterHandle::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QSplitterHandle::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QSplitterHandle::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QSplitterHandle::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QSplitterHandle::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QSplitterHandle::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QSplitterHandle::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QSplitterHandle::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QSplitterHandle::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QSplitterHandle::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QSplitterHandle::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QSplitterHandle::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * arg__1) { QSplitterHandle::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QMouseEvent * arg__1);
    inline void moveEvent_protected(QMoveEvent * event) { QSplitterHandle::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    inline void moveSplitter_protected(int p) { QSplitterHandle::moveSplitter(p); }
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QSplitterHandle::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void resetInputContext_protected() { QSplitterHandle::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * arg__1) { QSplitterHandle::resizeEvent(arg__1); }
    virtual void resizeEvent(QResizeEvent * arg__1);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QSplitterHandle::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QSplitterHandle::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QSplitterHandle::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QSplitterHandle::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QSplitterHandle::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QSplitterHandle::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QSplitterHandleWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QSPLITTERHANDLEWRAPPER_H

