/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QTABBARWRAPPER_H
#define SBK_QTABBARWRAPPER_H

#include <shiboken.h>

#include <qtabbar.h>

namespace PySide { class DynamicQMetaObject; }

class QTabBarWrapper : public QTabBar
{
public:
    QTabBarWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QTabBar::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QTabBar::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QTabBar::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QTabBar::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QTabBar::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QTabBar::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QTabBar::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QTabBar::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QTabBar::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QTabBar::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QTabBar::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QTabBar::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QTabBar::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QTabBar::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QTabBar::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QTabBar::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QTabBar::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QTabBar::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QTabBar::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QTabBar::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * arg__1) { QTabBar::hideEvent(arg__1); }
    virtual void hideEvent(QHideEvent * arg__1);
    inline void initStyleOption_protected(QStyleOptionTab * option, int tabIndex) const { QTabBar::initStyleOption(option, tabIndex); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QTabBar::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * arg__1) { QTabBar::keyPressEvent(arg__1); }
    virtual void keyPressEvent(QKeyEvent * arg__1);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QTabBar::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QTabBar::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QTabBar::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QTabBar::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QTabBar::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QTabBar::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QTabBar::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * arg__1) { QTabBar::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QMouseEvent * arg__1);
    inline void moveEvent_protected(QMoveEvent * event) { QTabBar::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QTabBar::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void resetInputContext_protected() { QTabBar::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * arg__1) { QTabBar::resizeEvent(arg__1); }
    virtual void resizeEvent(QResizeEvent * arg__1);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * arg__1) { QTabBar::showEvent(arg__1); }
    virtual void showEvent(QShowEvent * arg__1);
    virtual QSize sizeHint() const;
    inline void tabInserted_protected(int index) { QTabBar::tabInserted(index); }
    virtual void tabInserted(int index);
    inline void tabLayoutChange_protected() { QTabBar::tabLayoutChange(); }
    virtual void tabLayoutChange();
    inline void tabRemoved_protected(int index) { QTabBar::tabRemoved(index); }
    virtual void tabRemoved(int index);
    inline QSize tabSizeHint_protected(int index) const { return QTabBar::tabSizeHint(index); }
    virtual QSize tabSizeHint(int index) const;
    inline void tabletEvent_protected(QTabletEvent * event) { QTabBar::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QTabBar::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QTabBar::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QTabBar::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QTabBar::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QTabBarWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QTABBARWRAPPER_H

