/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QTABLEWIDGETWRAPPER_H
#define SBK_QTABLEWIDGETWRAPPER_H

#include <shiboken.h>

#include <qtablewidget.h>

namespace PySide { class DynamicQMetaObject; }

class QTableWidgetWrapper : public QTableWidget
{
public:
    QTableWidgetWrapper(QWidget * parent = 0);
    QTableWidgetWrapper(int rows, int columns, QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QTableWidget::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QTableWidget::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QTableWidget::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEditor_protected(QWidget * editor, int hint) { QTableWidget::closeEditor(editor, QAbstractItemDelegate::EndEditHint(hint)); }
    virtual void closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint);
    inline void closeEvent_protected(QCloseEvent * event) { QTableWidget::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void columnCountChanged_protected(int oldCount, int newCount) { QTableWidget::columnCountChanged(oldCount, newCount); }
    inline void columnMoved_protected(int column, int oldIndex, int newIndex) { QTableWidget::columnMoved(column, oldIndex, newIndex); }
    inline void columnResized_protected(int column, int oldWidth, int newWidth) { QTableWidget::columnResized(column, oldWidth, newWidth); }
    inline void commitData_protected(QWidget * editor) { QTableWidget::commitData(editor); }
    virtual void commitData(QWidget * editor);
    inline void connectNotify_protected(const char * signal) { QTableWidget::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QTableWidget::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void currentChanged_protected(const QModelIndex & current, const QModelIndex & previous) { QTableWidget::currentChanged(current, previous); }
    virtual void currentChanged(const QModelIndex & current, const QModelIndex & previous);
    inline void customEvent_protected(QEvent * arg__1) { QTableWidget::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void dataChanged_protected(const QModelIndex & topLeft, const QModelIndex & bottomRight) { QTableWidget::dataChanged(topLeft, bottomRight); }
    virtual void dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QTableWidget::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline QPoint dirtyRegionOffset_protected() const { return QTableWidget::dirtyRegionOffset(); }
    inline void disconnectNotify_protected(const char * signal) { QTableWidget::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void doAutoScroll_protected() { QTableWidget::doAutoScroll(); }
    virtual void doItemsLayout();
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QTableWidget::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QTableWidget::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QTableWidget::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void drawFrame_protected(QPainter * arg__1) { QTableWidget::drawFrame(arg__1); }
    inline void dropEvent_protected(QDropEvent * event) { QTableWidget::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline int dropIndicatorPosition_protected() const { return QTableWidget::dropIndicatorPosition(); }
    inline bool dropMimeData_protected(int row, int column, const QMimeData * data, int action) { return QTableWidget::dropMimeData(row, column, data, Qt::DropAction(action)); }
    virtual bool dropMimeData(int row, int column, const QMimeData * data, Qt::DropAction action);
    inline bool edit_protected(const QModelIndex & index, int trigger, QEvent * event) { return QTableWidget::edit(index, QAbstractItemView::EditTrigger(trigger), event); }
    virtual bool edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event);
    inline void editorDestroyed_protected(QObject * editor) { QTableWidget::editorDestroyed(editor); }
    virtual void editorDestroyed(QObject * editor);
    inline void enterEvent_protected(QEvent * event) { QTableWidget::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QTableWidget::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void executeDelayedItemsLayout_protected() { QTableWidget::executeDelayedItemsLayout(); }
    inline void focusInEvent_protected(QFocusEvent * event) { QTableWidget::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QTableWidget::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QTableWidget::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QTableWidget::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QTableWidget::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QTableWidget::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline int horizontalOffset_protected() const { return QTableWidget::horizontalOffset(); }
    virtual int horizontalOffset() const;
    inline void horizontalScrollbarAction_protected(int action) { QTableWidget::horizontalScrollbarAction(action); }
    virtual void horizontalScrollbarAction(int action);
    inline void horizontalScrollbarValueChanged_protected(int value) { QTableWidget::horizontalScrollbarValueChanged(value); }
    virtual void horizontalScrollbarValueChanged(int value);
    virtual QModelIndex indexAt(const QPoint & p) const;
    inline QModelIndex indexFromItem_protected(QTableWidgetItem * item) const { return QTableWidget::indexFromItem(item); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QTableWidget::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline bool isIndexHidden_protected(const QModelIndex & index) const { return QTableWidget::isIndexHidden(index); }
    virtual bool isIndexHidden(const QModelIndex & index) const;
    inline QTableWidgetItem * itemFromIndex_protected(const QModelIndex & index) const { return QTableWidget::itemFromIndex(index); }
    inline QList<QTableWidgetItem * > items_protected(const QMimeData * data) const { return QTableWidget::items(data); }
    inline void keyPressEvent_protected(QKeyEvent * event) { QTableWidget::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QTableWidget::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual void keyboardSearch(const QString & search);
    inline void languageChange_protected() { QTableWidget::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QTableWidget::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QTableWidget::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    inline QMimeData * mimeData_protected(const QList<QTableWidgetItem * > items) const { return QTableWidget::mimeData(items); }
    virtual QMimeData * mimeData(const QList<QTableWidgetItem * > items) const;
    inline QStringList mimeTypes_protected() const { return QTableWidget::mimeTypes(); }
    virtual QStringList mimeTypes() const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QTableWidget::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QTableWidget::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QTableWidget::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QTableWidget::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline QModelIndex moveCursor_protected(int cursorAction, int modifiers) { return QTableWidget::moveCursor(QAbstractItemView::CursorAction(cursorAction), QFlags<Qt::KeyboardModifier>(modifiers)); }
    virtual QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction, QFlags<Qt::KeyboardModifier> modifiers);
    inline void moveEvent_protected(QMoveEvent * event) { QTableWidget::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * e) { QTableWidget::paintEvent(e); }
    virtual void paintEvent(QPaintEvent * e);
    virtual void reset();
    inline void resetInputContext_protected() { QTableWidget::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QTableWidget::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    inline void rowCountChanged_protected(int oldCount, int newCount) { QTableWidget::rowCountChanged(oldCount, newCount); }
    inline void rowMoved_protected(int row, int oldIndex, int newIndex) { QTableWidget::rowMoved(row, oldIndex, newIndex); }
    inline void rowResized_protected(int row, int oldHeight, int newHeight) { QTableWidget::rowResized(row, oldHeight, newHeight); }
    inline void rowsAboutToBeRemoved_protected(const QModelIndex & parent, int start, int end) { QTableWidget::rowsAboutToBeRemoved(parent, start, end); }
    virtual void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end);
    inline void rowsInserted_protected(const QModelIndex & parent, int start, int end) { QTableWidget::rowsInserted(parent, start, end); }
    virtual void rowsInserted(const QModelIndex & parent, int start, int end);
    inline void scheduleDelayedItemsLayout_protected() { QTableWidget::scheduleDelayedItemsLayout(); }
    inline void scrollContentsBy_protected(int dx, int dy) { QTableWidget::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void scrollDirtyRegion_protected(int dx, int dy) { QTableWidget::scrollDirtyRegion(dx, dy); }
    virtual void scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint = EnsureVisible);
    virtual void selectAll();
    inline QModelIndexList selectedIndexes_protected() const { return QTableWidget::selectedIndexes(); }
    virtual QModelIndexList selectedIndexes() const;
    inline void selectionChanged_protected(const QItemSelection & selected, const QItemSelection & deselected) { QTableWidget::selectionChanged(selected, deselected); }
    virtual void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
    inline int selectionCommand_protected(const QModelIndex & index, const QEvent * event = 0) const { return QTableWidget::selectionCommand(index, event); }
    virtual QFlags<QItemSelectionModel::SelectionFlag> selectionCommand(const QModelIndex & index, const QEvent * event = 0) const;
    inline void setDirtyRegion_protected(const QRegion & region) { QTableWidget::setDirtyRegion(region); }
    virtual void setRootIndex(const QModelIndex & index);
    inline void setSelection_protected(const QRect & rect, int command) { QTableWidget::setSelection(rect, QFlags<QItemSelectionModel::SelectionFlag>(command)); }
    virtual void setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command);
    virtual void setSelectionModel(QItemSelectionModel * selectionModel);
    inline void setState_protected(int state) { QTableWidget::setState(QAbstractItemView::State(state)); }
    inline void setViewportMargins_protected(const QMargins & margins) { QTableWidget::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QTableWidget::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QTableWidget::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * event) { QTableWidget::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline int sizeHintForColumn_protected(int column) const { return QTableWidget::sizeHintForColumn(column); }
    virtual int sizeHintForColumn(int column) const;
    inline int sizeHintForRow_protected(int row) const { return QTableWidget::sizeHintForRow(row); }
    virtual int sizeHintForRow(int row) const;
    inline void startAutoScroll_protected() { QTableWidget::startAutoScroll(); }
    inline void startDrag_protected(int supportedActions) { QTableWidget::startDrag(QFlags<Qt::DropAction>(supportedActions)); }
    virtual void startDrag(QFlags<Qt::DropAction> supportedActions);
    inline int state_protected() const { return QTableWidget::state(); }
    inline void stopAutoScroll_protected() { QTableWidget::stopAutoScroll(); }
    inline int supportedDropActions_protected() const { return QTableWidget::supportedDropActions(); }
    virtual QFlags<Qt::DropAction> supportedDropActions() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QTableWidget::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * event) { QTableWidget::timerEvent(event); }
    virtual void timerEvent(QTimerEvent * event);
    inline void updateEditorData_protected() { QTableWidget::updateEditorData(); }
    virtual void updateEditorData();
    inline void updateEditorGeometries_protected() { QTableWidget::updateEditorGeometries(); }
    virtual void updateEditorGeometries();
    inline void updateGeometries_protected() { QTableWidget::updateGeometries(); }
    virtual void updateGeometries();
    inline void updateMicroFocus_protected() { QTableWidget::updateMicroFocus(); }
    inline int verticalOffset_protected() const { return QTableWidget::verticalOffset(); }
    virtual int verticalOffset() const;
    inline void verticalScrollbarAction_protected(int action) { QTableWidget::verticalScrollbarAction(action); }
    virtual void verticalScrollbarAction(int action);
    inline void verticalScrollbarValueChanged_protected(int value) { QTableWidget::verticalScrollbarValueChanged(value); }
    virtual void verticalScrollbarValueChanged(int value);
    inline QStyleOptionViewItem viewOptions_protected() const { return QTableWidget::viewOptions(); }
    virtual QStyleOptionViewItem viewOptions() const;
    inline bool viewportEvent_protected(QEvent * event) { return QTableWidget::viewportEvent(event); }
    virtual bool viewportEvent(QEvent * event);
    virtual QRect visualRect(const QModelIndex & index) const;
    inline QRegion visualRegionForSelection_protected(const QItemSelection & selection) const { return QTableWidget::visualRegionForSelection(selection); }
    virtual QRegion visualRegionForSelection(const QItemSelection & selection) const;
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QTableWidget::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QTableWidget::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QTableWidgetWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QTABLEWIDGETWRAPPER_H

