/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QTEXTBROWSERWRAPPER_H
#define SBK_QTEXTBROWSERWRAPPER_H

#include <shiboken.h>

#include <qtextbrowser.h>

namespace PySide { class DynamicQMetaObject; }

class QTextBrowserWrapper : public QTextBrowser
{
public:
    QTextBrowserWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QTextBrowser::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    virtual void backward();
    inline bool canInsertFromMimeData_protected(const QMimeData * source) const { return QTextBrowser::canInsertFromMimeData(source); }
    virtual bool canInsertFromMimeData(const QMimeData * source) const;
    inline void changeEvent_protected(QEvent * e) { QTextBrowser::changeEvent(e); }
    virtual void changeEvent(QEvent * e);
    inline void childEvent_protected(QChildEvent * arg__1) { QTextBrowser::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QTextBrowser::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QTextBrowser::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * e) { QTextBrowser::contextMenuEvent(e); }
    virtual void contextMenuEvent(QContextMenuEvent * e);
    inline QMimeData * createMimeDataFromSelection_protected() const { return QTextBrowser::createMimeDataFromSelection(); }
    virtual QMimeData * createMimeDataFromSelection() const;
    inline void customEvent_protected(QEvent * arg__1) { QTextBrowser::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QTextBrowser::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QTextBrowser::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * e) { QTextBrowser::dragEnterEvent(e); }
    virtual void dragEnterEvent(QDragEnterEvent * e);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * e) { QTextBrowser::dragLeaveEvent(e); }
    virtual void dragLeaveEvent(QDragLeaveEvent * e);
    inline void dragMoveEvent_protected(QDragMoveEvent * e) { QTextBrowser::dragMoveEvent(e); }
    virtual void dragMoveEvent(QDragMoveEvent * e);
    inline void drawFrame_protected(QPainter * arg__1) { QTextBrowser::drawFrame(arg__1); }
    inline void dropEvent_protected(QDropEvent * e) { QTextBrowser::dropEvent(e); }
    virtual void dropEvent(QDropEvent * e);
    inline void enterEvent_protected(QEvent * event) { QTextBrowser::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QTextBrowser::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * e) { QTextBrowser::focusInEvent(e); }
    virtual void focusInEvent(QFocusEvent * e);
    inline bool focusNextChild_protected() { return QTextBrowser::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QTextBrowser::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * ev) { QTextBrowser::focusOutEvent(ev); }
    virtual void focusOutEvent(QFocusEvent * ev);
    inline bool focusPreviousChild_protected() { return QTextBrowser::focusPreviousChild(); }
    virtual void forward();
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QTextBrowser::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    virtual void home();
    inline void inputMethodEvent_protected(QInputMethodEvent * arg__1) { QTextBrowser::inputMethodEvent(arg__1); }
    virtual void inputMethodEvent(QInputMethodEvent * arg__1);
    inline QVariant inputMethodQuery_protected(int property) const { return QTextBrowser::inputMethodQuery(Qt::InputMethodQuery(property)); }
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery property) const;
    inline void insertFromMimeData_protected(const QMimeData * source) { QTextBrowser::insertFromMimeData(source); }
    virtual void insertFromMimeData(const QMimeData * source);
    inline void keyPressEvent_protected(QKeyEvent * ev) { QTextBrowser::keyPressEvent(ev); }
    virtual void keyPressEvent(QKeyEvent * ev);
    inline void keyReleaseEvent_protected(QKeyEvent * e) { QTextBrowser::keyReleaseEvent(e); }
    virtual void keyReleaseEvent(QKeyEvent * e);
    inline void languageChange_protected() { QTextBrowser::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QTextBrowser::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual QVariant loadResource(int type, const QUrl & name);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QTextBrowser::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * e) { QTextBrowser::mouseDoubleClickEvent(e); }
    virtual void mouseDoubleClickEvent(QMouseEvent * e);
    inline void mouseMoveEvent_protected(QMouseEvent * ev) { QTextBrowser::mouseMoveEvent(ev); }
    virtual void mouseMoveEvent(QMouseEvent * ev);
    inline void mousePressEvent_protected(QMouseEvent * ev) { QTextBrowser::mousePressEvent(ev); }
    virtual void mousePressEvent(QMouseEvent * ev);
    inline void mouseReleaseEvent_protected(QMouseEvent * ev) { QTextBrowser::mouseReleaseEvent(ev); }
    virtual void mouseReleaseEvent(QMouseEvent * ev);
    inline void moveEvent_protected(QMoveEvent * event) { QTextBrowser::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * e) { QTextBrowser::paintEvent(e); }
    virtual void paintEvent(QPaintEvent * e);
    virtual void reload();
    inline void resetInputContext_protected() { QTextBrowser::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * e) { QTextBrowser::resizeEvent(e); }
    virtual void resizeEvent(QResizeEvent * e);
    inline void scrollContentsBy_protected(int dx, int dy) { QTextBrowser::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    virtual void setSource(const QUrl & name);
    inline void setViewportMargins_protected(const QMargins & margins) { QTextBrowser::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QTextBrowser::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QTextBrowser::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * arg__1) { QTextBrowser::showEvent(arg__1); }
    virtual void showEvent(QShowEvent * arg__1);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QTextBrowser::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * e) { QTextBrowser::timerEvent(e); }
    virtual void timerEvent(QTimerEvent * e);
    inline void updateMicroFocus_protected() { QTextBrowser::updateMicroFocus(); }
    inline bool viewportEvent_protected(QEvent * arg__1) { return QTextBrowser::viewportEvent(arg__1); }
    virtual bool viewportEvent(QEvent * arg__1);
    inline void wheelEvent_protected(QWheelEvent * e) { QTextBrowser::wheelEvent(e); }
    virtual void wheelEvent(QWheelEvent * e);
    inline bool winEvent_protected(MSG * message, long * result) { return QTextBrowser::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QTextBrowserWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QTEXTBROWSERWRAPPER_H

