/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QTIMEEDITWRAPPER_H
#define SBK_QTIMEEDITWRAPPER_H

#include <shiboken.h>

#include <qdatetimeedit.h>

namespace PySide { class DynamicQMetaObject; }

class QTimeEditWrapper : public QTimeEdit
{
public:
    QTimeEditWrapper(QWidget * parent = 0);
    QTimeEditWrapper(const QTime & time, QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QTimeEdit::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * event) { QTimeEdit::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QTimeEdit::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual void clear();
    inline void closeEvent_protected(QCloseEvent * event) { QTimeEdit::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QTimeEdit::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QTimeEdit::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QTimeEdit::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline QDateTime dateTimeFromText_protected(const QString & text) const { return QTimeEdit::dateTimeFromText(text); }
    virtual QDateTime dateTimeFromText(const QString & text) const;
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QTimeEdit::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QTimeEdit::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QTimeEdit::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QTimeEdit::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QTimeEdit::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QTimeEdit::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QTimeEdit::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    virtual bool event(QEvent * event);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void fixup_protected(QString & input) const { QTimeEdit::fixup(input); }
    virtual void fixup(QString & input) const;
    inline void focusInEvent_protected(QFocusEvent * event) { QTimeEdit::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QTimeEdit::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QTimeEdit::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QTimeEdit::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QTimeEdit::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QTimeEdit::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void initStyleOption_protected(QStyleOptionSpinBox * option) const { QTimeEdit::initStyleOption(option); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QTimeEdit::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QTimeEdit::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QTimeEdit::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QTimeEdit::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QTimeEdit::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    inline QLineEdit * lineEdit_protected() const { return QTimeEdit::lineEdit(); }
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QTimeEdit::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QTimeEdit::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QTimeEdit::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QTimeEdit::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QTimeEdit::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline void moveEvent_protected(QMoveEvent * event) { QTimeEdit::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * event) { QTimeEdit::paintEvent(event); }
    virtual void paintEvent(QPaintEvent * event);
    inline void resetInputContext_protected() { QTimeEdit::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QTimeEdit::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    inline void setLineEdit_protected(QLineEdit * edit) { QTimeEdit::setLineEdit(edit); }
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QTimeEdit::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    virtual void stepBy(int steps);
    inline int stepEnabled_protected() const { return QTimeEdit::stepEnabled(); }
    virtual QFlags<QAbstractSpinBox::StepEnabledFlag> stepEnabled() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QTimeEdit::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline QString textFromDateTime_protected(const QDateTime & dt) const { return QTimeEdit::textFromDateTime(dt); }
    virtual QString textFromDateTime(const QDateTime & dt) const;
    inline void timerEvent_protected(QTimerEvent * event) { QTimeEdit::timerEvent(event); }
    virtual void timerEvent(QTimerEvent * event);
    inline void updateMicroFocus_protected() { QTimeEdit::updateMicroFocus(); }
    inline int validate_protected(QString & input, int & pos) const { return QTimeEdit::validate(input, pos); }
    virtual QValidator::State validate(QString & input, int & pos) const;
    inline void wheelEvent_protected(QWheelEvent * event) { QTimeEdit::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QTimeEdit::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QTimeEditWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QTIMEEDITWRAPPER_H

