/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QTOOLBUTTONWRAPPER_H
#define SBK_QTOOLBUTTONWRAPPER_H

#include <shiboken.h>

#include <qtoolbutton.h>

namespace PySide { class DynamicQMetaObject; }

class QToolButtonWrapper : public QToolButton
{
public:
    QToolButtonWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * arg__1) { QToolButton::actionEvent(arg__1); }
    virtual void actionEvent(QActionEvent * arg__1);
    inline void changeEvent_protected(QEvent * arg__1) { QToolButton::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void checkStateSet_protected() { QToolButton::checkStateSet(); }
    virtual void checkStateSet();
    inline void childEvent_protected(QChildEvent * arg__1) { QToolButton::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QToolButton::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QToolButton::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QToolButton::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QToolButton::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QToolButton::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QToolButton::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QToolButton::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QToolButton::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QToolButton::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QToolButton::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * arg__1) { QToolButton::enterEvent(arg__1); }
    virtual void enterEvent(QEvent * arg__1);
    inline bool event_protected(QEvent * e) { return QToolButton::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * e) { QToolButton::focusInEvent(e); }
    virtual void focusInEvent(QFocusEvent * e);
    inline bool focusNextChild_protected() { return QToolButton::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QToolButton::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * e) { QToolButton::focusOutEvent(e); }
    virtual void focusOutEvent(QFocusEvent * e);
    inline bool focusPreviousChild_protected() { return QToolButton::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QToolButton::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline bool hitButton_protected(const QPoint & pos) const { return QToolButton::hitButton(pos); }
    virtual bool hitButton(const QPoint & pos) const;
    inline void initStyleOption_protected(QStyleOptionToolButton * option) const { QToolButton::initStyleOption(option); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QToolButton::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * e) { QToolButton::keyPressEvent(e); }
    virtual void keyPressEvent(QKeyEvent * e);
    inline void keyReleaseEvent_protected(QKeyEvent * e) { QToolButton::keyReleaseEvent(e); }
    virtual void keyReleaseEvent(QKeyEvent * e);
    inline void languageChange_protected() { QToolButton::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * arg__1) { QToolButton::leaveEvent(arg__1); }
    virtual void leaveEvent(QEvent * arg__1);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QToolButton::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QToolButton::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * e) { QToolButton::mouseMoveEvent(e); }
    virtual void mouseMoveEvent(QMouseEvent * e);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QToolButton::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * arg__1) { QToolButton::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QMouseEvent * arg__1);
    inline void moveEvent_protected(QMoveEvent * event) { QToolButton::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    inline void nextCheckState_protected() { QToolButton::nextCheckState(); }
    virtual void nextCheckState();
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QToolButton::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void resetInputContext_protected() { QToolButton::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QToolButton::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QToolButton::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QToolButton::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QToolButton::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QToolButton::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * event) { QToolButton::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QToolButton::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QToolButtonWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QTOOLBUTTONWRAPPER_H

