/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QTREEWIDGETWRAPPER_H
#define SBK_QTREEWIDGETWRAPPER_H

#include <shiboken.h>

#include <qtreewidget.h>

namespace PySide { class DynamicQMetaObject; }

class QTreeWidgetWrapper : public QTreeWidget
{
public:
    QTreeWidgetWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QTreeWidget::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QTreeWidget::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QTreeWidget::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEditor_protected(QWidget * editor, int hint) { QTreeWidget::closeEditor(editor, QAbstractItemDelegate::EndEditHint(hint)); }
    virtual void closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint);
    inline void closeEvent_protected(QCloseEvent * event) { QTreeWidget::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void columnCountChanged_protected(int oldCount, int newCount) { QTreeWidget::columnCountChanged(oldCount, newCount); }
    inline void columnMoved_protected() { QTreeWidget::columnMoved(); }
    inline void columnResized_protected(int column, int oldSize, int newSize) { QTreeWidget::columnResized(column, oldSize, newSize); }
    inline void commitData_protected(QWidget * editor) { QTreeWidget::commitData(editor); }
    virtual void commitData(QWidget * editor);
    inline void connectNotify_protected(const char * signal) { QTreeWidget::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QTreeWidget::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void currentChanged_protected(const QModelIndex & current, const QModelIndex & previous) { QTreeWidget::currentChanged(current, previous); }
    virtual void currentChanged(const QModelIndex & current, const QModelIndex & previous);
    inline void customEvent_protected(QEvent * arg__1) { QTreeWidget::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    virtual void dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QTreeWidget::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline QPoint dirtyRegionOffset_protected() const { return QTreeWidget::dirtyRegionOffset(); }
    inline void disconnectNotify_protected(const char * signal) { QTreeWidget::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void doAutoScroll_protected() { QTreeWidget::doAutoScroll(); }
    virtual void doItemsLayout();
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QTreeWidget::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QTreeWidget::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QTreeWidget::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void drawBranches_protected(QPainter * painter, const QRect & rect, const QModelIndex & index) const { QTreeWidget::drawBranches(painter, rect, index); }
    virtual void drawBranches(QPainter * painter, const QRect & rect, const QModelIndex & index) const;
    inline void drawFrame_protected(QPainter * arg__1) { QTreeWidget::drawFrame(arg__1); }
    inline void drawRow_protected(QPainter * painter, const QStyleOptionViewItem & options, const QModelIndex & index) const { QTreeWidget::drawRow(painter, options, index); }
    virtual void drawRow(QPainter * painter, const QStyleOptionViewItem & options, const QModelIndex & index) const;
    inline void drawTree_protected(QPainter * painter, const QRegion & region) const { QTreeWidget::drawTree(painter, region); }
    inline void dropEvent_protected(QDropEvent * event) { QTreeWidget::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline int dropIndicatorPosition_protected() const { return QTreeWidget::dropIndicatorPosition(); }
    inline bool dropMimeData_protected(QTreeWidgetItem * parent, int index, const QMimeData * data, int action) { return QTreeWidget::dropMimeData(parent, index, data, Qt::DropAction(action)); }
    virtual bool dropMimeData(QTreeWidgetItem * parent, int index, const QMimeData * data, Qt::DropAction action);
    inline bool edit_protected(const QModelIndex & index, int trigger, QEvent * event) { return QTreeWidget::edit(index, QAbstractItemView::EditTrigger(trigger), event); }
    virtual bool edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event);
    inline void editorDestroyed_protected(QObject * editor) { QTreeWidget::editorDestroyed(editor); }
    virtual void editorDestroyed(QObject * editor);
    inline void enterEvent_protected(QEvent * event) { QTreeWidget::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QTreeWidget::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void executeDelayedItemsLayout_protected() { QTreeWidget::executeDelayedItemsLayout(); }
    inline void focusInEvent_protected(QFocusEvent * event) { QTreeWidget::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QTreeWidget::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QTreeWidget::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QTreeWidget::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QTreeWidget::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QTreeWidget::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline int horizontalOffset_protected() const { return QTreeWidget::horizontalOffset(); }
    virtual int horizontalOffset() const;
    inline void horizontalScrollbarAction_protected(int action) { QTreeWidget::horizontalScrollbarAction(action); }
    virtual void horizontalScrollbarAction(int action);
    inline void horizontalScrollbarValueChanged_protected(int value) { QTreeWidget::horizontalScrollbarValueChanged(value); }
    virtual void horizontalScrollbarValueChanged(int value);
    virtual QModelIndex indexAt(const QPoint & p) const;
    inline QModelIndex indexFromItem_protected(QTreeWidgetItem * item, int column = 0) const { return QTreeWidget::indexFromItem(item, column); }
    inline int indexRowSizeHint_protected(const QModelIndex & index) const { return QTreeWidget::indexRowSizeHint(index); }
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QTreeWidget::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline bool isIndexHidden_protected(const QModelIndex & index) const { return QTreeWidget::isIndexHidden(index); }
    virtual bool isIndexHidden(const QModelIndex & index) const;
    inline QTreeWidgetItem * itemFromIndex_protected(const QModelIndex & index) const { return QTreeWidget::itemFromIndex(index); }
    inline QList<QTreeWidgetItem * > items_protected(const QMimeData * data) const { return QTreeWidget::items(data); }
    inline void keyPressEvent_protected(QKeyEvent * event) { QTreeWidget::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QTreeWidget::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual void keyboardSearch(const QString & search);
    inline void languageChange_protected() { QTreeWidget::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QTreeWidget::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QTreeWidget::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    inline QMimeData * mimeData_protected(const QList<QTreeWidgetItem * > items) const { return QTreeWidget::mimeData(items); }
    virtual QMimeData * mimeData(const QList<QTreeWidgetItem * > items) const;
    inline QStringList mimeTypes_protected() const { return QTreeWidget::mimeTypes(); }
    virtual QStringList mimeTypes() const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QTreeWidget::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QTreeWidget::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QTreeWidget::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QTreeWidget::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline QModelIndex moveCursor_protected(int cursorAction, int modifiers) { return QTreeWidget::moveCursor(QAbstractItemView::CursorAction(cursorAction), QFlags<Qt::KeyboardModifier>(modifiers)); }
    virtual QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction, QFlags<Qt::KeyboardModifier> modifiers);
    inline void moveEvent_protected(QMoveEvent * event) { QTreeWidget::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * event) { QTreeWidget::paintEvent(event); }
    virtual void paintEvent(QPaintEvent * event);
    inline void reexpand_protected() { QTreeWidget::reexpand(); }
    virtual void reset();
    inline void resetInputContext_protected() { QTreeWidget::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QTreeWidget::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    inline int rowHeight_protected(const QModelIndex & index) const { return QTreeWidget::rowHeight(index); }
    inline void rowsAboutToBeRemoved_protected(const QModelIndex & parent, int start, int end) { QTreeWidget::rowsAboutToBeRemoved(parent, start, end); }
    virtual void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end);
    inline void rowsInserted_protected(const QModelIndex & parent, int start, int end) { QTreeWidget::rowsInserted(parent, start, end); }
    virtual void rowsInserted(const QModelIndex & parent, int start, int end);
    inline void rowsRemoved_protected(const QModelIndex & parent, int first, int last) { QTreeWidget::rowsRemoved(parent, first, last); }
    inline void scheduleDelayedItemsLayout_protected() { QTreeWidget::scheduleDelayedItemsLayout(); }
    inline void scrollContentsBy_protected(int dx, int dy) { QTreeWidget::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void scrollDirtyRegion_protected(int dx, int dy) { QTreeWidget::scrollDirtyRegion(dx, dy); }
    virtual void scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint = EnsureVisible);
    virtual void selectAll();
    inline QModelIndexList selectedIndexes_protected() const { return QTreeWidget::selectedIndexes(); }
    virtual QModelIndexList selectedIndexes() const;
    inline void selectionChanged_protected(const QItemSelection & selected, const QItemSelection & deselected) { QTreeWidget::selectionChanged(selected, deselected); }
    virtual void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
    inline int selectionCommand_protected(const QModelIndex & index, const QEvent * event = 0) const { return QTreeWidget::selectionCommand(index, event); }
    virtual QFlags<QItemSelectionModel::SelectionFlag> selectionCommand(const QModelIndex & index, const QEvent * event = 0) const;
    inline void setDirtyRegion_protected(const QRegion & region) { QTreeWidget::setDirtyRegion(region); }
    virtual void setRootIndex(const QModelIndex & index);
    inline void setSelection_protected(const QRect & rect, int command) { QTreeWidget::setSelection(rect, QFlags<QItemSelectionModel::SelectionFlag>(command)); }
    virtual void setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command);
    virtual void setSelectionModel(QItemSelectionModel * selectionModel);
    inline void setState_protected(int state) { QTreeWidget::setState(QAbstractItemView::State(state)); }
    inline void setViewportMargins_protected(const QMargins & margins) { QTreeWidget::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QTreeWidget::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QTreeWidget::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * event) { QTreeWidget::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline int sizeHintForColumn_protected(int column) const { return QTreeWidget::sizeHintForColumn(column); }
    virtual int sizeHintForColumn(int column) const;
    virtual int sizeHintForRow(int row) const;
    inline void startAutoScroll_protected() { QTreeWidget::startAutoScroll(); }
    inline void startDrag_protected(int supportedActions) { QTreeWidget::startDrag(QFlags<Qt::DropAction>(supportedActions)); }
    virtual void startDrag(QFlags<Qt::DropAction> supportedActions);
    inline int state_protected() const { return QTreeWidget::state(); }
    inline void stopAutoScroll_protected() { QTreeWidget::stopAutoScroll(); }
    inline int supportedDropActions_protected() const { return QTreeWidget::supportedDropActions(); }
    virtual QFlags<Qt::DropAction> supportedDropActions() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QTreeWidget::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * event) { QTreeWidget::timerEvent(event); }
    virtual void timerEvent(QTimerEvent * event);
    inline void updateEditorData_protected() { QTreeWidget::updateEditorData(); }
    virtual void updateEditorData();
    inline void updateEditorGeometries_protected() { QTreeWidget::updateEditorGeometries(); }
    virtual void updateEditorGeometries();
    inline void updateGeometries_protected() { QTreeWidget::updateGeometries(); }
    virtual void updateGeometries();
    inline void updateMicroFocus_protected() { QTreeWidget::updateMicroFocus(); }
    inline int verticalOffset_protected() const { return QTreeWidget::verticalOffset(); }
    virtual int verticalOffset() const;
    inline void verticalScrollbarAction_protected(int action) { QTreeWidget::verticalScrollbarAction(action); }
    virtual void verticalScrollbarAction(int action);
    inline void verticalScrollbarValueChanged_protected(int value) { QTreeWidget::verticalScrollbarValueChanged(value); }
    virtual void verticalScrollbarValueChanged(int value);
    inline QStyleOptionViewItem viewOptions_protected() const { return QTreeWidget::viewOptions(); }
    virtual QStyleOptionViewItem viewOptions() const;
    inline bool viewportEvent_protected(QEvent * event) { return QTreeWidget::viewportEvent(event); }
    virtual bool viewportEvent(QEvent * event);
    virtual QRect visualRect(const QModelIndex & index) const;
    inline QRegion visualRegionForSelection_protected(const QItemSelection & selection) const { return QTreeWidget::visualRegionForSelection(selection); }
    virtual QRegion visualRegionForSelection(const QItemSelection & selection) const;
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QTreeWidget::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QTreeWidget::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QTreeWidgetWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QTREEWIDGETWRAPPER_H

