/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QUNDOVIEWWRAPPER_H
#define SBK_QUNDOVIEWWRAPPER_H

#include <shiboken.h>

#include <qundoview.h>

namespace PySide { class DynamicQMetaObject; }

class QUndoViewWrapper : public QUndoView
{
public:
    QUndoViewWrapper(QUndoGroup * group, QWidget * parent = 0);
    QUndoViewWrapper(QUndoStack * stack, QWidget * parent = 0);
    QUndoViewWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QUndoView::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QUndoView::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QUndoView::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEditor_protected(QWidget * editor, int hint) { QUndoView::closeEditor(editor, QAbstractItemDelegate::EndEditHint(hint)); }
    virtual void closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint);
    inline void closeEvent_protected(QCloseEvent * event) { QUndoView::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void commitData_protected(QWidget * editor) { QUndoView::commitData(editor); }
    virtual void commitData(QWidget * editor);
    inline void connectNotify_protected(const char * signal) { QUndoView::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline QSize contentsSize_protected() const { return QUndoView::contentsSize(); }
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QUndoView::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline void currentChanged_protected(const QModelIndex & current, const QModelIndex & previous) { QUndoView::currentChanged(current, previous); }
    virtual void currentChanged(const QModelIndex & current, const QModelIndex & previous);
    inline void customEvent_protected(QEvent * arg__1) { QUndoView::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void dataChanged_protected(const QModelIndex & topLeft, const QModelIndex & bottomRight) { QUndoView::dataChanged(topLeft, bottomRight); }
    virtual void dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QUndoView::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline QPoint dirtyRegionOffset_protected() const { return QUndoView::dirtyRegionOffset(); }
    inline void disconnectNotify_protected(const char * signal) { QUndoView::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void doAutoScroll_protected() { QUndoView::doAutoScroll(); }
    virtual void doItemsLayout();
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QUndoView::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * e) { QUndoView::dragLeaveEvent(e); }
    virtual void dragLeaveEvent(QDragLeaveEvent * e);
    inline void dragMoveEvent_protected(QDragMoveEvent * e) { QUndoView::dragMoveEvent(e); }
    virtual void dragMoveEvent(QDragMoveEvent * e);
    inline void drawFrame_protected(QPainter * arg__1) { QUndoView::drawFrame(arg__1); }
    inline void dropEvent_protected(QDropEvent * e) { QUndoView::dropEvent(e); }
    virtual void dropEvent(QDropEvent * e);
    inline int dropIndicatorPosition_protected() const { return QUndoView::dropIndicatorPosition(); }
    inline bool edit_protected(const QModelIndex & index, int trigger, QEvent * event) { return QUndoView::edit(index, QAbstractItemView::EditTrigger(trigger), event); }
    virtual bool edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event);
    inline void editorDestroyed_protected(QObject * editor) { QUndoView::editorDestroyed(editor); }
    virtual void editorDestroyed(QObject * editor);
    inline void enterEvent_protected(QEvent * event) { QUndoView::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * e) { return QUndoView::event(e); }
    virtual bool event(QEvent * e);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void executeDelayedItemsLayout_protected() { QUndoView::executeDelayedItemsLayout(); }
    inline void focusInEvent_protected(QFocusEvent * event) { QUndoView::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QUndoView::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QUndoView::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QUndoView::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QUndoView::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QUndoView::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline int horizontalOffset_protected() const { return QUndoView::horizontalOffset(); }
    virtual int horizontalOffset() const;
    inline void horizontalScrollbarAction_protected(int action) { QUndoView::horizontalScrollbarAction(action); }
    virtual void horizontalScrollbarAction(int action);
    inline void horizontalScrollbarValueChanged_protected(int value) { QUndoView::horizontalScrollbarValueChanged(value); }
    virtual void horizontalScrollbarValueChanged(int value);
    virtual QModelIndex indexAt(const QPoint & p) const;
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QUndoView::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    inline void internalDrag_protected(int supportedActions) { QUndoView::internalDrag(QFlags<Qt::DropAction>(supportedActions)); }
    inline void internalDrop_protected(QDropEvent * e) { QUndoView::internalDrop(e); }
    inline bool isIndexHidden_protected(const QModelIndex & index) const { return QUndoView::isIndexHidden(index); }
    virtual bool isIndexHidden(const QModelIndex & index) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QUndoView::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QUndoView::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual void keyboardSearch(const QString & search);
    inline void languageChange_protected() { QUndoView::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QUndoView::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QUndoView::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QUndoView::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * e) { QUndoView::mouseMoveEvent(e); }
    virtual void mouseMoveEvent(QMouseEvent * e);
    inline void mousePressEvent_protected(QMouseEvent * event) { QUndoView::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * e) { QUndoView::mouseReleaseEvent(e); }
    virtual void mouseReleaseEvent(QMouseEvent * e);
    inline QModelIndex moveCursor_protected(int cursorAction, int modifiers) { return QUndoView::moveCursor(QAbstractItemView::CursorAction(cursorAction), QFlags<Qt::KeyboardModifier>(modifiers)); }
    virtual QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction, QFlags<Qt::KeyboardModifier> modifiers);
    inline void moveEvent_protected(QMoveEvent * event) { QUndoView::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * e) { QUndoView::paintEvent(e); }
    virtual void paintEvent(QPaintEvent * e);
    inline QRect rectForIndex_protected(const QModelIndex & index) const { return QUndoView::rectForIndex(index); }
    virtual void reset();
    inline void resetInputContext_protected() { QUndoView::resetInputContext(); }
    inline void resizeContents_protected(int width, int height) { QUndoView::resizeContents(width, height); }
    inline void resizeEvent_protected(QResizeEvent * e) { QUndoView::resizeEvent(e); }
    virtual void resizeEvent(QResizeEvent * e);
    inline void rowsAboutToBeRemoved_protected(const QModelIndex & parent, int start, int end) { QUndoView::rowsAboutToBeRemoved(parent, start, end); }
    virtual void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end);
    inline void rowsInserted_protected(const QModelIndex & parent, int start, int end) { QUndoView::rowsInserted(parent, start, end); }
    virtual void rowsInserted(const QModelIndex & parent, int start, int end);
    inline void scheduleDelayedItemsLayout_protected() { QUndoView::scheduleDelayedItemsLayout(); }
    inline void scrollContentsBy_protected(int dx, int dy) { QUndoView::scrollContentsBy(dx, dy); }
    virtual void scrollContentsBy(int dx, int dy);
    inline void scrollDirtyRegion_protected(int dx, int dy) { QUndoView::scrollDirtyRegion(dx, dy); }
    virtual void scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint = EnsureVisible);
    virtual void selectAll();
    inline QModelIndexList selectedIndexes_protected() const { return QUndoView::selectedIndexes(); }
    virtual QModelIndexList selectedIndexes() const;
    inline void selectionChanged_protected(const QItemSelection & selected, const QItemSelection & deselected) { QUndoView::selectionChanged(selected, deselected); }
    virtual void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
    inline int selectionCommand_protected(const QModelIndex & index, const QEvent * event = 0) const { return QUndoView::selectionCommand(index, event); }
    virtual QFlags<QItemSelectionModel::SelectionFlag> selectionCommand(const QModelIndex & index, const QEvent * event = 0) const;
    inline void setDirtyRegion_protected(const QRegion & region) { QUndoView::setDirtyRegion(region); }
    virtual void setModel(QAbstractItemModel * model);
    inline void setPositionForIndex_protected(const QPoint & position, const QModelIndex & index) { QUndoView::setPositionForIndex(position, index); }
    virtual void setRootIndex(const QModelIndex & index);
    inline void setSelection_protected(const QRect & rect, int command) { QUndoView::setSelection(rect, QFlags<QItemSelectionModel::SelectionFlag>(command)); }
    virtual void setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command);
    virtual void setSelectionModel(QItemSelectionModel * selectionModel);
    inline void setState_protected(int state) { QUndoView::setState(QAbstractItemView::State(state)); }
    inline void setViewportMargins_protected(const QMargins & margins) { QUndoView::setViewportMargins(margins); }
    inline void setViewportMargins_protected(int left, int top, int right, int bottom) { QUndoView::setViewportMargins(left, top, right, bottom); }
    virtual void setVisible(bool visible);
    inline void setupViewport_protected(QWidget * viewport) { QUndoView::setupViewport(viewport); }
    inline void showEvent_protected(QShowEvent * event) { QUndoView::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    virtual int sizeHintForColumn(int column) const;
    virtual int sizeHintForRow(int row) const;
    inline void startAutoScroll_protected() { QUndoView::startAutoScroll(); }
    inline void startDrag_protected(int supportedActions) { QUndoView::startDrag(QFlags<Qt::DropAction>(supportedActions)); }
    virtual void startDrag(QFlags<Qt::DropAction> supportedActions);
    inline int state_protected() const { return QUndoView::state(); }
    inline void stopAutoScroll_protected() { QUndoView::stopAutoScroll(); }
    inline void tabletEvent_protected(QTabletEvent * event) { QUndoView::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * e) { QUndoView::timerEvent(e); }
    virtual void timerEvent(QTimerEvent * e);
    inline void updateEditorData_protected() { QUndoView::updateEditorData(); }
    virtual void updateEditorData();
    inline void updateEditorGeometries_protected() { QUndoView::updateEditorGeometries(); }
    virtual void updateEditorGeometries();
    inline void updateGeometries_protected() { QUndoView::updateGeometries(); }
    virtual void updateGeometries();
    inline void updateMicroFocus_protected() { QUndoView::updateMicroFocus(); }
    inline int verticalOffset_protected() const { return QUndoView::verticalOffset(); }
    virtual int verticalOffset() const;
    inline void verticalScrollbarAction_protected(int action) { QUndoView::verticalScrollbarAction(action); }
    virtual void verticalScrollbarAction(int action);
    inline void verticalScrollbarValueChanged_protected(int value) { QUndoView::verticalScrollbarValueChanged(value); }
    virtual void verticalScrollbarValueChanged(int value);
    inline QStyleOptionViewItem viewOptions_protected() const { return QUndoView::viewOptions(); }
    virtual QStyleOptionViewItem viewOptions() const;
    inline bool viewportEvent_protected(QEvent * event) { return QUndoView::viewportEvent(event); }
    virtual bool viewportEvent(QEvent * event);
    virtual QRect visualRect(const QModelIndex & index) const;
    inline QRegion visualRegionForSelection_protected(const QItemSelection & selection) const { return QUndoView::visualRegionForSelection(selection); }
    virtual QRegion visualRegionForSelection(const QItemSelection & selection) const;
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QUndoView::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QUndoView::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QUndoViewWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QUNDOVIEWWRAPPER_H

