/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QWIZARDPAGEWRAPPER_H
#define SBK_QWIZARDPAGEWRAPPER_H

#include <shiboken.h>

#include <qwizard.h>

namespace PySide { class DynamicQMetaObject; }

class QWizardPageWrapper : public QWizardPage
{
public:
    QWizardPageWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QWizardPage::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * event) { QWizardPage::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QWizardPage::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual void cleanupPage();
    inline void closeEvent_protected(QCloseEvent * event) { QWizardPage::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QWizardPage::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QWizardPage::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QWizardPage::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QWizardPage::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QWizardPage::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QWizardPage::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QWizardPage::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QWizardPage::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QWizardPage::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QWizardPage::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QWizardPage::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline QVariant field_protected(const QString & name) const { return QWizardPage::field(name); }
    inline void focusInEvent_protected(QFocusEvent * event) { QWizardPage::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QWizardPage::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QWizardPage::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QWizardPage::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QWizardPage::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QWizardPage::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    virtual void initializePage();
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QWizardPage::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    virtual bool isComplete() const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QWizardPage::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QWizardPage::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QWizardPage::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QWizardPage::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QWizardPage::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QWizardPage::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QWizardPage::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QWizardPage::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QWizardPage::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline void moveEvent_protected(QMoveEvent * event) { QWizardPage::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual int nextId() const;
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * event) { QWizardPage::paintEvent(event); }
    virtual void paintEvent(QPaintEvent * event);
    inline void registerField_protected(const QString & name, QWidget * widget, const char * property = 0, const char * changedSignal = 0) { QWizardPage::registerField(name, widget, property, changedSignal); }
    inline void resetInputContext_protected() { QWizardPage::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * event) { QWizardPage::resizeEvent(event); }
    virtual void resizeEvent(QResizeEvent * event);
    inline void setField_protected(const QString & name, const QVariant & value) { QWizardPage::setField(name, value); }
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QWizardPage::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QWizardPage::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QWizardPage::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QWizardPage::updateMicroFocus(); }
    virtual bool validatePage();
    inline void wheelEvent_protected(QWheelEvent * event) { QWizardPage::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QWizardPage::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    inline QWizard * wizard_protected() const { return QWizardPage::wizard(); }
    virtual ~QWizardPageWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QWIZARDPAGEWRAPPER_H

