/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QNETWORKREPLYWRAPPER_H
#define SBK_QNETWORKREPLYWRAPPER_H

#include <shiboken.h>

#include <qnetworkreply.h>

namespace PySide { class DynamicQMetaObject; }

class QNetworkReplyWrapper : public QNetworkReply
{
public:
    QNetworkReplyWrapper(QObject * parent = 0);
    virtual void abort();
    virtual bool atEnd() const;
    virtual qint64 bytesAvailable() const;
    virtual qint64 bytesToWrite() const;
    virtual bool canReadLine() const;
    inline void childEvent_protected(QChildEvent * arg__1) { QNetworkReply::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual void close();
    inline void connectNotify_protected(const char * signal) { QNetworkReply::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void customEvent_protected(QEvent * arg__1) { QNetworkReply::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QNetworkReply::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    virtual void ignoreSslErrors();
    virtual bool isSequential() const;
    virtual const QMetaObject * metaObject() const;
    virtual bool open(QFlags<QIODevice::OpenModeFlag> mode);
    virtual qint64 pos() const;
    inline qint64 readData_protected(char * data, qint64 maxlen) { return readData(data, maxlen); }
    virtual qint64 readData(char * data, qint64 maxlen);
    inline qint64 readLineData_protected(char * data, qint64 maxlen) { return QNetworkReply::readLineData(data, maxlen); }
    virtual qint64 readLineData(char * data, qint64 maxlen);
    inline int receivers_protected(const char * signal) const { return QNetworkReply::receivers(signal); }
    virtual bool reset();
    virtual bool seek(qint64 pos);
    inline QObject * sender_protected() const { return QNetworkReply::sender(); }
    inline int senderSignalIndex_protected() const { return QNetworkReply::senderSignalIndex(); }
    inline void setAttribute_protected(int code, const QVariant & value) { QNetworkReply::setAttribute(QNetworkRequest::Attribute(code), value); }
    inline void setError_protected(int errorCode, const QString & errorString) { QNetworkReply::setError(QNetworkReply::NetworkError(errorCode), errorString); }
    inline void setErrorString_protected(const QString & errorString) { QNetworkReply::setErrorString(errorString); }
    inline void setFinished_protected(bool arg__1) { QNetworkReply::setFinished(arg__1); }
    inline void setHeader_protected(int header, const QVariant & value) { QNetworkReply::setHeader(QNetworkRequest::KnownHeaders(header), value); }
    inline void setOpenMode_protected(int openMode) { QNetworkReply::setOpenMode(QFlags<QIODevice::OpenModeFlag>(openMode)); }
    inline void setOperation_protected(int operation) { QNetworkReply::setOperation(QNetworkAccessManager::Operation(operation)); }
    inline void setRawHeader_protected(const QByteArray & headerName, const QByteArray & value) { QNetworkReply::setRawHeader(headerName, value); }
    virtual void setReadBufferSize(qint64 size);
    inline void setRequest_protected(const QNetworkRequest & request) { QNetworkReply::setRequest(request); }
    inline void setUrl_protected(const QUrl & url) { QNetworkReply::setUrl(url); }
    virtual qint64 size() const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QNetworkReply::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual bool waitForBytesWritten(int msecs);
    virtual bool waitForReadyRead(int msecs);
    inline qint64 writeData_protected(const char * data, qint64 len) { return QNetworkReply::writeData(data, len); }
    virtual qint64 writeData(const char * data, qint64 len);
    virtual ~QNetworkReplyWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    // Inherited overloads, because the using keyword sux
    inline void ignoreSslErrors(const QList<QSslError > & errors) { QNetworkReply::ignoreSslErrors(errors); }
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QNETWORKREPLYWRAPPER_H

