/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QSSLSOCKETWRAPPER_H
#define SBK_QSSLSOCKETWRAPPER_H

#include <shiboken.h>

#include <qsslsocket.h>

namespace PySide { class DynamicQMetaObject; }

class QSslSocketWrapper : public QSslSocket
{
public:
    QSslSocketWrapper(QObject * parent = 0);
    virtual bool atEnd() const;
    virtual qint64 bytesAvailable() const;
    virtual qint64 bytesToWrite() const;
    virtual bool canReadLine() const;
    inline void childEvent_protected(QChildEvent * arg__1) { QSslSocket::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual void close();
    inline void connectNotify_protected(const char * signal) { QSslSocket::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void connectToHostImplementation_protected(const QString & hostName, quint16 port, int openMode) { QSslSocket::connectToHostImplementation(hostName, port, QFlags<QIODevice::OpenModeFlag>(openMode)); }
    inline void customEvent_protected(QEvent * arg__1) { QSslSocket::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectFromHostImplementation_protected() { QSslSocket::disconnectFromHostImplementation(); }
    inline void disconnectNotify_protected(const char * signal) { QSslSocket::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    virtual bool isSequential() const;
    virtual const QMetaObject * metaObject() const;
    virtual bool open(QFlags<QIODevice::OpenModeFlag> mode);
    virtual qint64 pos() const;
    inline qint64 readData_protected(char * data, qint64 maxlen) { return QSslSocket::readData(data, maxlen); }
    virtual qint64 readData(char * data, qint64 maxlen);
    inline qint64 readLineData_protected(char * data, qint64 maxlen) { return QSslSocket::readLineData(data, maxlen); }
    virtual qint64 readLineData(char * data, qint64 maxlen);
    inline int receivers_protected(const char * signal) const { return QSslSocket::receivers(signal); }
    virtual bool reset();
    virtual bool seek(qint64 pos);
    inline QObject * sender_protected() const { return QSslSocket::sender(); }
    inline int senderSignalIndex_protected() const { return QSslSocket::senderSignalIndex(); }
    inline void setErrorString_protected(const QString & errorString) { QSslSocket::setErrorString(errorString); }
    inline void setLocalAddress_protected(const QHostAddress & address) { QSslSocket::setLocalAddress(address); }
    inline void setLocalPort_protected(quint16 port) { QSslSocket::setLocalPort(port); }
    inline void setOpenMode_protected(int openMode) { QSslSocket::setOpenMode(QFlags<QIODevice::OpenModeFlag>(openMode)); }
    inline void setPeerAddress_protected(const QHostAddress & address) { QSslSocket::setPeerAddress(address); }
    inline void setPeerName_protected(const QString & name) { QSslSocket::setPeerName(name); }
    inline void setPeerPort_protected(quint16 port) { QSslSocket::setPeerPort(port); }
    inline void setSocketError_protected(int socketError) { QSslSocket::setSocketError(QAbstractSocket::SocketError(socketError)); }
    inline void setSocketState_protected(int state) { QSslSocket::setSocketState(QAbstractSocket::SocketState(state)); }
    virtual qint64 size() const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QSslSocket::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual bool waitForBytesWritten(int msecs = 30000);
    virtual bool waitForReadyRead(int msecs = 30000);
    inline qint64 writeData_protected(const char * data, qint64 len) { return QSslSocket::writeData(data, len); }
    virtual qint64 writeData(const char * data, qint64 len);
    virtual ~QSslSocketWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QSSLSOCKETWRAPPER_H

