/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QGLCONTEXTWRAPPER_H
#define SBK_QGLCONTEXTWRAPPER_H

#include <shiboken.h>

#include <qgl.h>

class QGLContextWrapper : public QGLContext
{
public:
    QGLContextWrapper(const QGLFormat & format);
    inline bool chooseContext_protected(const QGLContext * shareContext = 0) { return QGLContext::chooseContext(shareContext); }
    virtual bool chooseContext(const QGLContext * shareContext = 0);
    inline uint colorIndex_protected(const QColor & c) const { return QGLContext::colorIndex(c); }
    virtual bool create(const QGLContext * shareContext = 0);
    inline bool deviceIsPixmap_protected() const { return QGLContext::deviceIsPixmap(); }
    virtual void doneCurrent();
    inline void generateFontDisplayLists_protected(const QFont & fnt, int listBase) { QGLContext::generateFontDisplayLists(fnt, listBase); }
    inline bool initialized_protected() const { return QGLContext::initialized(); }
    virtual void makeCurrent();
    inline void setDevice_protected(QPaintDevice * pDev) { QGLContext::setDevice(pDev); }
    inline void setInitialized_protected(bool on) { QGLContext::setInitialized(on); }
    inline void setValid_protected(bool valid) { QGLContext::setValid(valid); }
    inline void setWindowCreated_protected(bool on) { QGLContext::setWindowCreated(on); }
    virtual void swapBuffers() const;
    inline bool windowCreated_protected() const { return QGLContext::windowCreated(); }
    virtual ~QGLContextWrapper();
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QGLCONTEXTWRAPPER_H

