/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QGLWIDGETWRAPPER_H
#define SBK_QGLWIDGETWRAPPER_H

#include <shiboken.h>

#include <qgl.h>

namespace PySide { class DynamicQMetaObject; }

class QGLWidgetWrapper : public QGLWidget
{
public:
    QGLWidgetWrapper(QGLContext * context, QWidget * parent = 0, const QGLWidget * shareWidget = 0, QFlags<Qt::WindowType> f = 0);
    QGLWidgetWrapper(QWidget * parent = 0, const QGLWidget * shareWidget = 0, QFlags<Qt::WindowType> f = 0);
    QGLWidgetWrapper(const QGLFormat & format, QWidget * parent = 0, const QGLWidget * shareWidget = 0, QFlags<Qt::WindowType> f = 0);
    inline void actionEvent_protected(QActionEvent * event) { QGLWidget::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline bool autoBufferSwap_protected() const { return QGLWidget::autoBufferSwap(); }
    inline void changeEvent_protected(QEvent * event) { QGLWidget::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QGLWidget::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QGLWidget::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QGLWidget::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * event) { QGLWidget::contextMenuEvent(event); }
    virtual void contextMenuEvent(QContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QGLWidget::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QGLWidget::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QGLWidget::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * event) { QGLWidget::dragEnterEvent(event); }
    virtual void dragEnterEvent(QDragEnterEvent * event);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * event) { QGLWidget::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QDragLeaveEvent * event);
    inline void dragMoveEvent_protected(QDragMoveEvent * event) { QGLWidget::dragMoveEvent(event); }
    virtual void dragMoveEvent(QDragMoveEvent * event);
    inline void dropEvent_protected(QDropEvent * event) { QGLWidget::dropEvent(event); }
    virtual void dropEvent(QDropEvent * event);
    inline void enterEvent_protected(QEvent * event) { QGLWidget::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    inline bool event_protected(QEvent * arg__1) { return QGLWidget::event(arg__1); }
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * event) { QGLWidget::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline bool focusNextChild_protected() { return QGLWidget::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QGLWidget::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * event) { QGLWidget::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline bool focusPreviousChild_protected() { return QGLWidget::focusPreviousChild(); }
    inline int fontDisplayListBase_protected(const QFont & fnt, int listBase = 2000) { return QGLWidget::fontDisplayListBase(fnt, listBase); }
    inline void glDraw_protected() { QGLWidget::glDraw(); }
    virtual void glDraw();
    inline void glInit_protected() { QGLWidget::glInit(); }
    virtual void glInit();
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QGLWidget::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void initializeGL_protected() { QGLWidget::initializeGL(); }
    virtual void initializeGL();
    inline void initializeOverlayGL_protected() { QGLWidget::initializeOverlayGL(); }
    virtual void initializeOverlayGL();
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QGLWidget::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const;
    inline void keyPressEvent_protected(QKeyEvent * event) { QGLWidget::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QGLWidget::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    inline void languageChange_protected() { QGLWidget::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QGLWidget::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QGLWidget::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * event) { QGLWidget::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QMouseEvent * event);
    inline void mouseMoveEvent_protected(QMouseEvent * event) { QGLWidget::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QMouseEvent * event);
    inline void mousePressEvent_protected(QMouseEvent * event) { QGLWidget::mousePressEvent(event); }
    virtual void mousePressEvent(QMouseEvent * event);
    inline void mouseReleaseEvent_protected(QMouseEvent * event) { QGLWidget::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QMouseEvent * event);
    inline void moveEvent_protected(QMoveEvent * event) { QGLWidget::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QGLWidget::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void paintGL_protected() { QGLWidget::paintGL(); }
    virtual void paintGL();
    inline void paintOverlayGL_protected() { QGLWidget::paintOverlayGL(); }
    virtual void paintOverlayGL();
    inline void resetInputContext_protected() { QGLWidget::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * arg__1) { QGLWidget::resizeEvent(arg__1); }
    virtual void resizeEvent(QResizeEvent * arg__1);
    inline void resizeGL_protected(int w, int h) { QGLWidget::resizeGL(w, h); }
    virtual void resizeGL(int w, int h);
    inline void resizeOverlayGL_protected(int w, int h) { QGLWidget::resizeOverlayGL(w, h); }
    virtual void resizeOverlayGL(int w, int h);
    inline void setAutoBufferSwap_protected(bool on) { QGLWidget::setAutoBufferSwap(on); }
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QGLWidget::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QGLWidget::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QGLWidget::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual void updateGL();
    inline void updateMicroFocus_protected() { QGLWidget::updateMicroFocus(); }
    virtual void updateOverlayGL();
    inline void wheelEvent_protected(QWheelEvent * event) { QGLWidget::wheelEvent(event); }
    virtual void wheelEvent(QWheelEvent * event);
    inline bool winEvent_protected(MSG * message, long * result) { return QGLWidget::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QGLWidgetWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QGLWIDGETWRAPPER_H

