/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QSQLDRIVERWRAPPER_H
#define SBK_QSQLDRIVERWRAPPER_H

#include <shiboken.h>

#include <qsqldriver.h>

namespace PySide { class DynamicQMetaObject; }

class QSqlDriverWrapper : public QSqlDriver
{
public:
    QSqlDriverWrapper(QObject * parent = 0);
    virtual bool beginTransaction();
    inline void childEvent_protected(QChildEvent * arg__1) { QSqlDriver::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual void close();
    virtual bool commitTransaction();
    inline void connectNotify_protected(const char * signal) { QSqlDriver::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    virtual QSqlResult * createResult() const;
    inline void customEvent_protected(QEvent * arg__1) { QSqlDriver::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QSqlDriver::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    virtual QString escapeIdentifier(const QString & identifier, QSqlDriver::IdentifierType type) const;
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    virtual QString formatValue(const QSqlField & field, bool trimStrings = false) const;
    virtual bool hasFeature(QSqlDriver::DriverFeature f) const;
    inline bool isIdentifierEscapedImplementation_protected(const QString & identifier, int type) const { return QSqlDriver::isIdentifierEscapedImplementation(identifier, QSqlDriver::IdentifierType(type)); }
    virtual bool isOpen() const;
    virtual const QMetaObject * metaObject() const;
    virtual bool open(const QString & db, const QString & user = QString(), const QString & password = QString(), const QString & host = QString(), int port = -1, const QString & connOpts = QString());
    virtual QSqlIndex primaryIndex(const QString & tableName) const;
    inline int receivers_protected(const char * signal) const { return QSqlDriver::receivers(signal); }
    virtual QSqlRecord record(const QString & tableName) const;
    virtual bool rollbackTransaction();
    inline QObject * sender_protected() const { return QSqlDriver::sender(); }
    inline int senderSignalIndex_protected() const { return QSqlDriver::senderSignalIndex(); }
    inline void setLastError_protected(const QSqlError & e) { QSqlDriver::setLastError(e); }
    virtual void setLastError(const QSqlError & e);
    inline void setOpen_protected(bool o) { QSqlDriver::setOpen(o); }
    virtual void setOpen(bool o);
    inline void setOpenError_protected(bool e) { QSqlDriver::setOpenError(e); }
    virtual void setOpenError(bool e);
    virtual QString sqlStatement(QSqlDriver::StatementType type, const QString & tableName, const QSqlRecord & rec, bool preparedStatement) const;
    inline QString stripDelimitersImplementation_protected(const QString & identifier, int type) const { return QSqlDriver::stripDelimitersImplementation(identifier, QSqlDriver::IdentifierType(type)); }
    inline bool subscribeToNotificationImplementation_protected(const QString & name) { return QSqlDriver::subscribeToNotificationImplementation(name); }
    inline QStringList subscribedToNotificationsImplementation_protected() const { return QSqlDriver::subscribedToNotificationsImplementation(); }
    virtual QStringList tables(QSql::TableType tableType) const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QSqlDriver::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline bool unsubscribeFromNotificationImplementation_protected(const QString & name) { return QSqlDriver::unsubscribeFromNotificationImplementation(name); }
    virtual ~QSqlDriverWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QSQLDRIVERWRAPPER_H

