/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QSQLRESULTWRAPPER_H
#define SBK_QSQLRESULTWRAPPER_H

#include <shiboken.h>

#include <qsqlresult.h>

class QSqlResultWrapper : public QSqlResult
{
public:
    QSqlResultWrapper(const QSqlDriver * db);
    inline void addBindValue_protected(const QVariant & val, int type) { QSqlResult::addBindValue(val, QFlags<QSql::ParamTypeFlag>(type)); }
    inline int at_protected() const { return QSqlResult::at(); }
    inline void bindValue_protected(const QString & placeholder, const QVariant & val, int type) { QSqlResult::bindValue(placeholder, val, QFlags<QSql::ParamTypeFlag>(type)); }
    virtual void bindValue(const QString & placeholder, const QVariant & val, QFlags<QSql::ParamTypeFlag> type);
    inline void bindValue_protected(int pos, const QVariant & val, int type) { QSqlResult::bindValue(pos, val, QFlags<QSql::ParamTypeFlag>(type)); }
    virtual void bindValue(int pos, const QVariant & val, QFlags<QSql::ParamTypeFlag> type);
    inline int bindValueType_protected(const QString & placeholder) const { return QSqlResult::bindValueType(placeholder); }
    inline int bindValueType_protected(int pos) const { return QSqlResult::bindValueType(pos); }
    inline int bindingSyntax_protected() const { return QSqlResult::bindingSyntax(); }
    inline QVariant boundValue_protected(const QString & placeholder) const { return QSqlResult::boundValue(placeholder); }
    inline QVariant boundValue_protected(int pos) const { return QSqlResult::boundValue(pos); }
    inline int boundValueCount_protected() const { return QSqlResult::boundValueCount(); }
    inline QString boundValueName_protected(int pos) const { return QSqlResult::boundValueName(pos); }
    inline QVector<QVariant > & boundValues_protected() const { return QSqlResult::boundValues(); }
    inline void clear_protected() { QSqlResult::clear(); }
    inline QVariant data_protected(int i) { return data(i); }
    virtual QVariant data(int i);
    inline void detachFromResultSet_protected() { QSqlResult::detachFromResultSet(); }
    inline const QSqlDriver * driver_protected() const { return QSqlResult::driver(); }
    inline bool exec_protected() { return QSqlResult::exec(); }
    virtual bool exec();
    inline bool execBatch_protected(bool arrayBind = false) { return QSqlResult::execBatch(arrayBind); }
    inline QString executedQuery_protected() const { return QSqlResult::executedQuery(); }
    inline bool fetch_protected(int i) { return fetch(i); }
    virtual bool fetch(int i);
    inline bool fetchFirst_protected() { return fetchFirst(); }
    virtual bool fetchFirst();
    inline bool fetchLast_protected() { return fetchLast(); }
    virtual bool fetchLast();
    inline bool fetchNext_protected() { return QSqlResult::fetchNext(); }
    virtual bool fetchNext();
    inline bool fetchPrevious_protected() { return QSqlResult::fetchPrevious(); }
    virtual bool fetchPrevious();
    virtual QVariant handle() const;
    inline bool hasOutValues_protected() const { return QSqlResult::hasOutValues(); }
    inline bool isActive_protected() const { return QSqlResult::isActive(); }
    inline bool isForwardOnly_protected() const { return QSqlResult::isForwardOnly(); }
    inline bool isNull_protected(int i) { return isNull(i); }
    virtual bool isNull(int i);
    inline bool isSelect_protected() const { return QSqlResult::isSelect(); }
    inline bool isValid_protected() const { return QSqlResult::isValid(); }
    inline QSqlError lastError_protected() const { return QSqlResult::lastError(); }
    inline QVariant lastInsertId_protected() const { return QSqlResult::lastInsertId(); }
    virtual QVariant lastInsertId() const;
    inline QString lastQuery_protected() const { return QSqlResult::lastQuery(); }
    inline bool nextResult_protected() { return QSqlResult::nextResult(); }
    inline int numRowsAffected_protected() { return numRowsAffected(); }
    virtual int numRowsAffected();
    inline int numericalPrecisionPolicy_protected() const { return QSqlResult::numericalPrecisionPolicy(); }
    inline bool prepare_protected(const QString & query) { return QSqlResult::prepare(query); }
    virtual bool prepare(const QString & query);
    inline QSqlRecord record_protected() const { return QSqlResult::record(); }
    virtual QSqlRecord record() const;
    inline bool reset_protected(const QString & sqlquery) { return reset(sqlquery); }
    virtual bool reset(const QString & sqlquery);
    inline bool savePrepare_protected(const QString & sqlquery) { return QSqlResult::savePrepare(sqlquery); }
    virtual bool savePrepare(const QString & sqlquery);
    inline void setActive_protected(bool a) { QSqlResult::setActive(a); }
    virtual void setActive(bool a);
    inline void setAt_protected(int at) { QSqlResult::setAt(at); }
    virtual void setAt(int at);
    inline void setForwardOnly_protected(bool forward) { QSqlResult::setForwardOnly(forward); }
    virtual void setForwardOnly(bool forward);
    inline void setLastError_protected(const QSqlError & e) { QSqlResult::setLastError(e); }
    virtual void setLastError(const QSqlError & e);
    inline void setNumericalPrecisionPolicy_protected(int policy) { QSqlResult::setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy(policy)); }
    inline void setQuery_protected(const QString & query) { QSqlResult::setQuery(query); }
    virtual void setQuery(const QString & query);
    inline void setSelect_protected(bool s) { QSqlResult::setSelect(s); }
    virtual void setSelect(bool s);
    inline int size_protected() { return size(); }
    virtual int size();
    inline void virtual_hook_protected(int id, void * data) { QSqlResult::virtual_hook(id, data); }
    virtual ~QSqlResultWrapper();
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QSQLRESULTWRAPPER_H

