/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QSQLTABLEMODELWRAPPER_H
#define SBK_QSQLTABLEMODELWRAPPER_H

#include <shiboken.h>

#include <qsqltablemodel.h>

namespace PySide { class DynamicQMetaObject; }

class QSqlTableModelWrapper : public QSqlTableModel
{
public:
    QSqlTableModelWrapper(QObject * parent = 0, QSqlDatabase db = QSqlDatabase());
    inline void beginInsertColumns_protected(const QModelIndex & parent, int first, int last) { QSqlTableModel::beginInsertColumns(parent, first, last); }
    inline void beginInsertRows_protected(const QModelIndex & parent, int first, int last) { QSqlTableModel::beginInsertRows(parent, first, last); }
    inline bool beginMoveColumns_protected(const QModelIndex & sourceParent, int sourceFirst, int sourceLast, const QModelIndex & destinationParent, int destinationColumn) { return QSqlTableModel::beginMoveColumns(sourceParent, sourceFirst, sourceLast, destinationParent, destinationColumn); }
    inline bool beginMoveRows_protected(const QModelIndex & sourceParent, int sourceFirst, int sourceLast, const QModelIndex & destinationParent, int destinationRow) { return QSqlTableModel::beginMoveRows(sourceParent, sourceFirst, sourceLast, destinationParent, destinationRow); }
    inline void beginRemoveColumns_protected(const QModelIndex & parent, int first, int last) { QSqlTableModel::beginRemoveColumns(parent, first, last); }
    inline void beginRemoveRows_protected(const QModelIndex & parent, int first, int last) { QSqlTableModel::beginRemoveRows(parent, first, last); }
    inline void beginResetModel_protected() { QSqlTableModel::beginResetModel(); }
    virtual QModelIndex buddy(const QModelIndex & index) const;
    virtual bool canFetchMore(const QModelIndex & parent = QModelIndex()) const;
    inline void changePersistentIndex_protected(const QModelIndex & from, const QModelIndex & to) { QSqlTableModel::changePersistentIndex(from, to); }
    inline void changePersistentIndexList_protected(const QModelIndexList & from, const QModelIndexList & to) { QSqlTableModel::changePersistentIndexList(from, to); }
    inline void childEvent_protected(QChildEvent * arg__1) { QSqlTableModel::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual void clear();
    virtual int columnCount(const QModelIndex & parent = QModelIndex()) const;
    inline void connectNotify_protected(const char * signal) { QSqlTableModel::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline QModelIndex createIndex_protected(int row, int column, int id) const { return QSqlTableModel::createIndex(row, column, id); }
    inline void customEvent_protected(QEvent * arg__1) { QSqlTableModel::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    virtual QVariant data(const QModelIndex & idx, int role = Qt::DisplayRole) const;
    inline bool decodeData_protected(int row, int column, const QModelIndex & parent, QDataStream & stream) { return QSqlTableModel::decodeData(row, column, parent, stream); }
    inline bool deleteRowFromTable_protected(int row) { return QSqlTableModel::deleteRowFromTable(row); }
    virtual bool deleteRowFromTable(int row);
    inline void disconnectNotify_protected(const char * signal) { QSqlTableModel::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    virtual bool dropMimeData(const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent);
    inline void encodeData_protected(const QModelIndexList & indexes, QDataStream & stream) const { QSqlTableModel::encodeData(indexes, stream); }
    inline void endInsertColumns_protected() { QSqlTableModel::endInsertColumns(); }
    inline void endInsertRows_protected() { QSqlTableModel::endInsertRows(); }
    inline void endMoveColumns_protected() { QSqlTableModel::endMoveColumns(); }
    inline void endMoveRows_protected() { QSqlTableModel::endMoveRows(); }
    inline void endRemoveColumns_protected() { QSqlTableModel::endRemoveColumns(); }
    inline void endRemoveRows_protected() { QSqlTableModel::endRemoveRows(); }
    inline void endResetModel_protected() { QSqlTableModel::endResetModel(); }
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    virtual void fetchMore(const QModelIndex & parent = QModelIndex());
    virtual QFlags<Qt::ItemFlag> flags(const QModelIndex & index) const;
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
    virtual QModelIndex index(int row, int column, const QModelIndex & parent = QModelIndex()) const;
    inline QModelIndex indexInQuery_protected(const QModelIndex & item) const { return QSqlTableModel::indexInQuery(item); }
    virtual bool insertColumns(int column, int count, const QModelIndex & parent = QModelIndex());
    inline bool insertRowIntoTable_protected(const QSqlRecord & values) { return QSqlTableModel::insertRowIntoTable(values); }
    virtual bool insertRowIntoTable(const QSqlRecord & values);
    virtual bool insertRows(int row, int count, const QModelIndex & parent = QModelIndex());
    virtual QMap<int, QVariant > itemData(const QModelIndex & index) const;
    virtual QModelIndexList match(const QModelIndex & start, int role, const QVariant & value, int hits = 1, QFlags<Qt::MatchFlag> flags = Qt::MatchFlags(Qt::MatchStartsWith|Qt::MatchWrap)) const;
    virtual const QMetaObject * metaObject() const;
    virtual QMimeData * mimeData(const QModelIndexList & indexes) const;
    virtual QStringList mimeTypes() const;
    inline QString orderByClause_protected() const { return QSqlTableModel::orderByClause(); }
    virtual QString orderByClause() const;
    inline QModelIndexList persistentIndexList_protected() const { return QSqlTableModel::persistentIndexList(); }
    inline void queryChange_protected() { QSqlTableModel::queryChange(); }
    virtual void queryChange();
    inline int receivers_protected(const char * signal) const { return QSqlTableModel::receivers(signal); }
    virtual bool removeColumns(int column, int count, const QModelIndex & parent = QModelIndex());
    virtual bool removeRows(int row, int count, const QModelIndex & parent = QModelIndex());
    inline void reset_protected() { QSqlTableModel::reset(); }
    inline void resetInternalData_protected() { QSqlTableModel::resetInternalData(); }
    virtual void revert();
    virtual void revertRow(int row);
    virtual int rowCount(const QModelIndex & parent = QModelIndex()) const;
    virtual bool select();
    inline QString selectStatement_protected() const { return QSqlTableModel::selectStatement(); }
    virtual QString selectStatement() const;
    inline QObject * sender_protected() const { return QSqlTableModel::sender(); }
    inline int senderSignalIndex_protected() const { return QSqlTableModel::senderSignalIndex(); }
    virtual bool setData(const QModelIndex & index, const QVariant & value, int role = Qt::EditRole);
    virtual void setEditStrategy(QSqlTableModel::EditStrategy strategy);
    virtual void setFilter(const QString & filter);
    virtual bool setHeaderData(int section, Qt::Orientation orientation, const QVariant & value, int role = Qt::EditRole);
    virtual bool setItemData(const QModelIndex & index, const QMap<int, QVariant > & roles);
    inline void setLastError_protected(const QSqlError & error) { QSqlTableModel::setLastError(error); }
    inline void setPrimaryKey_protected(const QSqlIndex & key) { QSqlTableModel::setPrimaryKey(key); }
    inline void setQuery_protected(const QSqlQuery & query) { QSqlTableModel::setQuery(query); }
    inline void setRoleNames_protected(const QHash<int, QByteArray > & roleNames) { QSqlTableModel::setRoleNames(roleNames); }
    virtual void setSort(int column, Qt::SortOrder order);
    virtual void setTable(const QString & tableName);
    virtual void sort(int column, Qt::SortOrder order);
    virtual QSize span(const QModelIndex & index) const;
    virtual bool submit();
    virtual QFlags<Qt::DropAction> supportedDropActions() const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QSqlTableModel::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline bool updateRowInTable_protected(int row, const QSqlRecord & values) { return QSqlTableModel::updateRowInTable(row, values); }
    virtual bool updateRowInTable(int row, const QSqlRecord & values);
    virtual ~QSqlTableModelWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QSQLTABLEMODELWRAPPER_H

