/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QGRAPHICSSVGITEMWRAPPER_H
#define SBK_QGRAPHICSSVGITEMWRAPPER_H

#include <shiboken.h>

#include <qgraphicssvgitem.h>

namespace PySide { class DynamicQMetaObject; }

class QGraphicsSvgItemWrapper : public QGraphicsSvgItem
{
public:
    QGraphicsSvgItemWrapper(QGraphicsItem * parentItem = 0);
    QGraphicsSvgItemWrapper(const QString & fileName, QGraphicsItem * parentItem = 0);
    inline void addToIndex_protected() { QGraphicsSvgItem::addToIndex(); }
    virtual void advance(int phase);
    virtual QRectF boundingRect() const;
    inline void childEvent_protected(QChildEvent * arg__1) { QGraphicsSvgItem::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    virtual bool collidesWithItem(const QGraphicsItem * other, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    virtual bool collidesWithPath(const QPainterPath & path, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    inline void connectNotify_protected(const char * signal) { QGraphicsSvgItem::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    virtual bool contains(const QPointF & point) const;
    inline void contextMenuEvent_protected(QGraphicsSceneContextMenuEvent * event) { QGraphicsSvgItem::contextMenuEvent(event); }
    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent * event);
    inline void customEvent_protected(QEvent * arg__1) { QGraphicsSvgItem::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QGraphicsSvgItem::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsSvgItem::dragEnterEvent(event); }
    virtual void dragEnterEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragLeaveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsSvgItem::dragLeaveEvent(event); }
    virtual void dragLeaveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dragMoveEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsSvgItem::dragMoveEvent(event); }
    virtual void dragMoveEvent(QGraphicsSceneDragDropEvent * event);
    inline void dropEvent_protected(QGraphicsSceneDragDropEvent * event) { QGraphicsSvgItem::dropEvent(event); }
    virtual void dropEvent(QGraphicsSceneDragDropEvent * event);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline QVariant extension_protected(const QVariant & variant) const { return QGraphicsSvgItem::extension(variant); }
    virtual QVariant extension(const QVariant & variant) const;
    inline void focusInEvent_protected(QFocusEvent * event) { QGraphicsSvgItem::focusInEvent(event); }
    virtual void focusInEvent(QFocusEvent * event);
    inline void focusOutEvent_protected(QFocusEvent * event) { QGraphicsSvgItem::focusOutEvent(event); }
    virtual void focusOutEvent(QFocusEvent * event);
    inline void hoverEnterEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsSvgItem::hoverEnterEvent(event); }
    virtual void hoverEnterEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverLeaveEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsSvgItem::hoverLeaveEvent(event); }
    virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverMoveEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsSvgItem::hoverMoveEvent(event); }
    virtual void hoverMoveEvent(QGraphicsSceneHoverEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * event) { QGraphicsSvgItem::inputMethodEvent(event); }
    virtual void inputMethodEvent(QInputMethodEvent * event);
    inline QVariant inputMethodQuery_protected(int query) const { return QGraphicsSvgItem::inputMethodQuery(Qt::InputMethodQuery(query)); }
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    virtual bool isObscuredBy(const QGraphicsItem * item) const;
    inline QVariant itemChange_protected(int change, const QVariant & value) { return QGraphicsSvgItem::itemChange(QGraphicsItem::GraphicsItemChange(change), value); }
    virtual QVariant itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant & value);
    inline void keyPressEvent_protected(QKeyEvent * event) { QGraphicsSvgItem::keyPressEvent(event); }
    virtual void keyPressEvent(QKeyEvent * event);
    inline void keyReleaseEvent_protected(QKeyEvent * event) { QGraphicsSvgItem::keyReleaseEvent(event); }
    virtual void keyReleaseEvent(QKeyEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline void mouseDoubleClickEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsSvgItem::mouseDoubleClickEvent(event); }
    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseMoveEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsSvgItem::mouseMoveEvent(event); }
    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
    inline void mousePressEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsSvgItem::mousePressEvent(event); }
    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
    inline void mouseReleaseEvent_protected(QGraphicsSceneMouseEvent * event) { QGraphicsSvgItem::mouseReleaseEvent(event); }
    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
    virtual QPainterPath opaqueArea() const;
    virtual void paint(QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget = 0);
    inline void prepareGeometryChange_protected() { QGraphicsSvgItem::prepareGeometryChange(); }
    inline void removeFromIndex_protected() { QGraphicsSvgItem::removeFromIndex(); }
    inline bool sceneEvent_protected(QEvent * event) { return QGraphicsSvgItem::sceneEvent(event); }
    virtual bool sceneEvent(QEvent * event);
    inline bool sceneEventFilter_protected(QGraphicsItem * watched, QEvent * event) { return QGraphicsSvgItem::sceneEventFilter(watched, event); }
    virtual bool sceneEventFilter(QGraphicsItem * watched, QEvent * event);
    virtual QPainterPath shape() const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QGraphicsSvgItem::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual int type() const;
    inline void updateMicroFocus_protected() { QGraphicsSvgItem::updateMicroFocus(); }
    inline void wheelEvent_protected(QGraphicsSceneWheelEvent * event) { QGraphicsSvgItem::wheelEvent(event); }
    virtual void wheelEvent(QGraphicsSceneWheelEvent * event);
    virtual ~QGraphicsSvgItemWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QGRAPHICSSVGITEMWRAPPER_H

