/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QGRAPHICSWEBVIEWWRAPPER_H
#define SBK_QGRAPHICSWEBVIEWWRAPPER_H

#include <shiboken.h>

#include <qgraphicswebview.h>

namespace PySide { class DynamicQMetaObject; }

class QGraphicsWebViewWrapper : public QGraphicsWebView
{
public:
    QGraphicsWebViewWrapper(QGraphicsItem * parent = 0);
    virtual void advance(int phase);
    virtual QRectF boundingRect() const;
    inline void changeEvent_protected(QEvent * event) { QGraphicsWebView::changeEvent(event); }
    virtual void changeEvent(QEvent * event);
    inline void childEvent_protected(QChildEvent * arg__1) { QGraphicsWebView::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QGraphicsWebView::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    virtual bool collidesWithItem(const QGraphicsItem * other, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    virtual bool collidesWithPath(const QPainterPath & path, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
    inline void connectNotify_protected(const char * signal) { QGraphicsWebView::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    virtual bool contains(const QPointF & point) const;
    inline void contextMenuEvent_protected(QGraphicsSceneContextMenuEvent * arg__1) { QGraphicsWebView::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent * arg__1);
    inline void customEvent_protected(QEvent * arg__1) { QGraphicsWebView::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QGraphicsWebView::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QGraphicsSceneDragDropEvent * arg__1) { QGraphicsWebView::dragEnterEvent(arg__1); }
    virtual void dragEnterEvent(QGraphicsSceneDragDropEvent * arg__1);
    inline void dragLeaveEvent_protected(QGraphicsSceneDragDropEvent * arg__1) { QGraphicsWebView::dragLeaveEvent(arg__1); }
    virtual void dragLeaveEvent(QGraphicsSceneDragDropEvent * arg__1);
    inline void dragMoveEvent_protected(QGraphicsSceneDragDropEvent * arg__1) { QGraphicsWebView::dragMoveEvent(arg__1); }
    virtual void dragMoveEvent(QGraphicsSceneDragDropEvent * arg__1);
    inline void dropEvent_protected(QGraphicsSceneDragDropEvent * arg__1) { QGraphicsWebView::dropEvent(arg__1); }
    virtual void dropEvent(QGraphicsSceneDragDropEvent * arg__1);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline QVariant extension_protected(const QVariant & variant) const { return QGraphicsWebView::extension(variant); }
    virtual QVariant extension(const QVariant & variant) const;
    inline void focusInEvent_protected(QFocusEvent * arg__1) { QGraphicsWebView::focusInEvent(arg__1); }
    virtual void focusInEvent(QFocusEvent * arg__1);
    inline bool focusNextPrevChild_protected(bool next) { return QGraphicsWebView::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * arg__1) { QGraphicsWebView::focusOutEvent(arg__1); }
    virtual void focusOutEvent(QFocusEvent * arg__1);
    virtual void getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const;
    inline void grabKeyboardEvent_protected(QEvent * event) { QGraphicsWebView::grabKeyboardEvent(event); }
    virtual void grabKeyboardEvent(QEvent * event);
    inline void grabMouseEvent_protected(QEvent * event) { QGraphicsWebView::grabMouseEvent(event); }
    virtual void grabMouseEvent(QEvent * event);
    inline void hideEvent_protected(QHideEvent * event) { QGraphicsWebView::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void hoverEnterEvent_protected(QGraphicsSceneHoverEvent * event) { QGraphicsWebView::hoverEnterEvent(event); }
    virtual void hoverEnterEvent(QGraphicsSceneHoverEvent * event);
    inline void hoverLeaveEvent_protected(QGraphicsSceneHoverEvent * arg__1) { QGraphicsWebView::hoverLeaveEvent(arg__1); }
    virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent * arg__1);
    inline void hoverMoveEvent_protected(QGraphicsSceneHoverEvent * arg__1) { QGraphicsWebView::hoverMoveEvent(arg__1); }
    virtual void hoverMoveEvent(QGraphicsSceneHoverEvent * arg__1);
    inline void initStyleOption_protected(QStyleOption * option) const { QGraphicsWebView::initStyleOption(option); }
    virtual void initStyleOption(QStyleOption * option) const;
    inline void inputMethodEvent_protected(QInputMethodEvent * arg__1) { QGraphicsWebView::inputMethodEvent(arg__1); }
    virtual void inputMethodEvent(QInputMethodEvent * arg__1);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query) const;
    virtual bool isObscuredBy(const QGraphicsItem * item) const;
    virtual QVariant itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant & value);
    inline void keyPressEvent_protected(QKeyEvent * arg__1) { QGraphicsWebView::keyPressEvent(arg__1); }
    virtual void keyPressEvent(QKeyEvent * arg__1);
    inline void keyReleaseEvent_protected(QKeyEvent * arg__1) { QGraphicsWebView::keyReleaseEvent(arg__1); }
    virtual void keyReleaseEvent(QKeyEvent * arg__1);
    virtual const QMetaObject * metaObject() const;
    inline void mouseDoubleClickEvent_protected(QGraphicsSceneMouseEvent * arg__1) { QGraphicsWebView::mouseDoubleClickEvent(arg__1); }
    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent * arg__1);
    inline void mouseMoveEvent_protected(QGraphicsSceneMouseEvent * arg__1) { QGraphicsWebView::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * arg__1);
    inline void mousePressEvent_protected(QGraphicsSceneMouseEvent * arg__1) { QGraphicsWebView::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QGraphicsSceneMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QGraphicsSceneMouseEvent * arg__1) { QGraphicsWebView::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * arg__1);
    inline void moveEvent_protected(QGraphicsSceneMoveEvent * event) { QGraphicsWebView::moveEvent(event); }
    virtual void moveEvent(QGraphicsSceneMoveEvent * event);
    virtual QPainterPath opaqueArea() const;
    virtual void paint(QPainter * arg__1, const QStyleOptionGraphicsItem * options, QWidget * widget = 0);
    virtual void paintWindowFrame(QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget = 0);
    inline void polishEvent_protected() { QGraphicsWebView::polishEvent(); }
    virtual void polishEvent();
    inline QVariant propertyChange_protected(const QString & propertyName, const QVariant & value) { return QGraphicsWebView::propertyChange(propertyName, value); }
    virtual QVariant propertyChange(const QString & propertyName, const QVariant & value);
    inline void resizeEvent_protected(QGraphicsSceneResizeEvent * event) { QGraphicsWebView::resizeEvent(event); }
    virtual void resizeEvent(QGraphicsSceneResizeEvent * event);
    inline bool sceneEvent_protected(QEvent * arg__1) { return QGraphicsWebView::sceneEvent(arg__1); }
    virtual bool sceneEvent(QEvent * arg__1);
    inline bool sceneEventFilter_protected(QGraphicsItem * watched, QEvent * event) { return QGraphicsWebView::sceneEventFilter(watched, event); }
    virtual bool sceneEventFilter(QGraphicsItem * watched, QEvent * event);
    virtual void setGeometry(const QRectF & rect);
    inline void setGraphicsItem_protected(QGraphicsItem * item) { QGraphicsWebView::setGraphicsItem(item); }
    inline void setOwnedByLayout_protected(bool ownedByLayout) { QGraphicsWebView::setOwnedByLayout(ownedByLayout); }
    virtual QPainterPath shape() const;
    inline void showEvent_protected(QShowEvent * event) { QGraphicsWebView::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSizeF sizeHint(Qt::SizeHint which, const QSizeF & constraint) const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QGraphicsWebView::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual int type() const;
    inline void ungrabKeyboardEvent_protected(QEvent * event) { QGraphicsWebView::ungrabKeyboardEvent(event); }
    virtual void ungrabKeyboardEvent(QEvent * event);
    inline void ungrabMouseEvent_protected(QEvent * event) { QGraphicsWebView::ungrabMouseEvent(event); }
    virtual void ungrabMouseEvent(QEvent * event);
    virtual void updateGeometry();
    inline void wheelEvent_protected(QGraphicsSceneWheelEvent * arg__1) { QGraphicsWebView::wheelEvent(arg__1); }
    virtual void wheelEvent(QGraphicsSceneWheelEvent * arg__1);
    inline bool windowFrameEvent_protected(QEvent * e) { return QGraphicsWebView::windowFrameEvent(e); }
    virtual bool windowFrameEvent(QEvent * e);
    inline int windowFrameSectionAt_protected(const QPointF & pos) const { return QGraphicsWebView::windowFrameSectionAt(pos); }
    virtual Qt::WindowFrameSection windowFrameSectionAt(const QPointF & pos) const;
    virtual ~QGraphicsWebViewWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QGRAPHICSWEBVIEWWRAPPER_H

