/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QWEBPAGEWRAPPER_H
#define SBK_QWEBPAGEWRAPPER_H

#include <shiboken.h>

#include <qwebpage.h>

namespace PySide { class DynamicQMetaObject; }

class QWebPageWrapper : public QWebPage
{
public:
    QWebPageWrapper(QObject * parent = 0);
    inline bool acceptNavigationRequest_protected(QWebFrame * frame, const QNetworkRequest & request, int type) { return QWebPage::acceptNavigationRequest(frame, request, QWebPage::NavigationType(type)); }
    virtual bool acceptNavigationRequest(QWebFrame * frame, const QNetworkRequest & request, QWebPage::NavigationType type);
    inline void childEvent_protected(QChildEvent * arg__1) { QWebPage::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline QString chooseFile_protected(QWebFrame * originatingFrame, const QString & oldFile) { return QWebPage::chooseFile(originatingFrame, oldFile); }
    virtual QString chooseFile(QWebFrame * originatingFrame, const QString & oldFile);
    inline void connectNotify_protected(const char * signal) { QWebPage::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline QObject * createPlugin_protected(const QString & classid, const QUrl & url, const QStringList & paramNames, const QStringList & paramValues) { return QWebPage::createPlugin(classid, url, paramNames, paramValues); }
    virtual QObject * createPlugin(const QString & classid, const QUrl & url, const QStringList & paramNames, const QStringList & paramValues);
    inline QWebPage * createWindow_protected(int type) { return QWebPage::createWindow(QWebPage::WebWindowType(type)); }
    virtual QWebPage * createWindow(QWebPage::WebWindowType type);
    inline void customEvent_protected(QEvent * arg__1) { QWebPage::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void disconnectNotify_protected(const char * signal) { QWebPage::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    virtual bool extension(QWebPage::Extension extension, const QWebPage::ExtensionOption * option = 0, QWebPage::ExtensionReturn * output = 0);
    inline void javaScriptAlert_protected(QWebFrame * originatingFrame, const QString & msg) { QWebPage::javaScriptAlert(originatingFrame, msg); }
    virtual void javaScriptAlert(QWebFrame * originatingFrame, const QString & msg);
    inline bool javaScriptConfirm_protected(QWebFrame * originatingFrame, const QString & msg) { return QWebPage::javaScriptConfirm(originatingFrame, msg); }
    virtual bool javaScriptConfirm(QWebFrame * originatingFrame, const QString & msg);
    inline void javaScriptConsoleMessage_protected(const QString & message, int lineNumber, const QString & sourceID) { QWebPage::javaScriptConsoleMessage(message, lineNumber, sourceID); }
    virtual void javaScriptConsoleMessage(const QString & message, int lineNumber, const QString & sourceID);
    inline bool javaScriptPrompt_protected(QWebFrame * originatingFrame, const QString & msg, const QString & defaultValue, QString * result) { return QWebPage::javaScriptPrompt(originatingFrame, msg, defaultValue, result); }
    virtual bool javaScriptPrompt(QWebFrame * originatingFrame, const QString & msg, const QString & defaultValue, QString * result);
    virtual const QMetaObject * metaObject() const;
    inline int receivers_protected(const char * signal) const { return QWebPage::receivers(signal); }
    inline QObject * sender_protected() const { return QWebPage::sender(); }
    inline int senderSignalIndex_protected() const { return QWebPage::senderSignalIndex(); }
    virtual bool supportsExtension(QWebPage::Extension extension) const;
    inline void timerEvent_protected(QTimerEvent * arg__1) { QWebPage::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    virtual void triggerAction(QWebPage::WebAction action, bool checked = false);
    inline QString userAgentForUrl_protected(const QUrl & url) const { return QWebPage::userAgentForUrl(url); }
    virtual QString userAgentForUrl(const QUrl & url) const;
    virtual ~QWebPageWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QWEBPAGEWRAPPER_H

