/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef SBK_QWEBVIEWWRAPPER_H
#define SBK_QWEBVIEWWRAPPER_H

#include <shiboken.h>

#include <qwebview.h>

namespace PySide { class DynamicQMetaObject; }

class QWebViewWrapper : public QWebView
{
public:
    QWebViewWrapper(QWidget * parent = 0);
    inline void actionEvent_protected(QActionEvent * event) { QWebView::actionEvent(event); }
    virtual void actionEvent(QActionEvent * event);
    inline void changeEvent_protected(QEvent * arg__1) { QWebView::changeEvent(arg__1); }
    virtual void changeEvent(QEvent * arg__1);
    inline void childEvent_protected(QChildEvent * arg__1) { QWebView::childEvent(arg__1); }
    virtual void childEvent(QChildEvent * arg__1);
    inline void closeEvent_protected(QCloseEvent * event) { QWebView::closeEvent(event); }
    virtual void closeEvent(QCloseEvent * event);
    inline void connectNotify_protected(const char * signal) { QWebView::connectNotify(signal); }
    virtual void connectNotify(const char * signal);
    inline void contextMenuEvent_protected(QContextMenuEvent * arg__1) { QWebView::contextMenuEvent(arg__1); }
    virtual void contextMenuEvent(QContextMenuEvent * arg__1);
    inline QWebView * createWindow_protected(int type) { return QWebView::createWindow(QWebPage::WebWindowType(type)); }
    virtual QWebView * createWindow(QWebPage::WebWindowType type);
    inline void customEvent_protected(QEvent * arg__1) { QWebView::customEvent(arg__1); }
    virtual void customEvent(QEvent * arg__1);
    inline void destroy_protected(bool destroyWindow = true, bool destroySubWindows = true) { QWebView::destroy(destroyWindow, destroySubWindows); }
    virtual int devType() const;
    inline void disconnectNotify_protected(const char * signal) { QWebView::disconnectNotify(signal); }
    virtual void disconnectNotify(const char * signal);
    inline void dragEnterEvent_protected(QDragEnterEvent * arg__1) { QWebView::dragEnterEvent(arg__1); }
    virtual void dragEnterEvent(QDragEnterEvent * arg__1);
    inline void dragLeaveEvent_protected(QDragLeaveEvent * arg__1) { QWebView::dragLeaveEvent(arg__1); }
    virtual void dragLeaveEvent(QDragLeaveEvent * arg__1);
    inline void dragMoveEvent_protected(QDragMoveEvent * arg__1) { QWebView::dragMoveEvent(arg__1); }
    virtual void dragMoveEvent(QDragMoveEvent * arg__1);
    inline void dropEvent_protected(QDropEvent * arg__1) { QWebView::dropEvent(arg__1); }
    virtual void dropEvent(QDropEvent * arg__1);
    inline void enterEvent_protected(QEvent * event) { QWebView::enterEvent(event); }
    virtual void enterEvent(QEvent * event);
    virtual bool event(QEvent * arg__1);
    virtual bool eventFilter(QObject * arg__1, QEvent * arg__2);
    inline void focusInEvent_protected(QFocusEvent * arg__1) { QWebView::focusInEvent(arg__1); }
    virtual void focusInEvent(QFocusEvent * arg__1);
    inline bool focusNextChild_protected() { return QWebView::focusNextChild(); }
    inline bool focusNextPrevChild_protected(bool next) { return QWebView::focusNextPrevChild(next); }
    virtual bool focusNextPrevChild(bool next);
    inline void focusOutEvent_protected(QFocusEvent * arg__1) { QWebView::focusOutEvent(arg__1); }
    virtual void focusOutEvent(QFocusEvent * arg__1);
    inline bool focusPreviousChild_protected() { return QWebView::focusPreviousChild(); }
    virtual int heightForWidth(int arg__1) const;
    inline void hideEvent_protected(QHideEvent * event) { QWebView::hideEvent(event); }
    virtual void hideEvent(QHideEvent * event);
    inline void inputMethodEvent_protected(QInputMethodEvent * arg__1) { QWebView::inputMethodEvent(arg__1); }
    virtual void inputMethodEvent(QInputMethodEvent * arg__1);
    virtual QVariant inputMethodQuery(Qt::InputMethodQuery property) const;
    inline void keyPressEvent_protected(QKeyEvent * arg__1) { QWebView::keyPressEvent(arg__1); }
    virtual void keyPressEvent(QKeyEvent * arg__1);
    inline void keyReleaseEvent_protected(QKeyEvent * arg__1) { QWebView::keyReleaseEvent(arg__1); }
    virtual void keyReleaseEvent(QKeyEvent * arg__1);
    inline void languageChange_protected() { QWebView::languageChange(); }
    virtual void languageChange();
    inline void leaveEvent_protected(QEvent * event) { QWebView::leaveEvent(event); }
    virtual void leaveEvent(QEvent * event);
    virtual const QMetaObject * metaObject() const;
    inline int metric_protected(int arg__1) const { return QWebView::metric(QPaintDevice::PaintDeviceMetric(arg__1)); }
    virtual int metric(QPaintDevice::PaintDeviceMetric arg__1) const;
    virtual QSize minimumSizeHint() const;
    inline void mouseDoubleClickEvent_protected(QMouseEvent * arg__1) { QWebView::mouseDoubleClickEvent(arg__1); }
    virtual void mouseDoubleClickEvent(QMouseEvent * arg__1);
    inline void mouseMoveEvent_protected(QMouseEvent * arg__1) { QWebView::mouseMoveEvent(arg__1); }
    virtual void mouseMoveEvent(QMouseEvent * arg__1);
    inline void mousePressEvent_protected(QMouseEvent * arg__1) { QWebView::mousePressEvent(arg__1); }
    virtual void mousePressEvent(QMouseEvent * arg__1);
    inline void mouseReleaseEvent_protected(QMouseEvent * arg__1) { QWebView::mouseReleaseEvent(arg__1); }
    virtual void mouseReleaseEvent(QMouseEvent * arg__1);
    inline void moveEvent_protected(QMoveEvent * event) { QWebView::moveEvent(event); }
    virtual void moveEvent(QMoveEvent * event);
    virtual QPaintEngine * paintEngine() const;
    inline void paintEvent_protected(QPaintEvent * arg__1) { QWebView::paintEvent(arg__1); }
    virtual void paintEvent(QPaintEvent * arg__1);
    inline void resetInputContext_protected() { QWebView::resetInputContext(); }
    inline void resizeEvent_protected(QResizeEvent * arg__1) { QWebView::resizeEvent(arg__1); }
    virtual void resizeEvent(QResizeEvent * arg__1);
    virtual void setVisible(bool visible);
    inline void showEvent_protected(QShowEvent * event) { QWebView::showEvent(event); }
    virtual void showEvent(QShowEvent * event);
    virtual QSize sizeHint() const;
    inline void tabletEvent_protected(QTabletEvent * event) { QWebView::tabletEvent(event); }
    virtual void tabletEvent(QTabletEvent * event);
    inline void timerEvent_protected(QTimerEvent * arg__1) { QWebView::timerEvent(arg__1); }
    virtual void timerEvent(QTimerEvent * arg__1);
    inline void updateMicroFocus_protected() { QWebView::updateMicroFocus(); }
    inline void wheelEvent_protected(QWheelEvent * arg__1) { QWebView::wheelEvent(arg__1); }
    virtual void wheelEvent(QWheelEvent * arg__1);
    inline bool winEvent_protected(MSG * message, long * result) { return QWebView::winEvent(message, result); }
    virtual bool winEvent(MSG * message, long * result);
    virtual ~QWebViewWrapper();
public:
    virtual int qt_metacall(QMetaObject::Call call, int id, void** args);
    virtual void* qt_metacast(const char* _clname);
    static void pysideInitQtMetaTypes();
};

#endif // SBK_QWEBVIEWWRAPPER_H

